@@ -116,7 +116,7 @@ namespace etl
     //*************************************************************************
     ETL_NODISCARD
     ETL_CONSTEXPR14
-    reference at(size_t i)
+    reference at(size_t i) ETL_NOEXCEPT_EXPR(ETL_NOT_USING_EXCEPTIONS)
     {
       ETL_ASSERT(i < SIZE, ETL_ERROR(array_out_of_range));
 
@@ -129,7 +129,7 @@ namespace etl
     //*************************************************************************
     ETL_NODISCARD
     ETL_CONSTEXPR14
-    const_reference at(size_t i) const
+    const_reference at(size_t i) const ETL_NOEXCEPT_EXPR(ETL_NOT_USING_EXCEPTIONS)
     {
       ETL_ASSERT(i < SIZE, ETL_ERROR(array_out_of_range));
 
@@ -143,8 +143,10 @@ namespace etl
     //*************************************************************************
     ETL_NODISCARD
     ETL_CONSTEXPR14
-    reference operator[](size_t i)
+    reference operator[](size_t i) ETL_NOEXCEPT_EXPR(ETL_NOT_USING_EXCEPTIONS || ETL_NOT_CHECKING_INDEX_OPERATOR)
     {
+      ETL_ASSERT_CHECK_INDEX_OPERATOR(i < SIZE, ETL_ERROR(array_out_of_range));
+
       return _buffer[i];
     }
 
@@ -154,9 +156,16 @@ namespace etl
     ///\param i The index of the element to access.
     //*************************************************************************
     ETL_NODISCARD
-    ETL_CONSTEXPR const_reference operator[](size_t i) const
+    ETL_CONSTEXPR const_reference operator[](size_t i) const ETL_NOEXCEPT_EXPR(ETL_NOT_USING_EXCEPTIONS || ETL_NOT_CHECKING_INDEX_OPERATOR)
     {
+      // Throwing from c++11 constexpr requires special syntax
+#if ETL_USING_CPP11 && ETL_NOT_USING_CPP14 && ETL_USING_EXCEPTIONS && ETL_CHECKING_INDEX_OPERATOR
+      return i < SIZE ? _buffer[i] : throw(ETL_ERROR(array_out_of_range));
+#else
+      ETL_ASSERT_CHECK_INDEX_OPERATOR(i < SIZE, ETL_ERROR(array_out_of_range));
+
       return _buffer[i];
+#endif
     }
 
     //*************************************************************************
@@ -164,8 +173,10 @@ namespace etl
     //*************************************************************************
     ETL_NODISCARD
     ETL_CONSTEXPR14
-    reference front()
+    reference front() ETL_NOEXCEPT
     {
+      ETL_STATIC_ASSERT(SIZE > 0, "Array is empty.");
+
       return _buffer[0];
     }
 
@@ -173,8 +184,10 @@ namespace etl
     /// Returns a const reference to the first element.
     //*************************************************************************
     ETL_NODISCARD
-    ETL_CONSTEXPR const_reference front() const
+    ETL_CONSTEXPR const_reference front() const ETL_NOEXCEPT
     {
+      ETL_STATIC_ASSERT(SIZE > 0, "Array is empty.");
+
       return _buffer[0];
     }
 
@@ -183,8 +196,10 @@ namespace etl
     //*************************************************************************
     ETL_NODISCARD
     ETL_CONSTEXPR14
-    reference back()
+    reference back() ETL_NOEXCEPT
     {
+      ETL_STATIC_ASSERT(SIZE > 0, "Array is empty.");
+
       return _buffer[SIZE - 1];
     }
 
@@ -192,8 +207,10 @@ namespace etl
     /// Returns a const reference to the last element.
     //*************************************************************************
     ETL_NODISCARD
-    ETL_CONSTEXPR const_reference back() const
+    ETL_CONSTEXPR const_reference back() const ETL_NOEXCEPT
     {
+      ETL_STATIC_ASSERT(SIZE > 0, "Array is empty.");
+
       return _buffer[SIZE - 1];
     }
 
@@ -380,7 +397,7 @@ namespace etl
     /// Swaps the contents of this array and another.
     ///\param other A reference to the other array.
     //*************************************************************************
-    ETL_CONSTEXPR14 void swap(array& other) ETL_NOEXCEPT
+    ETL_CONSTEXPR14 void swap(array& other) ETL_NOEXCEPT_FROM(ETL_OR_STD::swap(etl::declval<T&>(), etl::declval<T&>()))
     {
       using ETL_OR_STD::swap; // Allow ADL
 
@@ -429,6 +446,8 @@ namespace etl
     //*************************************************************************
     inline iterator insert_at(size_t position, parameter_t value)
     {
+      ETL_ASSERT_CHECK_EXTRA(position < SIZE, ETL_ERROR(array_out_of_range));
+
       return insert(begin() + position, value);
     }
 
@@ -439,6 +458,8 @@ namespace etl
     //*************************************************************************
     iterator insert(const_iterator position, parameter_t value)
     {
+      ETL_ASSERT_CHECK_EXTRA(cbegin() <= position && position < cend(), ETL_ERROR(array_out_of_range));
+
       iterator p = to_iterator(position);
 
       etl::move_backward(p, end() - 1, end());
@@ -456,6 +477,8 @@ namespace etl
     template <typename TIterator>
     inline iterator insert_at(size_t position, TIterator first, const TIterator last)
     {
+      ETL_ASSERT_CHECK_EXTRA(position < SIZE, ETL_ERROR(array_out_of_range));
+
       return insert(begin() + position, first, last);
     }
 
@@ -468,6 +491,8 @@ namespace etl
     template <typename TIterator>
     iterator insert(const_iterator position, TIterator first, const TIterator last)
     {
+      ETL_ASSERT_CHECK_EXTRA(cbegin() <= position && position < cend(), ETL_ERROR(array_out_of_range));
+
       iterator p = to_iterator(position);
       iterator result(p);
 
@@ -494,6 +519,8 @@ namespace etl
     //*************************************************************************
     inline iterator erase_at(size_t position)
     {
+      ETL_ASSERT_CHECK_EXTRA(position < SIZE, ETL_ERROR(array_out_of_range));
+
       return erase(begin() + position);
     }
 
@@ -504,6 +531,8 @@ namespace etl
     //*************************************************************************
     iterator erase(const_iterator position)
     {
+      ETL_ASSERT_CHECK_EXTRA(cbegin() <= position && position < cend(), ETL_ERROR(array_out_of_range));
+
       iterator p = to_iterator(position);
       etl::move(p + 1, end(), p);
 
@@ -518,6 +547,8 @@ namespace etl
     //*************************************************************************
     iterator erase_range(size_t first, size_t last)
     {
+      ETL_ASSERT_CHECK_EXTRA(first <= last && last <= SIZE, ETL_ERROR(array_out_of_range));
+
       return erase(begin() + first, begin() + last);
     }
 
@@ -529,6 +560,8 @@ namespace etl
     //*************************************************************************
     iterator erase(const_iterator first, const_iterator last)
     {
+      ETL_ASSERT_CHECK_EXTRA(cbegin() <= first && first <= last && last <= cend(), ETL_ERROR(array_out_of_range));
+
       iterator p = to_iterator(first);
       etl::move(last, cend(), p);
       return p;
@@ -541,6 +574,8 @@ namespace etl
     //*************************************************************************
     inline iterator erase_at(size_t position, parameter_t value)
     {
+      ETL_ASSERT_CHECK_EXTRA(position < SIZE, ETL_ERROR(array_out_of_range));
+
       return erase(begin() + position, value);
     }
 
@@ -551,6 +586,8 @@ namespace etl
     //*************************************************************************
     iterator erase(const_iterator position, parameter_t value)
     {
+      ETL_ASSERT_CHECK_EXTRA(cbegin() <= position && position < cend(), ETL_ERROR(array_out_of_range));
+
       iterator p = to_iterator(position);
 
       etl::move(p + 1, end(), p);
@@ -567,16 +604,21 @@ namespace etl
     //*************************************************************************
     iterator erase_range(size_t first, size_t last, parameter_t value)
     {
+      ETL_ASSERT_CHECK_EXTRA(first <= last && last <= SIZE, ETL_ERROR(array_out_of_range));
+
       return erase(begin() + first, begin() + last, value);
     }
 
     //*************************************************************************
     /// Erases a range of values from the array.
-    ///\param position The iterator to the position to erase at.
-    ///\param value    The value to use to overwrite the last elements in the array.
+    ///\param first The first item to erase.
+    ///\param last  The one past the last item to erase.
+    ///\param value The value to use to overwrite the last elements in the array.
     //*************************************************************************
     iterator erase(const_iterator first, const_iterator last, parameter_t value)
     {
+      ETL_ASSERT_CHECK_EXTRA(cbegin() <= first && first <= last && last <= cend(), ETL_ERROR(array_out_of_range));
+
       iterator p = to_iterator(first);
 
       p = etl::move(last, cend(), p);
@@ -640,7 +682,7 @@ namespace etl
     //*************************************************************************
     ETL_NODISCARD
     ETL_CONSTEXPR14
-    reference at(size_t)
+    reference at(size_t) ETL_NOEXCEPT
     {
       return *data();
     }
@@ -651,7 +693,7 @@ namespace etl
     //*************************************************************************
     ETL_NODISCARD
     ETL_CONSTEXPR14
-    const_reference at(size_t) const
+    const_reference at(size_t) const ETL_NOEXCEPT
     {
       return *data();
     }
@@ -663,7 +705,7 @@ namespace etl
     //*************************************************************************
     ETL_NODISCARD
     ETL_CONSTEXPR14
-    reference operator[](size_t)
+    reference operator[](size_t) ETL_NOEXCEPT
     {
       return *data();
     }
@@ -674,7 +716,7 @@ namespace etl
     ///\param i The index of the element to access.
     //*************************************************************************
     ETL_NODISCARD
-    ETL_CONSTEXPR const_reference operator[](size_t) const
+    ETL_CONSTEXPR const_reference operator[](size_t) const ETL_NOEXCEPT
     {
       return *data();
     }
@@ -684,7 +726,7 @@ namespace etl
     //*************************************************************************
     ETL_NODISCARD
     ETL_CONSTEXPR14
-    reference front()
+    reference front() ETL_NOEXCEPT
     {
       return *data();
     }
@@ -693,7 +735,7 @@ namespace etl
     /// Returns a const reference to the first element.
     //*************************************************************************
     ETL_NODISCARD
-    ETL_CONSTEXPR const_reference front() const
+    ETL_CONSTEXPR const_reference front() const ETL_NOEXCEPT
     {
       return *data();
     }
@@ -703,7 +745,7 @@ namespace etl
     //*************************************************************************
     ETL_NODISCARD
     ETL_CONSTEXPR14
-    reference back()
+    reference back() ETL_NOEXCEPT
     {
       return *data();
     }
@@ -891,7 +933,7 @@ namespace etl
     /// Fills the array with the specified value.
     ///\param value The value to fill the array with.
     //*************************************************************************
-    ETL_CONSTEXPR14 void fill(parameter_t)
+    ETL_CONSTEXPR14 void fill(parameter_t) ETL_NOEXCEPT
     {
     }
 
@@ -911,7 +953,7 @@ namespace etl
     ///\return An iterator to the first unassigned array element, or end().
     //*************************************************************************
     template <typename TIterator>
-    iterator assign(TIterator, const TIterator)
+    iterator assign(TIterator, const TIterator) ETL_NOEXCEPT
     {
       return iterator();
     }
@@ -924,7 +966,7 @@ namespace etl
     ///\return An iterator to the first array element set to 'value', or end().
     //*************************************************************************
     template <typename TIterator>
-    iterator assign(TIterator, const TIterator, parameter_t)
+    iterator assign(TIterator, const TIterator, parameter_t) ETL_NOEXCEPT
     {
       return iterator();
     }
@@ -934,7 +976,7 @@ namespace etl
     ///\param position The index of the position to insert at.
     ///\param value    The value to insert.
     //*************************************************************************
-    inline iterator insert_at(size_t, parameter_t)
+    inline iterator insert_at(size_t, parameter_t) ETL_NOEXCEPT
     {
       return iterator();
     }
@@ -944,7 +986,7 @@ namespace etl
     ///\param position The iterator to the position to insert at.
     ///\param value    The value to insert.
     //*************************************************************************
-    iterator insert(const_iterator, parameter_t)
+    iterator insert(const_iterator, parameter_t) ETL_NOEXCEPT
     {
       return iterator();
     }
@@ -956,7 +998,7 @@ namespace etl
     ///\param last     The iterator to one past the final item in the range.
     //*************************************************************************
     template <typename TIterator>
-    inline iterator insert_at(size_t, TIterator, const TIterator)
+    inline iterator insert_at(size_t, TIterator, const TIterator) ETL_NOEXCEPT
     {
       return iterator();
     }
@@ -968,7 +1010,7 @@ namespace etl
     ///\param last     The iterator to one past the final item in the range.
     //*************************************************************************
     template <typename TIterator>
-    iterator insert(const_iterator, TIterator, const TIterator)
+    iterator insert(const_iterator, TIterator, const TIterator) ETL_NOEXCEPT
     {
       return iterator();
     }
@@ -978,7 +1020,7 @@ namespace etl
     /// After erase, the last value in the array will be unmodified.
     ///\param position The index of the position to erase at.
     //*************************************************************************
-    inline iterator erase_at(size_t)
+    inline iterator erase_at(size_t) ETL_NOEXCEPT
     {
       return iterator();
     }
@@ -988,7 +1030,7 @@ namespace etl
     /// After erase, the last value in the array will be unmodified.
     ///\param position The iterator to the position to erase at.
     //*************************************************************************
-    iterator erase(const_iterator)
+    iterator erase(const_iterator) ETL_NOEXCEPT
     {
       return iterator();
     }
@@ -999,7 +1041,7 @@ namespace etl
     ///\param first The first item to erase.
     ///\param last  The one past the last item to erase.
     //*************************************************************************
-    iterator erase_range(size_t, size_t)
+    iterator erase_range(size_t, size_t) ETL_NOEXCEPT
     {
       return iterator();
     }
@@ -1010,7 +1052,7 @@ namespace etl
     ///\param first The first item to erase.
     ///\param last  The one past the last item to erase.
     //*************************************************************************
-    iterator erase(const_iterator, const_iterator)
+    iterator erase(const_iterator, const_iterator) ETL_NOEXCEPT
     {
       return iterator();
     }
@@ -1020,7 +1062,7 @@ namespace etl
     ///\param position The index of the position to erase at.
     ///\param value    The value to use to overwrite the last element in the array.
     //*************************************************************************
-    inline iterator erase_at(size_t, parameter_t)
+    inline iterator erase_at(size_t, parameter_t) ETL_NOEXCEPT
     {
       return iterator();
     }
@@ -1030,7 +1072,7 @@ namespace etl
     ///\param position The iterator to the position to erase at.
     ///\param value    The value to use to overwrite the last element in the array.
     //*************************************************************************
-    iterator erase(const_iterator, parameter_t)
+    iterator erase(const_iterator, parameter_t) ETL_NOEXCEPT
     {
       return iterator();
     }
@@ -1041,7 +1083,7 @@ namespace etl
     ///\param last  The one past the last item to erase.
     ///\param value The value to use to overwrite the last elements in the array.
     //*************************************************************************
-    iterator erase_range(size_t, size_t, parameter_t)
+    iterator erase_range(size_t, size_t, parameter_t) ETL_NOEXCEPT
     {
       return iterator();
     }
@@ -1051,7 +1093,7 @@ namespace etl
     ///\param position The iterator to the position to erase at.
     ///\param value    The value to use to overwrite the last elements in the array.
     //*************************************************************************
-    iterator erase(const_iterator, const_iterator, parameter_t)
+    iterator erase(const_iterator, const_iterator, parameter_t) ETL_NOEXCEPT
     {
       return iterator();
     }
@@ -1164,32 +1206,32 @@ namespace etl
 
   //*************************************************************************
   /// Gets a reference to an element in the array.
-  ///\tparam I The index.
+  ///\tparam Index The index.
   ///\tparam T The type.
-  ///\tparam MAXN The array size.
+  ///\tparam Size The array size.
   ///\param a The array.
   ///\return A reference to the element
   //*************************************************************************
-  template <size_t I, typename T, size_t MAXN>
-  inline T& get(array<T, MAXN>& a)
+  template <size_t Index, typename T, size_t Size>
+  inline T& get(array<T, Size>& a)
   {
-    ETL_STATIC_ASSERT(I < MAXN, "Index out of bounds");
-    return a[I];
+    ETL_STATIC_ASSERT(Index < Size, "Index out of bounds");
+    return a[Index];
   }
 
   //*************************************************************************
   /// Gets a const reference to an element in the array.
-  ///\tparam I The index.
+  ///\tparam Index The index.
   ///\tparam T The type.
-  ///\tparam MAXN The array size.
+  ///\tparam Size The array size.
   ///\param a The array.
   ///\return A const reference to the element
   //*************************************************************************
-  template <size_t I, typename T, size_t MAXN>
-  inline const T& get(const array<T, MAXN>& a)
+  template <size_t Index, typename T, size_t Size>
+  inline const T& get(const array<T, Size>& a)
   {
-    ETL_STATIC_ASSERT(I < MAXN, "Index out of bounds");
-    return a[I];
+    ETL_STATIC_ASSERT(Index < Size, "Index out of bounds");
+    return a[Index];
   }
 }
 
