@@ -52,6 +52,8 @@ namespace etl
 
     typedef etl::delegate<void(void)> callback_type;
 
+    typedef etl::delegate<void(etl::timer::id::type)> event_callback_type;
+
     //*******************************************
     /// Register a timer.
     //*******************************************
@@ -61,12 +63,12 @@ namespace etl
     {
       etl::timer::id::type id = etl::timer::id::NO_TIMER;
 
-      bool is_space = (number_of_registered_timers < MAX_TIMERS);
+      bool is_space = (number_of_registered_timers < Max_Timers);
 
       if (is_space)
       {
         // Search for the free space.
-        for (uint_least8_t i = 0U; i < MAX_TIMERS; ++i)
+        for (uint_least8_t i = 0U; i < Max_Timers; ++i)
         {
           timer_data& timer = timer_array[i];
 
@@ -106,6 +108,7 @@ namespace etl
             (void)guard; // Silence 'unused variable warnings.
 
             active_list.remove(timer.id, false);
+            remove_callback.call_if(timer.id);
           }
 
           // Reset in-place.
@@ -148,7 +151,7 @@ namespace etl
         number_of_registered_timers = 0;
       }
 
-      for (uint8_t i = 0U; i < MAX_TIMERS; ++i)
+      for (uint8_t i = 0U; i < Max_Timers; ++i)
       {
         ::new (&timer_array[i]) timer_data();
       }
@@ -176,6 +179,7 @@ namespace etl
             count -= timer.delta;
 
             active_list.remove(timer.id, true);
+            remove_callback.call_if(timer.id);
 
             if (timer.callback.is_valid())
             {
@@ -187,6 +191,7 @@ namespace etl
               // Reinsert the timer.
               timer.delta = timer.period;
               active_list.insert(timer.id);
+              insert_callback.call_if(timer.id);
             }
 
             has_active = !active_list.empty();
@@ -229,10 +234,12 @@ namespace etl
             if (timer.is_active())
             {
               active_list.remove(timer.id, false);
+              remove_callback.call_if(timer.id);
             }
 
             timer.delta = immediate_ ? 0U : timer.period;
             active_list.insert(timer.id);
+            insert_callback.call_if(timer.id);
 
             result = true;
           }
@@ -263,6 +270,7 @@ namespace etl
             (void)guard; // Silence 'unused variable warnings.
 
             active_list.remove(timer.id, false);
+            remove_callback.call_if(timer.id);
           }
 
           result = true;
@@ -356,6 +364,34 @@ namespace etl
       return false;
     }
 
+    //*******************************************
+    /// Set a callback when a timer is inserted on list
+    //*******************************************
+    void set_insert_callback(event_callback_type insert_)
+    {
+      insert_callback = insert_;
+    }
+
+    //*******************************************
+    /// Set a callback when a timer is removed from list
+    //*******************************************
+    void set_remove_callback(event_callback_type remove_)
+    {
+      remove_callback = remove_;
+    }
+
+    //*******************************************
+    void clear_insert_callback()
+    {
+      insert_callback.clear();
+    }
+
+    //*******************************************
+    void clear_remove_callback()
+    {
+      remove_callback.clear();
+    }
+
   protected:
 
     //*************************************************************************
@@ -425,12 +461,12 @@ namespace etl
     //*******************************************
     /// Constructor.
     //*******************************************
-    icallback_timer_interrupt(timer_data* const timer_array_, const uint_least8_t  MAX_TIMERS_)
+    icallback_timer_interrupt(timer_data* const timer_array_, const uint_least8_t  Max_Timers_)
       : timer_array(timer_array_)
       , active_list(timer_array_)
       , enabled(false)
       , number_of_registered_timers(0U)
-      , MAX_TIMERS(MAX_TIMERS_)
+      , Max_Timers(Max_Timers_)
     {
     }
 
@@ -441,7 +477,7 @@ namespace etl
     //*******************************************
     bool is_valid_timer_id(etl::timer::id::type id_) const
     {
-      return (id_ < MAX_TIMERS);
+      return (id_ < Max_Timers);
     }
 
     //*************************************************************************
@@ -637,20 +673,23 @@ namespace etl
     bool enabled;
     uint_least8_t number_of_registered_timers;
 
+    event_callback_type insert_callback;
+    event_callback_type remove_callback;
+
   public:
 
-    const uint_least8_t MAX_TIMERS;
+    const uint_least8_t Max_Timers;
   };
 
   //***************************************************************************
   /// The callback timer
   //***************************************************************************
-  template <uint_least8_t MAX_TIMERS_, typename TInterruptGuard>
+  template <uint_least8_t Max_Timers_, typename TInterruptGuard>
   class callback_timer_interrupt : public etl::icallback_timer_interrupt<TInterruptGuard>
   {
   public:
 
-    ETL_STATIC_ASSERT(MAX_TIMERS_ <= 254U, "No more than 254 timers are allowed");
+    ETL_STATIC_ASSERT(Max_Timers_ <= 254U, "No more than 254 timers are allowed");
 
     typedef typename icallback_timer_interrupt<TInterruptGuard>::callback_type callback_type;
 
@@ -658,13 +697,13 @@ namespace etl
     /// Constructor.
     //*******************************************
     callback_timer_interrupt()
-      : icallback_timer_interrupt<TInterruptGuard>(timer_array, MAX_TIMERS_)
+      : icallback_timer_interrupt<TInterruptGuard>(timer_array, Max_Timers_)
     {
     }
 
   private:
 
-    typename icallback_timer_interrupt<TInterruptGuard>::timer_data timer_array[MAX_TIMERS_];
+    typename icallback_timer_interrupt<TInterruptGuard>::timer_data timer_array[Max_Timers_];
   };
 }
 
