@@ -54,6 +54,8 @@ namespace etl
     typedef etl::delegate<void(void)> lock_type;
     typedef etl::delegate<void(void)> unlock_type;
 
+    typedef etl::delegate<void(etl::timer::id::type)> event_callback_type;
+
     //*******************************************
     /// Register a timer.
     //*******************************************
@@ -63,12 +65,12 @@ namespace etl
     {
       etl::timer::id::type id = etl::timer::id::NO_TIMER;
 
-      bool is_space = (number_of_registered_timers < MAX_TIMERS);
+      bool is_space = (number_of_registered_timers < Max_Timers);
 
       if (is_space)
       {
         // Search for the free space.
-        for (uint_least8_t i = 0U; i < MAX_TIMERS; ++i)
+        for (uint_least8_t i = 0U; i < Max_Timers; ++i)
         {
           timer_data& timer = timer_array[i];
 
@@ -103,6 +105,7 @@ namespace etl
           {
             lock();
             active_list.remove(timer.id, false);
+            remove_callback.call_if(timer.id);
             unlock();
           }
 
@@ -142,7 +145,7 @@ namespace etl
       active_list.clear();
       unlock();
 
-      for (uint8_t i = 0U; i < MAX_TIMERS; ++i)
+      for (uint8_t i = 0U; i < Max_Timers; ++i)
       {
         ::new (&timer_array[i]) timer_data();
       }
@@ -180,10 +183,12 @@ namespace etl
             if (timer.is_active())
             {
               active_list.remove(timer.id, false);
+              remove_callback.call_if(timer.id);
             }
 
             timer.delta = immediate_ ? 0U : timer.period;
             active_list.insert(timer.id);
+            insert_callback.call_if(timer.id);
             unlock();
 
             result = true;
@@ -213,6 +218,7 @@ namespace etl
           {
             lock();
             active_list.remove(timer.id, false);
+            remove_callback.call_if(timer.id);
             unlock();
           }
 
@@ -319,8 +325,53 @@ namespace etl
       return result;
     }
 
+    //*******************************************
+    /// Set a callback when a timer is inserted on list
+    //*******************************************
+    void set_insert_callback(event_callback_type insert_)
+    {
+      insert_callback = insert_;
+    }
+
+    //*******************************************
+    /// Set a callback when a timer is removed from list
+    //*******************************************
+    void set_remove_callback(event_callback_type remove_)
+    {
+      remove_callback = remove_;
+    }
+
+    //*******************************************
+    void clear_insert_callback()
+    {
+      insert_callback.clear();
+    }
+
+    //*******************************************
+    void clear_remove_callback()
+    {
+      remove_callback.clear();
+    }
+
   protected:
 
+    class callback_node 
+    {
+    public:
+
+      callback_node(callback_type &callback_,uint_least8_t priority_) : callback(callback_), priority(priority_) 
+      {
+      }
+
+      bool operator < (const callback_node& p) const
+      {
+        return this->priority > p.priority; // comparison was inverted here to easy the code design
+      }
+
+      callback_type callback;
+      uint_least8_t priority;
+    };
+
     //*************************************************************************
     /// The configuration of a timer.
     struct timer_data
@@ -388,12 +439,12 @@ namespace etl
     //*******************************************
     /// Constructor.
     //*******************************************
-    icallback_timer_locked(timer_data* const timer_array_, const uint_least8_t  MAX_TIMERS_)
+    icallback_timer_locked(timer_data* const timer_array_, const uint_least8_t  Max_Timers_)
       : timer_array(timer_array_),
         active_list(timer_array_),
         enabled(false),
         number_of_registered_timers(0U),
-        MAX_TIMERS(MAX_TIMERS_)
+        Max_Timers(Max_Timers_)
     {
     }
 
@@ -588,7 +639,7 @@ namespace etl
     //*******************************************
     bool is_valid_timer_id(etl::timer::id::type id_) const
     {
-      return (id_ < MAX_TIMERS);
+      return (id_ < Max_Timers);
     }
 
     // The array of timer data structures.
@@ -604,36 +655,46 @@ namespace etl
     lock_type     lock;     ///< The callback that locks.
     unlock_type   unlock;   ///< The callback that unlocks.
 
+    event_callback_type insert_callback;
+    event_callback_type remove_callback;
+
   public:
+
     template <uint_least8_t>
     friend class callback_timer_locked;
 
     template <uint_least8_t, uint32_t>
     friend class callback_timer_deferred_locked;
 
-    const uint_least8_t MAX_TIMERS;
+    const uint_least8_t Max_Timers;
   };
 
   //***************************************************************************
   /// The callback timer
   //***************************************************************************
-  template <uint_least8_t MAX_TIMERS_>
+  template <uint_least8_t Max_Timers_>
   class callback_timer_locked : public etl::icallback_timer_locked
   {
   public:
 
-    ETL_STATIC_ASSERT(MAX_TIMERS_ <= 254U, "No more than 254 timers are allowed");
+    ETL_STATIC_ASSERT(Max_Timers_ <= 254U, "No more than 254 timers are allowed");
 
     typedef icallback_timer_locked::callback_type callback_type;
     typedef icallback_timer_locked::try_lock_type try_lock_type;
     typedef icallback_timer_locked::lock_type     lock_type;
     typedef icallback_timer_locked::unlock_type   unlock_type;
 
+  private:
+
+    typedef icallback_timer_locked::callback_node callback_node;
+
+  public:
+
     //*******************************************
     /// Constructor.
     //*******************************************
     callback_timer_locked()
-      : icallback_timer_locked(timer_array, MAX_TIMERS_)
+      : icallback_timer_locked(timer_array, Max_Timers_)
     {
     }
 
@@ -641,13 +702,14 @@ namespace etl
     /// Constructor.
     //*******************************************
     callback_timer_locked(try_lock_type try_lock_, lock_type lock_, unlock_type unlock_)
-      : icallback_timer_locked(timer_array, MAX_TIMERS_)
+      : icallback_timer_locked(timer_array, Max_Timers_)
     {
       this->set_locks(try_lock_, lock_, unlock_);
     }
 
-    // Implement virtual functions
-
+    //*******************************************
+    /// Handle the tick call
+    //*******************************************
     bool tick(uint32_t count) final
     {
       if (enabled)
@@ -666,6 +728,7 @@ namespace etl
               count -= timer.delta;
 
               active_list.remove(timer.id, true);
+              remove_callback.call_if(timer.id);
 
               if (timer.callback.is_valid())
               {
@@ -677,6 +740,7 @@ namespace etl
                 // Reinsert the timer.
                 timer.delta = timer.period;
                 active_list.insert(timer.id);
+                insert_callback.call_if(timer.id);
               }
 
               has_active = !active_list.empty();
@@ -700,7 +764,7 @@ namespace etl
 
   private:
 
-    timer_data timer_array[MAX_TIMERS_];
+    timer_data timer_array[Max_Timers_];
   };
 }
 
