@@ -990,8 +990,8 @@ namespace etl
     {
       if ETL_IF_CONSTEXPR(etl::is_trivially_destructible<T>::value)
       {
-        in    = 0U;
-        out   = 0U;
+        in  = 0U;
+        out = 0U;
         ETL_RESET_DEBUG_COUNT;
       }
       else
@@ -1063,9 +1063,9 @@ namespace etl
     template <typename TIterator>
     static difference_type distance(const TIterator& other)
     {
-      const difference_type index = other.get_index();
-      const difference_type reference_index = other.container().out;
-      const size_t buffer_size = other.container().buffer_size;
+      const difference_type index           = other.get_index();
+      const difference_type reference_index = static_cast<difference_type>(other.container().out);
+      const size_t buffer_size              = other.container().buffer_size;
 
       if (index < reference_index)
       {
@@ -1385,6 +1385,25 @@ namespace etl
 #endif
     }
 
+#if ETL_USING_CPP11
+    //*************************************************************************
+    /// Swap with another circular buffer
+    //*************************************************************************
+    void swap(circular_buffer_ext&& other) ETL_NOEXCEPT
+    {
+      using ETL_OR_STD::swap; // Allow ADL
+
+      swap(this->in, other.in);
+      swap(this->out, other.out);
+      swap(this->pbuffer, other.pbuffer);
+      swap(this->buffer_size, other.buffer_size);
+
+#if defined(ETL_DEBUG_COUNT)
+      this->etl_debug_count.swap(other.etl_debug_count);
+#endif
+    }
+#endif
+
     //*************************************************************************
     /// set_buffer
     //*************************************************************************
@@ -1439,6 +1458,17 @@ namespace etl
     lhs.swap(rhs);
   }
 
+#if ETL_USING_CPP11
+  //*************************************************************************
+  /// Overloaded swap for etl::circular_buffer_ext<T, 0>
+  //*************************************************************************
+  template <typename T>
+  void swap(etl::circular_buffer_ext<T>& lhs, etl::circular_buffer_ext<T>&& rhs)
+  {
+    lhs.swap(rhs);
+  }
+#endif
+
   //*************************************************************************
   /// Equality operator
   //*************************************************************************
