@@ -485,11 +485,11 @@ namespace etl
   /// Template deduction guides.
   //*************************************************************************
 #if ETL_USING_CPP17
-  template <typename TElements, size_t N>
-  const_multiset_ext(const etl::span<TElements, N>&) -> const_multiset_ext<TElements>;
+  template <typename TElements, size_t Size>
+  const_multiset_ext(const etl::span<TElements, Size>&) -> const_multiset_ext<TElements>;
 
-  template <typename TElements, size_t N>
-  const_multiset_ext(const TElements(&)[N]) -> const_multiset_ext<TElements>;
+  template <typename TElements, size_t Size>
+  const_multiset_ext(const TElements(&)[Size]) -> const_multiset_ext<TElements>;
 #endif
 
   //*************************************************************************
