@@ -107,4 +107,6 @@ SOFTWARE.
 #define ETL_UNALIGNED_TYPE_FILE_ID "74"
 #define ETL_SPAN_FILE_ID "75"
 #define ETL_ALGORITHM_FILE_ID "76"
+#define ETL_NOT_NULL_FILE_ID "77"
+#define ETL_SIGNAL_FILE_ID "78"
 #endif
