@@ -43,7 +43,6 @@ SOFTWARE.
 #include "type_traits.h"
 #include "algorithm.h"
 #include "memory.h"
-#include "iterator.h"
 #include "static_assert.h"
 #include "parameter_type.h"
 #include "placement_new.h"
@@ -397,7 +396,7 @@ namespace etl
     node_t      terminal_node;   ///< The node that acts as the list start and end.
     size_type   MAX_SIZE;        ///< The maximum size of the list.
     bool        pool_is_shared;  ///< If <b>true</b> then the pool is shared between lists.
-    ETL_DECLARE_DEBUG_COUNT      ///< Internal debugging.
+    ETL_DECLARE_DEBUG_COUNT;      ///< Internal debugging.
   };
 
   //***************************************************************************
@@ -838,9 +837,8 @@ namespace etl
     //*************************************************************************
     void push_front(const T& value)
     {
-#if defined(ETL_CHECK_PUSH_POP)
-      ETL_ASSERT(!full(), ETL_ERROR(list_full));
-#endif
+      ETL_ASSERT_CHECK_PUSH_POP_OR_RETURN(!full(), ETL_ERROR(list_full));
+
       insert_node(get_head(), allocate_data_node(value));
     }
 
@@ -850,46 +848,60 @@ namespace etl
     //*************************************************************************
     void push_front(rvalue_reference value)
     {
-#if defined(ETL_CHECK_PUSH_POP)
-      ETL_ASSERT(!full(), ETL_ERROR(list_full));
-#endif
+      ETL_ASSERT_CHECK_PUSH_POP_OR_RETURN(!full(), ETL_ERROR(list_full));
+
       insert_node(get_head(), allocate_data_node(etl::move(value)));
     }
 #endif
 
-#if ETL_USING_CPP11 && ETL_NOT_USING_STLPORT
+#if ETL_USING_CPP11 && ETL_NOT_USING_STLPORT && !defined(ETL_LIST_FORCE_CPP03_IMPLEMENTATION)
     //*************************************************************************
     /// Emplaces a value to the front of the list.
     //*************************************************************************
     template <typename ... Args>
     reference emplace_front(Args && ... args)
     {
-#if defined(ETL_CHECK_PUSH_POP)
-      ETL_ASSERT(!full(), ETL_ERROR(list_full));
-#endif
+
+      ETL_ASSERT_CHECK_PUSH_POP(!full(), ETL_ERROR(list_full));
+
       ETL_ASSERT(p_node_pool != ETL_NULLPTR, ETL_ERROR(list_no_pool));
 
       data_node_t* p_data_node = allocate_data_node();
       ::new (&(p_data_node->value)) T(etl::forward<Args>(args)...);
-      ETL_INCREMENT_DEBUG_COUNT
+      ETL_INCREMENT_DEBUG_COUNT;
       insert_node(get_head(), *p_data_node);
       return front();
     }
 #else
+    //*************************************************************************
+    /// Emplaces a value to the front of the list.
+    //*************************************************************************
+    reference emplace_front()
+    {
+      ETL_ASSERT_CHECK_PUSH_POP(!full(), ETL_ERROR(list_full));
+
+      ETL_ASSERT(p_node_pool != ETL_NULLPTR, ETL_ERROR(list_no_pool));
+
+      data_node_t* p_data_node = allocate_data_node();
+      ::new (&(p_data_node->value)) T();
+      ETL_INCREMENT_DEBUG_COUNT;
+        insert_node(get_head(), *p_data_node);
+      return front();
+    }
+
     //*************************************************************************
     /// Emplaces a value to the front of the list.
     //*************************************************************************
     template <typename T1>
     reference emplace_front(const T1& value1)
     {
-#if defined(ETL_CHECK_PUSH_POP)
-      ETL_ASSERT(!full(), ETL_ERROR(list_full));
-#endif
+      ETL_ASSERT_CHECK_PUSH_POP(!full(), ETL_ERROR(list_full));
+
       ETL_ASSERT(p_node_pool != ETL_NULLPTR, ETL_ERROR(list_no_pool));
 
       data_node_t* p_data_node = allocate_data_node();
       ::new (&(p_data_node->value)) T(value1);
-      ETL_INCREMENT_DEBUG_COUNT
+      ETL_INCREMENT_DEBUG_COUNT;
       insert_node(get_head(), *p_data_node);
       return front();
     }
@@ -900,14 +912,13 @@ namespace etl
     template <typename T1, typename T2>
     reference emplace_front(const T1& value1, const T2& value2)
     {
-#if defined(ETL_CHECK_PUSH_POP)
-      ETL_ASSERT(!full(), ETL_ERROR(list_full));
-#endif
+      ETL_ASSERT_CHECK_PUSH_POP(!full(), ETL_ERROR(list_full));
+
       ETL_ASSERT(p_node_pool != ETL_NULLPTR, ETL_ERROR(list_no_pool));
 
       data_node_t* p_data_node = allocate_data_node();
       ::new (&(p_data_node->value)) T(value1, value2);
-      ETL_INCREMENT_DEBUG_COUNT
+      ETL_INCREMENT_DEBUG_COUNT;
       insert_node(get_head(), *p_data_node);
       return front();
     }
@@ -918,14 +929,13 @@ namespace etl
     template <typename T1, typename T2, typename T3>
     reference emplace_front(const T1& value1, const T2& value2, const T3& value3)
     {
-#if defined(ETL_CHECK_PUSH_POP)
-      ETL_ASSERT(!full(), ETL_ERROR(list_full));
-#endif
+      ETL_ASSERT_CHECK_PUSH_POP(!full(), ETL_ERROR(list_full));
+
       ETL_ASSERT(p_node_pool != ETL_NULLPTR, ETL_ERROR(list_no_pool));
 
       data_node_t* p_data_node = allocate_data_node();
       ::new (&(p_data_node->value)) T(value1, value2, value3);
-      ETL_INCREMENT_DEBUG_COUNT
+      ETL_INCREMENT_DEBUG_COUNT;
       insert_node(get_head(), *p_data_node);
       return front();
     }
@@ -936,14 +946,13 @@ namespace etl
     template <typename T1, typename T2, typename T3, typename T4>
     reference emplace_front(const T1& value1, const T2& value2, const T3& value3, const T4& value4)
     {
-#if defined(ETL_CHECK_PUSH_POP)
-      ETL_ASSERT(!full(), ETL_ERROR(list_full));
-#endif
+      ETL_ASSERT_CHECK_PUSH_POP(!full(), ETL_ERROR(list_full));
+
       ETL_ASSERT(p_node_pool != ETL_NULLPTR, ETL_ERROR(list_no_pool));
 
       data_node_t* p_data_node = allocate_data_node();
       ::new (&(p_data_node->value)) T(value1, value2, value3, value4);
-      ETL_INCREMENT_DEBUG_COUNT
+      ETL_INCREMENT_DEBUG_COUNT;
       insert_node(get_head(), *p_data_node);
       return front();
     }
@@ -954,9 +963,8 @@ namespace etl
     //*************************************************************************
     void pop_front()
     {
-#if defined(ETL_CHECK_PUSH_POP)
-      ETL_ASSERT(!empty(), ETL_ERROR(list_empty));
-#endif
+      ETL_ASSERT_CHECK_PUSH_POP_OR_RETURN(!empty(), ETL_ERROR(list_empty));
+
       node_t& node = get_head();
       remove_node(node);
     }
@@ -966,9 +974,8 @@ namespace etl
     //*************************************************************************
     void push_back(const T& value)
     {
-#if defined(ETL_CHECK_PUSH_POP)
-      ETL_ASSERT(!full(), ETL_ERROR(list_full));
-#endif
+      ETL_ASSERT_CHECK_PUSH_POP_OR_RETURN(!full(), ETL_ERROR(list_full));
+
       insert_node(terminal_node, allocate_data_node(value));
     }
 
@@ -978,9 +985,8 @@ namespace etl
     //*************************************************************************
     void push_back(rvalue_reference value)
     {
-#if defined(ETL_CHECK_PUSH_POP)
-      ETL_ASSERT(!full(), ETL_ERROR(list_full));
-#endif
+      ETL_ASSERT_CHECK_PUSH_POP_OR_RETURN(!full(), ETL_ERROR(list_full));
+
       insert_node(terminal_node, allocate_data_node(etl::move(value)));
     }
 #endif
@@ -992,29 +998,40 @@ namespace etl
     template <typename ... Args>
     reference emplace_back(Args && ... args)
     {
-#if defined(ETL_CHECK_PUSH_POP)
-      ETL_ASSERT(!full(), ETL_ERROR(list_full));
-#endif
+      ETL_ASSERT_CHECK_PUSH_POP(!full(), ETL_ERROR(list_full));
+
       ETL_ASSERT(p_node_pool != ETL_NULLPTR, ETL_ERROR(list_no_pool));
 
       data_node_t* p_data_node = allocate_data_node();
       ::new (&(p_data_node->value)) T(etl::forward<Args>(args)...);
-      ETL_INCREMENT_DEBUG_COUNT
+      ETL_INCREMENT_DEBUG_COUNT;
       insert_node(terminal_node, *p_data_node);
       return back();
     }
 #else
+    reference emplace_back()
+    {
+      ETL_ASSERT_CHECK_PUSH_POP(!full(), ETL_ERROR(list_full));
+
+      ETL_ASSERT(p_node_pool != ETL_NULLPTR, ETL_ERROR(list_no_pool));
+
+      data_node_t* p_data_node = allocate_data_node();
+      ::new (&(p_data_node->value)) T();
+      ETL_INCREMENT_DEBUG_COUNT;
+        insert_node(terminal_node, *p_data_node);
+      return back();
+    }
+
     template <typename T1>
     reference emplace_back(const T1& value1)
     {
-#if defined(ETL_CHECK_PUSH_POP)
-      ETL_ASSERT(!full(), ETL_ERROR(list_full));
-#endif
+      ETL_ASSERT_CHECK_PUSH_POP(!full(), ETL_ERROR(list_full));
+
       ETL_ASSERT(p_node_pool != ETL_NULLPTR, ETL_ERROR(list_no_pool));
 
       data_node_t* p_data_node = allocate_data_node();
       ::new (&(p_data_node->value)) T(value1);
-      ETL_INCREMENT_DEBUG_COUNT
+      ETL_INCREMENT_DEBUG_COUNT;
       insert_node(terminal_node, *p_data_node);
       return back();
     }
@@ -1022,14 +1039,13 @@ namespace etl
     template <typename T1, typename T2>
     reference emplace_back(const T1& value1, const T2& value2)
     {
-#if defined(ETL_CHECK_PUSH_POP)
-      ETL_ASSERT(!full(), ETL_ERROR(list_full));
-#endif
+      ETL_ASSERT_CHECK_PUSH_POP(!full(), ETL_ERROR(list_full));
+
       ETL_ASSERT(p_node_pool != ETL_NULLPTR, ETL_ERROR(list_no_pool));
 
       data_node_t* p_data_node = allocate_data_node();
       ::new (&(p_data_node->value)) T(value1, value2);
-      ETL_INCREMENT_DEBUG_COUNT
+      ETL_INCREMENT_DEBUG_COUNT;
       insert_node(terminal_node, *p_data_node);
       return back();
     }
@@ -1037,14 +1053,13 @@ namespace etl
     template <typename T1, typename T2, typename T3>
     reference emplace_back(const T1& value1, const T2& value2, const T3& value3)
     {
-#if defined(ETL_CHECK_PUSH_POP)
-      ETL_ASSERT(!full(), ETL_ERROR(list_full));
-#endif
+      ETL_ASSERT_CHECK_PUSH_POP(!full(), ETL_ERROR(list_full));
+
       ETL_ASSERT(p_node_pool != ETL_NULLPTR, ETL_ERROR(list_no_pool));
 
       data_node_t* p_data_node = allocate_data_node();
       ::new (&(p_data_node->value)) T(value1, value2, value3);
-      ETL_INCREMENT_DEBUG_COUNT
+      ETL_INCREMENT_DEBUG_COUNT;
       insert_node(terminal_node, *p_data_node);
       return back();
     }
@@ -1052,14 +1067,13 @@ namespace etl
     template <typename T1, typename T2, typename T3, typename T4>
     reference emplace_back(const T1& value1, const T2& value2, const T3& value3, const T4& value4)
     {
-#if defined(ETL_CHECK_PUSH_POP)
-      ETL_ASSERT(!full(), ETL_ERROR(list_full));
-#endif
+      ETL_ASSERT_CHECK_PUSH_POP(!full(), ETL_ERROR(list_full));
+
       ETL_ASSERT(p_node_pool != ETL_NULLPTR, ETL_ERROR(list_no_pool));
 
       data_node_t* p_data_node = allocate_data_node();
       ::new (&(p_data_node->value)) T(value1, value2, value3, value4);
-      ETL_INCREMENT_DEBUG_COUNT
+      ETL_INCREMENT_DEBUG_COUNT;
       insert_node(terminal_node, *p_data_node);
       return back();
     }
@@ -1070,9 +1084,8 @@ namespace etl
     //*************************************************************************
     void pop_back()
     {
-#if defined(ETL_CHECK_PUSH_POP)
-      ETL_ASSERT(!empty(), ETL_ERROR(list_empty));
-#endif
+      ETL_ASSERT_CHECK_PUSH_POP_OR_RETURN(!empty(), ETL_ERROR(list_empty));
+
       node_t& node = get_tail();
       remove_node(node);
     }
@@ -1108,21 +1121,34 @@ namespace etl
     //*************************************************************************
     /// Emplaces a value to the list at the specified position.
     //*************************************************************************
-#if ETL_USING_CPP11 && ETL_NOT_USING_STLPORT
+#if ETL_USING_CPP11 && ETL_NOT_USING_STLPORT && !defined(ETL_LIST_FORCE_CPP03_IMPLEMENTATION)
     template <typename ... Args>
-    iterator emplace(const_iterator position, Args && ... args)
+    iterator emplace(const_iterator position, Args&& ... args)
     {
       ETL_ASSERT(!full(), ETL_ERROR(list_full));
       ETL_ASSERT(p_node_pool != ETL_NULLPTR, ETL_ERROR(list_no_pool));
 
       data_node_t* p_data_node = allocate_data_node();
       ::new (&(p_data_node->value)) T(etl::forward<Args>(args)...);
-      ETL_INCREMENT_DEBUG_COUNT
+      ETL_INCREMENT_DEBUG_COUNT;
       insert_node(*to_iterator(position).p_node, *p_data_node);
 
       return iterator(*p_data_node);
     }
 #else
+    iterator emplace(const_iterator position)
+    {
+      ETL_ASSERT(!full(), ETL_ERROR(list_full));
+      ETL_ASSERT(p_node_pool != ETL_NULLPTR, ETL_ERROR(list_no_pool));
+
+      data_node_t* p_data_node = allocate_data_node();
+      ::new (&(p_data_node->value)) T();
+      ETL_INCREMENT_DEBUG_COUNT;
+      insert_node(*to_iterator(position).p_node, *p_data_node);
+
+      return iterator(*p_data_node);
+    }
+
     template <typename T1>
     iterator emplace(const_iterator position, const T1& value1)
     {
@@ -1131,8 +1157,8 @@ namespace etl
 
       data_node_t* p_data_node = allocate_data_node();
       ::new (&(p_data_node->value)) T(value1);
-      ETL_INCREMENT_DEBUG_COUNT
-      insert_node(*position.p_node, *p_data_node);
+      ETL_INCREMENT_DEBUG_COUNT;
+      insert_node(*to_iterator(position).p_node, *p_data_node);
 
       return iterator(*p_data_node);
     }
@@ -1145,8 +1171,8 @@ namespace etl
 
       data_node_t* p_data_node = allocate_data_node();
       ::new (&(p_data_node->value)) T(value1, value2);
-      ETL_INCREMENT_DEBUG_COUNT
-      insert_node(*position.p_node, *p_data_node);
+      ETL_INCREMENT_DEBUG_COUNT;
+      insert_node(*to_iterator(position).p_node, *p_data_node);
 
       return iterator(*p_data_node);
     }
@@ -1159,8 +1185,8 @@ namespace etl
 
       data_node_t* p_data_node = allocate_data_node();
       ::new (&(p_data_node->value)) T(value1, value2, value3);
-      ETL_INCREMENT_DEBUG_COUNT
-      insert_node(*position.p_node, *p_data_node);
+      ETL_INCREMENT_DEBUG_COUNT;
+      insert_node(*to_iterator(position).p_node, *p_data_node);
 
       return iterator(*p_data_node);
     }
@@ -1173,8 +1199,8 @@ namespace etl
 
       data_node_t* p_data_node = allocate_data_node();
       ::new (&(p_data_node->value)) T(value1, value2, value3, value4);
-      ETL_INCREMENT_DEBUG_COUNT
-      insert_node(*position.p_node, *p_data_node);
+      ETL_INCREMENT_DEBUG_COUNT;
+      insert_node(*to_iterator(position).p_node, *p_data_node);
 
       return iterator(*p_data_node);
     }
@@ -1813,7 +1839,7 @@ namespace etl
           {
             ETL_ASSERT(p_node_pool != ETL_NULLPTR, ETL_ERROR(list_no_pool));
             p_node_pool->release_all();
-            ETL_RESET_DEBUG_COUNT;
+            ETL_RESET_DEBUG_COUNT;;
           }
           else
           {
@@ -1955,7 +1981,7 @@ namespace etl
 
       data_node_t* p_data_node = allocate_data_node();
       ::new (&(p_data_node->value)) T(value);
-      ETL_INCREMENT_DEBUG_COUNT
+      ETL_INCREMENT_DEBUG_COUNT;
 
       return *p_data_node;
     }
@@ -1970,7 +1996,7 @@ namespace etl
 
       data_node_t* p_data_node = allocate_data_node();
       ::new (&(p_data_node->value)) T(etl::move(value));
-      ETL_INCREMENT_DEBUG_COUNT
+      ETL_INCREMENT_DEBUG_COUNT;
 
         return *p_data_node;
     }
@@ -1993,7 +2019,7 @@ namespace etl
       ETL_ASSERT(p_node_pool != ETL_NULLPTR, ETL_ERROR(list_no_pool));
       node.value.~T();
       p_node_pool->release(&node);
-      ETL_DECREMENT_DEBUG_COUNT
+      ETL_DECREMENT_DEBUG_COUNT;
     }
 
     // Disable copy construction.
@@ -2186,7 +2212,7 @@ namespace etl
   template <typename... T>
   constexpr auto make_list(T... t) -> etl::list<typename etl::common_type_t<T...>, sizeof...(T)>
   {
-    return { { etl::forward<T>(t)... } };
+    return { etl::forward<T>(t)... };
   }
 #endif
 
