@@ -39,6 +39,7 @@ SOFTWARE.
 #include "timer.h"
 #include "atomic.h"
 #include "algorithm.h"
+#include "delegate.h"
 
 #include <stdint.h>
 
@@ -86,7 +87,7 @@ namespace etl
       : p_message(ETL_NULLPTR),
         p_router(ETL_NULLPTR),
         period(0),
-        delta(etl::timer::state::INACTIVE),
+        delta(etl::timer::state::Inactive),
         destination_router_id(etl::imessage_bus::ALL_MESSAGE_ROUTERS),
         id(etl::timer::id::NO_TIMER),
         previous(etl::timer::id::NO_TIMER),
@@ -105,7 +106,7 @@ namespace etl
       : p_message(&message_),
         p_router(&irouter_),
         period(period_),
-        delta(etl::timer::state::INACTIVE),
+        delta(etl::timer::state::Inactive),
         destination_router_id(destination_router_id_),
         id(id_),
         previous(etl::timer::id::NO_TIMER),
@@ -119,7 +120,7 @@ namespace etl
     //*******************************************
     bool is_active() const
     {
-      return delta != etl::timer::state::INACTIVE;
+      return delta != etl::timer::state::Inactive;
     }
 
     //*******************************************
@@ -127,7 +128,7 @@ namespace etl
     //*******************************************
     void set_inactive()
     {
-      delta = etl::timer::state::INACTIVE;
+      delta = etl::timer::state::Inactive;
     }
 
     const etl::imessage*     p_message;
@@ -271,7 +272,7 @@ namespace etl
 
         timer.previous = etl::timer::id::NO_TIMER;
         timer.next     = etl::timer::id::NO_TIMER;
-        timer.delta    = etl::timer::state::INACTIVE;
+        timer.delta    = etl::timer::state::Inactive;
       }
 
       //*******************************
@@ -280,6 +281,12 @@ namespace etl
         return ptimers[head];
       }
 
+      //*******************************
+      const etl::message_timer_data& front() const
+      {
+        return ptimers[head];
+      }
+
       //*******************************
       etl::timer::id::type begin()
       {
@@ -335,6 +342,8 @@ namespace etl
   {
   public:
 
+    typedef etl::delegate<void(etl::timer::id::type)> event_callback_type;
+
     //*******************************************
     /// Register a timer.
     //*******************************************
@@ -346,7 +355,7 @@ namespace etl
     {
       etl::timer::id::type id = etl::timer::id::NO_TIMER;
 
-      bool is_space = (registered_timers < MAX_TIMERS);
+      bool is_space = (registered_timers < Max_Timers);
 
       if (is_space)
       {
@@ -354,7 +363,7 @@ namespace etl
         if (!router_.is_null_router())
         {
           // Search for the free space.
-          for (uint_least8_t i = 0U; i < MAX_TIMERS; ++i)
+          for (uint_least8_t i = 0U; i < Max_Timers; ++i)
           {
             etl::message_timer_data& timer = timer_array[i];
 
@@ -390,6 +399,7 @@ namespace etl
           {
             ETL_DISABLE_TIMER_UPDATES;
             active_list.remove(timer.id, true);
+            remove_callback.call_if(timer.id);
             ETL_ENABLE_TIMER_UPDATES;
           }
 
@@ -429,7 +439,7 @@ namespace etl
       active_list.clear();
       ETL_ENABLE_TIMER_UPDATES;
 
-      for (int i = 0; i < MAX_TIMERS; ++i)
+      for (int i = 0; i < Max_Timers; ++i)
       {
         new (&timer_array[i]) message_timer_data();
       }
@@ -461,11 +471,13 @@ namespace etl
               count -= timer.delta;
 
               active_list.remove(timer.id, true);
+              remove_callback.call_if(timer.id);
 
               if (timer.repeating)
               {
                 timer.delta = timer.period;
                 active_list.insert(timer.id);
+                insert_callback.call_if(timer.id);
               }
 
               if (timer.p_router != ETL_NULLPTR)
@@ -506,16 +518,18 @@ namespace etl
         if (timer.id != etl::timer::id::NO_TIMER)
         {
           // Has a valid period.
-          if (timer.period != etl::timer::state::INACTIVE)
+          if (timer.period != etl::timer::state::Inactive)
           {
             ETL_DISABLE_TIMER_UPDATES;
             if (timer.is_active())
             {
               active_list.remove(timer.id, false);
+              remove_callback.call_if(timer.id);
             }
 
             timer.delta = immediate_ ? 0 : timer.period;
             active_list.insert(timer.id);
+            insert_callback.call_if(timer.id);
             ETL_ENABLE_TIMER_UPDATES;
 
             result = true;
@@ -545,6 +559,7 @@ namespace etl
           {
             ETL_DISABLE_TIMER_UPDATES;
             active_list.remove(timer.id, false);
+            remove_callback.call_if(timer.id);
             ETL_ENABLE_TIMER_UPDATES;
           }
 
@@ -583,12 +598,70 @@ namespace etl
       return false;
     }
 
+    //*******************************************
+    /// Check if there is an active timer.
+    //*******************************************
+    bool has_active_timer() const
+    {
+      ETL_DISABLE_TIMER_UPDATES;
+      bool result = !active_list.empty();
+      ETL_ENABLE_TIMER_UPDATES;
+
+      return result;
+    }
+
+    //*******************************************
+    /// Get the time to the next timer event.
+    /// Returns etl::timer::interval::No_Active_Interval if there is no active timer.
+    //*******************************************
+    uint32_t time_to_next() const
+    {
+      uint32_t delta = static_cast<uint32_t>(etl::timer::interval::No_Active_Interval);
+
+      ETL_DISABLE_TIMER_UPDATES;
+      if (!active_list.empty())
+      {        
+        delta = active_list.front().delta;
+      }
+      ETL_ENABLE_TIMER_UPDATES;
+
+      return delta;
+    }
+
+    //*******************************************
+    /// Set a callback when a timer is inserted on list
+    //*******************************************
+    void set_insert_callback(event_callback_type insert_)
+    {
+      insert_callback = insert_;
+    }
+
+    //*******************************************
+    /// Set a callback when a timer is removed from list
+    //*******************************************
+    void set_remove_callback(event_callback_type remove_)
+    {
+      remove_callback = remove_;
+    }
+
+    //*******************************************
+    void clear_insert_callback()
+    {
+      insert_callback.clear();
+    }
+
+    //*******************************************
+    void clear_remove_callback()
+    {
+      remove_callback.clear();
+    }
+
   protected:
 
     //*******************************************
     /// Constructor.
     //*******************************************
-    imessage_timer(message_timer_data* const timer_array_, const uint_least8_t  MAX_TIMERS_)
+    imessage_timer(message_timer_data* const timer_array_, const uint_least8_t  Max_Timers_)
       : timer_array(timer_array_),
         active_list(timer_array_),
         enabled(false),
@@ -596,7 +669,7 @@ namespace etl
         process_semaphore(0),
 #endif
         registered_timers(0),
-        MAX_TIMERS(MAX_TIMERS_)
+        Max_Timers(Max_Timers_)
     {
     }
 
@@ -629,36 +702,39 @@ namespace etl
   #endif
 #endif
 
-    etl::timer_semaphore_t process_semaphore;
+    mutable etl::timer_semaphore_t process_semaphore;
 #endif
     uint_least8_t registered_timers;
 
+    event_callback_type insert_callback;
+    event_callback_type remove_callback;
+
   public:
 
-    const uint_least8_t MAX_TIMERS;
+    const uint_least8_t Max_Timers;
   };
 
   //***************************************************************************
   /// The message timer
   //***************************************************************************
-  template <uint_least8_t MAX_TIMERS_>
+  template <uint_least8_t Max_Timers_>
   class message_timer : public etl::imessage_timer
   {
   public:
 
-    ETL_STATIC_ASSERT(MAX_TIMERS_ <= 254, "No more than 254 timers are allowed");
+    ETL_STATIC_ASSERT(Max_Timers_ <= 254, "No more than 254 timers are allowed");
 
     //*******************************************
     /// Constructor.
     //*******************************************
     message_timer()
-      : imessage_timer(timer_array, MAX_TIMERS_)
+      : imessage_timer(timer_array, Max_Timers_)
     {
     }
 
   private:
 
-    message_timer_data timer_array[MAX_TIMERS_];
+    message_timer_data timer_array[Max_Timers_];
   };
 }
 
