@@ -56,6 +56,8 @@ namespace etl
     typedef etl::delegate<void(void)> lock_type;
     typedef etl::delegate<void(void)> unlock_type;
 
+    typedef etl::delegate<void(etl::timer::id::type)> event_callback_type;
+
   public:
 
     //*******************************************
@@ -69,7 +71,7 @@ namespace etl
     {
       etl::timer::id::type id = etl::timer::id::NO_TIMER;
 
-      bool is_space = (number_of_registered_timers < MAX_TIMERS);
+      bool is_space = (number_of_registered_timers < Max_Timers);
 
       if (is_space)
       {
@@ -77,7 +79,7 @@ namespace etl
         if (!router_.is_null_router())
         {
           // Search for the free space.
-          for (uint_least8_t i = 0U; i < MAX_TIMERS; ++i)
+          for (uint_least8_t i = 0U; i < Max_Timers; ++i)
           {
             timer_data& timer = timer_array[i];
 
@@ -113,6 +115,7 @@ namespace etl
           {
             lock();
             active_list.remove(timer.id, true);
+            remove_callback.call_if(timer.id);
             unlock();
           }
 
@@ -152,7 +155,7 @@ namespace etl
       active_list.clear();
       unlock();
 
-      for (int i = 0; i < MAX_TIMERS; ++i)
+      for (int i = 0; i < Max_Timers; ++i)
       {
         new (&timer_array[i]) timer_data();
       }
@@ -184,6 +187,7 @@ namespace etl
               count -= timer.delta;
 
               active_list.remove(timer.id, true);
+              remove_callback.call_if(timer.id);
 
               if (timer.p_router != ETL_NULLPTR)
               {
@@ -194,6 +198,7 @@ namespace etl
               {
                 timer.delta = timer.period;
                 active_list.insert(timer.id);
+                insert_callback.call_if(timer.id);
               }
 
               has_active = !active_list.empty();
@@ -237,10 +242,12 @@ namespace etl
             if (timer.is_active())
             {
               active_list.remove(timer.id, false);
+              remove_callback.call_if(timer.id);
             }
 
             timer.delta = immediate_ ? 0 : timer.period;
             active_list.insert(timer.id);
+            insert_callback.call_if(timer.id);
             unlock();
 
             result = true;
@@ -270,6 +277,7 @@ namespace etl
           {
             lock();
             active_list.remove(timer.id, false);
+            remove_callback.call_if(timer.id);
             unlock();
           }
 
@@ -348,6 +356,34 @@ namespace etl
       return delta;
     }
 
+    //*******************************************
+    /// Set a callback when a timer is inserted on list
+    //*******************************************
+    void set_insert_callback(event_callback_type insert_)
+    {
+      insert_callback = insert_;
+    }
+
+    //*******************************************
+    /// Set a callback when a timer is removed from list
+    //*******************************************
+    void set_remove_callback(event_callback_type remove_)
+    {
+      remove_callback = remove_;
+    }
+
+    //*******************************************
+    void clear_insert_callback()
+    {
+      insert_callback.clear();
+    }
+
+    //*******************************************
+    void clear_remove_callback()
+    {
+      remove_callback.clear();
+    }
+
   protected:
 
     //*************************************************************************
@@ -423,12 +459,12 @@ namespace etl
     //*******************************************
     /// Constructor.
     //*******************************************
-    imessage_timer_locked(timer_data* const timer_array_, const uint_least8_t  MAX_TIMERS_)
+    imessage_timer_locked(timer_data* const timer_array_, const uint_least8_t  Max_Timers_)
       : timer_array(timer_array_)
       , active_list(timer_array_)
       , enabled(false)
       , number_of_registered_timers(0U)
-      , MAX_TIMERS(MAX_TIMERS_)
+      , Max_Timers(Max_Timers_)
     {
     }
 
@@ -638,20 +674,22 @@ namespace etl
     lock_type     lock;     ///< The callback that locks.
     unlock_type   unlock;   ///< The callback that unlocks.
 
+    event_callback_type insert_callback;
+    event_callback_type remove_callback;
   public:
 
-    const uint_least8_t MAX_TIMERS;
+    const uint_least8_t Max_Timers;
   };
 
   //***************************************************************************
   /// The message timer
   //***************************************************************************
-  template <uint_least8_t MAX_TIMERS_>
+  template <uint_least8_t Max_Timers_>
   class message_timer_locked : public etl::imessage_timer_locked
   {
   public:
 
-    ETL_STATIC_ASSERT(MAX_TIMERS_ <= 254, "No more than 254 timers are allowed");
+    ETL_STATIC_ASSERT(Max_Timers_ <= 254, "No more than 254 timers are allowed");
 
     typedef imessage_timer_locked::callback_type callback_type;
     typedef imessage_timer_locked::try_lock_type try_lock_type;
@@ -662,7 +700,7 @@ namespace etl
     /// Constructor.
     //*******************************************
     message_timer_locked()
-      : imessage_timer_locked(timer_array, MAX_TIMERS_)
+      : imessage_timer_locked(timer_array, Max_Timers_)
     {
     }
 
@@ -670,14 +708,14 @@ namespace etl
     /// Constructor.
     //*******************************************
     message_timer_locked(try_lock_type try_lock_, lock_type lock_, unlock_type unlock_)
-      : imessage_timer_locked(timer_array, MAX_TIMERS_)
+      : imessage_timer_locked(timer_array, Max_Timers_)
     {
       this->set_locks(try_lock_, lock_, unlock_);
     }
 
   private:
 
-    timer_data timer_array[MAX_TIMERS_];
+    timer_data timer_array[Max_Timers_];
   };
 }
 
