@@ -242,15 +242,25 @@ SOFTWARE.
 #endif
 
 //*************************************
-// Indicate if C++ exceptions are enabled.
+// Indicate if C++ exceptions within the ETL are enabled.
 #if defined(ETL_THROW_EXCEPTIONS)
-  #define ETL_USING_EXCEPTIONS 1
+  #define ETL_USING_EXCEPTIONS     1
   #define ETL_NOT_USING_EXCEPTIONS 0
 #else
-  #define ETL_USING_EXCEPTIONS 0
+  #define ETL_USING_EXCEPTIONS     0
   #define ETL_NOT_USING_EXCEPTIONS 1
 #endif
 
+//*************************************
+// Indicate if C++ exceptions are enabled for debug asserts.
+#if ETL_IS_DEBUG_BUILD && defined(ETL_DEBUG_THROW_EXCEPTIONS)
+  #define ETL_DEBUG_USING_EXCEPTIONS     1
+  #define ETL_DEBUG_NOT_USING_EXCEPTIONS 0
+#else
+  #define ETL_DEBUG_USING_EXCEPTIONS     0
+  #define ETL_DEBUG_NOT_USING_EXCEPTIONS 1
+#endif
+
 //*************************************
 // Indicate if nullptr is used.
 #if ETL_NO_NULLPTR_SUPPORT
@@ -315,6 +325,16 @@ SOFTWARE.
 #define ETL_HAS_CHRONO_LITERALS_DURATION 1
 #endif
 
+//*************************************
+// Indicate if noexcept is part of the function type.
+#if !defined(ETL_HAS_NOEXCEPT_FUNCTION_TYPE)
+  #if defined(__cpp_noexcept_function_type) && (__cpp_noexcept_function_type >= 201510)
+    #define ETL_HAS_NOEXCEPT_FUNCTION_TYPE 1
+  #else
+    #define ETL_HAS_NOEXCEPT_FUNCTION_TYPE 0
+  #endif
+#endif
+
 //*************************************
 // The macros below are dependent on the profile.
 // C++11
@@ -331,13 +351,14 @@ SOFTWARE.
   #define ETL_ENUM_CLASS(name)            enum class name
   #define ETL_ENUM_CLASS_TYPE(name, type) enum class name : type
   #define ETL_LVALUE_REF_QUALIFIER        &
-
   #if ETL_USING_EXCEPTIONS
-    #define ETL_NOEXCEPT           noexcept
-    #define ETL_NOEXCEPT_EXPR(...) noexcept(__VA_ARGS__)
+    #define ETL_NOEXCEPT                  noexcept
+    #define ETL_NOEXCEPT_EXPR(...)        noexcept(__VA_ARGS__)
+    #define ETL_NOEXCEPT_FROM(x)          noexcept(noexcept(x))
   #else
     #define ETL_NOEXCEPT
     #define ETL_NOEXCEPT_EXPR(...)
+    #define ETL_NOEXCEPT_FROM(x) 
   #endif
 #else
   #define ETL_CONSTEXPR
@@ -350,6 +371,7 @@ SOFTWARE.
   #define ETL_NORETURN
   #define ETL_NOEXCEPT
   #define ETL_NOEXCEPT_EXPR(...)
+  #define ETL_NOEXCEPT_FROM(x) 
   #define ETL_MOVE(x) x
   #define ETL_ENUM_CLASS(name)            enum name
   #define ETL_ENUM_CLASS_TYPE(name, type) enum name
@@ -463,6 +485,14 @@ SOFTWARE.
 
 //*************************************
 // Determine if the ETL can use libc's wchar.h
+#if !defined(ETL_NO_LIBC_WCHAR_H)
+  #if defined(__has_include)
+    #if !__has_include(<wchar.h>)
+        #define ETL_NO_LIBC_WCHAR_H
+    #endif
+  #endif
+#endif
+
 #if defined(ETL_NO_LIBC_WCHAR_H)
   #define ETL_USING_LIBC_WCHAR_H     0
   #define ETL_NOT_USING_LIBC_WCHAR_H 1
@@ -471,6 +501,24 @@ SOFTWARE.
   #define ETL_NOT_USING_LIBC_WCHAR_H 0
 #endif
 
+//*************************************
+// Determine if the ETL can use STL ostream
+#if !defined(ETL_NO_STD_OSTREAM) && ETL_USING_STL
+  #if defined(__has_include)
+    #if !__has_include(<ostream>)
+      #define ETL_NO_STD_OSTREAM
+    #endif
+  #endif
+#endif
+
+#if defined(ETL_NO_STD_OSTREAM) || (ETL_NOT_USING_STL && !defined(ETL_IN_UNIT_TEST))
+  #define ETL_USING_STD_OSTREAM     0
+  #define ETL_NOT_USING_STD_OSTREAM 1
+#else
+  #define ETL_USING_STD_OSTREAM     1
+  #define ETL_NOT_USING_STD_OSTREAM 0
+#endif
+
 //*************************************
 // Determine if the ETL should support atomics.
 #if defined(ETL_NO_ATOMICS) || \
@@ -478,6 +526,7 @@ SOFTWARE.
     defined(ETL_TARGET_DEVICE_ARM_CORTEX_M0_PLUS) || \
     defined(__STDC_NO_ATOMICS__)
   #define ETL_HAS_ATOMIC 0
+  #define ETL_HAS_ATOMIC_ALWAYS_LOCK_FREE 0
 #else
   #if ((ETL_USING_CPP11 && (ETL_USING_STL || defined(ETL_IN_UNIT_TEST))) || \
         defined(ETL_COMPILER_ARM5)  || \
@@ -613,6 +662,7 @@ namespace etl
     static ETL_CONSTANT bool has_chrono_literals_microseconds = (ETL_HAS_CHRONO_LITERALS_DURATION == 1);
     static ETL_CONSTANT bool has_chrono_literals_nanoseconds  = (ETL_HAS_CHRONO_LITERALS_DURATION == 1);
     static ETL_CONSTANT bool has_std_byteswap                 = (ETL_HAS_STD_BYTESWAP == 1);
+    static ETL_CONSTANT bool has_noexcept_function_type       = (ETL_HAS_NOEXCEPT_FUNCTION_TYPE == 1);
 
     // Is...
     static ETL_CONSTANT bool is_debug_build                   = (ETL_IS_DEBUG_BUILD == 1);
