@@ -46,23 +46,23 @@ namespace etl
     namespace private_chrono
     {
       // Helper to find the greatest common divisor
-      template <intmax_t A, intmax_t B>
+      template <intmax_t Value1, intmax_t Value2>
       struct gcd 
       {
-        static ETL_CONSTANT intmax_t value = gcd<B, A % B>::value;
+        static ETL_CONSTANT intmax_t value = gcd<Value2, Value1 % Value2>::value;
       };
 
-      template <intmax_t A>
-      struct gcd<A, 0> 
+      template <intmax_t Value1>
+      struct gcd<Value1, 0> 
       {
-        static ETL_CONSTANT intmax_t value = A;
+        static ETL_CONSTANT intmax_t value = Value1;
       };
 
       // Helper to find the least common multiple
-      template <intmax_t A, intmax_t B>
+      template <intmax_t Value1, intmax_t Value2>
       struct lcm 
       {
-        static ETL_CONSTANT intmax_t value = (A / gcd<A, B>::value) * B;
+        static ETL_CONSTANT intmax_t value = (Value1 / gcd<Value1, Value2>::value) * Value2;
       };
     }
 
