@@ -55,6 +55,20 @@ SOFTWARE.
 
 namespace etl
 {
+  template <typename T> struct is_std_array : etl::false_type {};
+#if ETL_USING_STL && ETL_USING_CPP11
+  template <typename T, size_t N> struct is_std_array<std::array<T, N>> : etl::true_type {};
+#endif
+  template <typename T> struct is_std_array<const T> : is_std_array<T> {};
+  template <typename T> struct is_std_array<volatile T> : is_std_array<T> {};
+  template <typename T> struct is_std_array<const volatile T> : is_std_array<T> {};
+
+  template <typename T> struct is_etl_array : etl::false_type {};
+  template <typename T, size_t N> struct is_etl_array<etl::array<T, N> > : etl::true_type {};
+  template <typename T> struct is_etl_array<const T> : is_etl_array<T> {};
+  template <typename T> struct is_etl_array<volatile T> : is_etl_array<T> {};
+  template <typename T> struct is_etl_array<const volatile T> : is_etl_array<T> {};
+
   //***************************************************************************
   // Tag to indicate a class is a span.
   //***************************************************************************
@@ -102,6 +116,20 @@ namespace etl
     }
   };
 
+  //***************************************************************************
+  ///\ingroup span
+  /// The out of range exceptions.
+  //***************************************************************************
+  class span_out_of_range : public span_exception
+  {
+  public:
+
+    span_out_of_range(string_type file_name_, numeric_type line_number_)
+      : span_exception(ETL_ERROR_TEXT("span:range", ETL_SPAN_FILE_ID"C"), file_name_, line_number_)
+    {
+    }
+  };
+
   //***************************************************************************
   /// Span - Fixed Extent
   //***************************************************************************
@@ -141,7 +169,7 @@ namespace etl
     /// Construct from iterators
     //*************************************************************************
     template <typename TIterator>
-    ETL_CONSTEXPR explicit span(const TIterator begin_, const TIterator /*end_*/)
+    ETL_CONSTEXPR explicit span(const TIterator begin_, const TIterator /*end_*/) ETL_NOEXCEPT
       : pbegin(etl::to_address(begin_))
     {
     }
@@ -172,8 +200,10 @@ namespace etl
     /// data() and size() member functions.
     //*************************************************************************
     template <typename TContainer, typename = typename etl::enable_if<!etl::is_base_of<span_tag, etl::remove_reference_t<TContainer>>::value &&
+                                                                      !etl::is_std_array<etl::remove_reference_t<TContainer>>::value &&
+                                                                      !etl::is_etl_array<etl::remove_reference_t<TContainer>>::value &&
                                                                       !etl::is_pointer<etl::remove_reference_t<TContainer>>::value &&
-                                                                      !etl::is_array<etl::remove_reference_t<TContainer>>::value&&
+                                                                      !etl::is_array<etl::remove_reference_t<TContainer>>::value &&
                                                                       etl::is_same<etl::remove_cv_t<T>, etl::remove_cv_t<typename etl::remove_reference_t<TContainer>::value_type>>::value, void>::type>
     ETL_CONSTEXPR span(TContainer&& a) ETL_NOEXCEPT
       : pbegin(a.data())
@@ -186,6 +216,8 @@ namespace etl
     //*************************************************************************
     template <typename TContainer>
     span(TContainer& a, typename etl::enable_if<!etl::is_base_of<span_tag, typename etl::remove_reference<TContainer>::type>::value &&
+                                                !etl::is_std_array<typename etl::remove_reference<TContainer>::type>::value &&
+                                                !etl::is_etl_array<typename etl::remove_reference<TContainer>::type>::value &&
                                                 !etl::is_pointer<typename etl::remove_reference<TContainer>::type>::value &&
                                                 !etl::is_array<TContainer>::value &&
                                                 etl::is_same<typename etl::remove_cv<T>::type, typename etl::remove_cv<typename etl::remove_reference<TContainer>::type::value_type>::type>::value, void>::type* = 0) ETL_NOEXCEPT
@@ -199,6 +231,8 @@ namespace etl
     //*************************************************************************
     template <typename TContainer>
     span(const TContainer& a, typename etl::enable_if<!etl::is_base_of<span_tag, typename etl::remove_reference<TContainer>::type>::value &&
+                                                      !etl::is_std_array<typename etl::remove_reference<TContainer>::type>::value &&
+                                                      !etl::is_etl_array<typename etl::remove_reference<TContainer>::type>::value &&
                                                       !etl::is_pointer<typename etl::remove_reference<TContainer>::type>::value &&
                                                       !etl::is_array<TContainer>::value&&
                                                       etl::is_same<typename etl::remove_cv<T>::type, typename etl::remove_cv<typename etl::remove_reference<TContainer>::type::value_type>::type>::value, void>::type* = 0) ETL_NOEXCEPT
@@ -219,8 +253,8 @@ namespace etl
     /// Copy constructor
     /// From fixed extent span.
     //*************************************************************************
-    template <typename U, size_t N>
-    ETL_CONSTEXPR span(const etl::span<U, N>& other, typename etl::enable_if<N == Extent, void>::type* = 0) ETL_NOEXCEPT
+    template <typename U, size_t Size>
+    ETL_CONSTEXPR span(const etl::span<U, Size>& other, typename etl::enable_if<Size == Extent, void>::type* = 0) ETL_NOEXCEPT
       : pbegin(other.data())
     {
     }
@@ -229,18 +263,58 @@ namespace etl
     /// Copy constructor
     /// From dynamic extent span.
     //*************************************************************************
-    template <typename U, size_t N>
-    ETL_CONSTEXPR14 span(const etl::span<U, N>& other, typename etl::enable_if<N == etl::dynamic_extent, void>::type* = 0)
+    template <typename U, size_t Size>
+    ETL_CONSTEXPR14 span(const etl::span<U, Size>& other, typename etl::enable_if<Size == etl::dynamic_extent, void>::type* = 0)
       : pbegin(other.data())
     {
       ETL_ASSERT(other.size() == Extent, ETL_ERROR(span_size_mismatch));
     }
 
+#if ETL_USING_STL && ETL_USING_CPP11
+    //*************************************************************************
+    /// Constructor from std array.
+    //*************************************************************************
+    template <typename U, size_t Size>
+    ETL_CONSTEXPR span(std::array<U, Size>& other, typename etl::enable_if<Size == Extent, void>::type* = 0) ETL_NOEXCEPT
+      : pbegin(other.data())
+    {
+    }
+
+    //*************************************************************************
+    /// Constructor from const std array.
+    //*************************************************************************
+    template <typename U, size_t Size>
+    ETL_CONSTEXPR span(const std::array<U, Size>& other, typename etl::enable_if<Size == Extent && etl::is_const<T>::value, void>::type* = 0) ETL_NOEXCEPT
+      : pbegin(other.data())
+    {
+    }
+#endif
+
+    //*************************************************************************
+    /// Constructor from etl array.
+    //*************************************************************************
+    template <typename U, size_t Size>
+    ETL_CONSTEXPR span(etl::array<U, Size>& other, typename etl::enable_if<Size == Extent, void>::type* = 0) ETL_NOEXCEPT
+      : pbegin(other.data())
+    {
+    }
+
+    //*************************************************************************
+    /// Constructor from const etl array.
+    //*************************************************************************
+    template <typename U, size_t Size>
+    ETL_CONSTEXPR span(const etl::array<U, Size>& other, typename etl::enable_if<Size == Extent && etl::is_const<T>::value, void>::type* = 0) ETL_NOEXCEPT
+      : pbegin(other.data())
+    {
+    }
+
     //*************************************************************************
     /// Returns a reference to the first element.
     //*************************************************************************
     ETL_NODISCARD ETL_CONSTEXPR reference front() const ETL_NOEXCEPT
     {
+      ETL_STATIC_ASSERT(Extent > 0, "Span is empty");
+
       return *pbegin;
     }
 
@@ -249,6 +323,8 @@ namespace etl
     //*************************************************************************
     ETL_NODISCARD ETL_CONSTEXPR reference back() const ETL_NOEXCEPT
     {
+      ETL_STATIC_ASSERT(Extent > 0, "Span is empty");
+
       return *((pbegin + Extent) - 1);
     }
 
@@ -386,7 +462,7 @@ namespace etl
     //*************************************************************************
     ETL_NODISCARD ETL_CONSTEXPR14 reference at(size_t i)
     {
-      ETL_ASSERT(i < size(), ETL_ERROR(array_out_of_range));
+      ETL_ASSERT(i < size(), ETL_ERROR(span_out_of_range));
 
       return pbegin[i];
     }
@@ -396,7 +472,7 @@ namespace etl
     //*************************************************************************
     ETL_NODISCARD ETL_CONSTEXPR14 const_reference at(size_t i) const
     {
-      ETL_ASSERT(i < size(), ETL_ERROR(array_out_of_range));
+      ETL_ASSERT(i < size(), ETL_ERROR(span_out_of_range));
 
       return pbegin[i];
     }
@@ -406,7 +482,13 @@ namespace etl
     //*************************************************************************
     ETL_CONSTEXPR reference operator[](const size_t i) const
     {
+#if ETL_USING_CPP11 && ETL_NOT_USING_CPP14 && ETL_USING_EXCEPTIONS && ETL_CHECKING_INDEX_OPERATOR
+      return i < size() ? pbegin[i] : throw(ETL_ERROR(span_out_of_range));
+#else
+      ETL_ASSERT_CHECK_INDEX_OPERATOR(i < size(), ETL_ERROR(span_out_of_range));
+
       return pbegin[i];
+#endif
     }
 
     //*************************************************************************
@@ -416,7 +498,7 @@ namespace etl
     ETL_NODISCARD ETL_CONSTEXPR etl::span<element_type, COUNT> first() const ETL_NOEXCEPT
     {
       // If Extent is static, check that original span contains at least COUNT elements
-      ETL_STATIC_ASSERT((Extent != etl::dynamic_extent) ? COUNT <= Extent : true, "Original span does not contain COUNT elements");
+      ETL_STATIC_ASSERT(COUNT <= Extent, "Original span does not contain COUNT elements");
 
       return etl::span<element_type, COUNT>(pbegin, pbegin + COUNT);
     }
@@ -424,9 +506,15 @@ namespace etl
     //*************************************************************************
     /// Obtains a span that is a view over the first count elements of this span.
     //*************************************************************************
-    ETL_NODISCARD ETL_CONSTEXPR etl::span<element_type, etl::dynamic_extent> first(size_t count) const ETL_NOEXCEPT
+    ETL_NODISCARD ETL_CONSTEXPR etl::span<element_type, etl::dynamic_extent> first(size_t count) const ETL_NOEXCEPT_EXPR(ETL_NOT_USING_EXCEPTIONS || ETL_NOT_CHECKING_EXTRA)
     {
+#if ETL_USING_CPP11 && ETL_NOT_USING_CPP14 && ETL_USING_EXCEPTIONS && ETL_CHECKING_EXTRA
+      return count <= size() ? etl::span<element_type, etl::dynamic_extent>(pbegin, pbegin + count) : throw(ETL_ERROR(span_out_of_range));
+#else
+      ETL_ASSERT_CHECK_EXTRA(count <= size(), ETL_ERROR(span_out_of_range));
+      
       return etl::span<element_type, etl::dynamic_extent>(pbegin, pbegin + count);
+#endif
     }
 
     //*************************************************************************
@@ -436,7 +524,7 @@ namespace etl
     ETL_NODISCARD ETL_CONSTEXPR etl::span<element_type, COUNT> last() const ETL_NOEXCEPT
     {
       // If Extent is static, check that original span contains at least COUNT elements
-      ETL_STATIC_ASSERT((Extent != etl::dynamic_extent) ? COUNT <= Extent : true, "Original span does not contain COUNT elements");
+      ETL_STATIC_ASSERT(COUNT <= Extent, "Original span does not contain COUNT elements");
 
       return etl::span<element_type, COUNT>(pbegin + Extent - COUNT, (pbegin + Extent));
     }
@@ -444,9 +532,17 @@ namespace etl
     //*************************************************************************
     /// Obtains a span that is a view over the last count elements of this span.
     //*************************************************************************
-    ETL_NODISCARD ETL_CONSTEXPR etl::span<element_type, etl::dynamic_extent> last(size_t count) const ETL_NOEXCEPT
+    ETL_NODISCARD ETL_CONSTEXPR etl::span<element_type, etl::dynamic_extent> last(size_t count) const ETL_NOEXCEPT_EXPR(ETL_NOT_USING_EXCEPTIONS || ETL_NOT_CHECKING_EXTRA)
     {
+#if ETL_USING_CPP11 && ETL_NOT_USING_CPP14 && ETL_USING_EXCEPTIONS && ETL_CHECKING_EXTRA
+      return count <= size() ? 
+        etl::span<element_type, etl::dynamic_extent>((pbegin + Extent) - count, (pbegin + Extent)) : 
+        throw(ETL_ERROR(span_out_of_range));
+#else
+      ETL_ASSERT_CHECK_EXTRA(count <= size(), ETL_ERROR(span_out_of_range));
+
       return etl::span<element_type, etl::dynamic_extent>((pbegin + Extent) - count, (pbegin + Extent));
+#endif
     }
 
 #if ETL_USING_CPP11
@@ -458,10 +554,10 @@ namespace etl
       etl::span<element_type, COUNT != etl::dynamic_extent ? COUNT : Extent - OFFSET> subspan() const ETL_NOEXCEPT
     {
       // If Extent is static, check that OFFSET is within the original span
-      ETL_STATIC_ASSERT((Extent != etl::dynamic_extent) ? OFFSET <= Extent : true, "OFFSET is not within the original span");
+      ETL_STATIC_ASSERT(OFFSET <= Extent, "OFFSET is not within the original span");
 
       // If count is also static, check that OFFSET + COUNT is within the original span
-      ETL_STATIC_ASSERT((Extent != etl::dynamic_extent) && (COUNT != etl::dynamic_extent) ? COUNT <= (Extent - OFFSET) : true, "OFFSET + COUNT is not within the original span");
+      ETL_STATIC_ASSERT((COUNT != etl::dynamic_extent) ? COUNT <= (Extent - OFFSET) : true, "OFFSET + COUNT is not within the original span");
 
       return (COUNT == etl::dynamic_extent) ? etl::span<element_type, COUNT != etl::dynamic_extent ? COUNT : Extent - OFFSET>(pbegin + OFFSET, (pbegin + Extent))
                                             : etl::span<element_type, COUNT != etl::dynamic_extent ? COUNT : Extent - OFFSET>(pbegin + OFFSET, pbegin + OFFSET + COUNT);
@@ -474,10 +570,10 @@ namespace etl
     etl::span<element_type, COUNT != etl::dynamic_extent ? COUNT : Extent - OFFSET> subspan() const
     {
       // If Extent is static, check that OFFSET is within the original span
-      ETL_STATIC_ASSERT((Extent != etl::dynamic_extent) ? OFFSET <= Extent : true, "OFFSET is not within the original span");
+      ETL_STATIC_ASSERT(OFFSET <= Extent, "OFFSET is not within the original span");
 
       // If count is also static, check that OFFSET + COUNT is within the original span
-      ETL_STATIC_ASSERT((Extent != etl::dynamic_extent) && (COUNT != etl::dynamic_extent) ? COUNT <= (Extent - OFFSET) : true, "OFFSET + COUNT is not within the original span");
+      ETL_STATIC_ASSERT((COUNT != etl::dynamic_extent) ? COUNT <= (Extent - OFFSET) : true, "OFFSET + COUNT is not within the original span");
 
       if (COUNT == etl::dynamic_extent)
       {
@@ -493,10 +589,20 @@ namespace etl
     //*************************************************************************
     /// Obtains a span that is a view from 'offset' over the next 'count' elements of this span.
     //*************************************************************************
-    ETL_NODISCARD ETL_CONSTEXPR etl::span<element_type, etl::dynamic_extent> subspan(size_t offset, size_t count = etl::dynamic_extent) const ETL_NOEXCEPT
+    ETL_NODISCARD ETL_CONSTEXPR etl::span<element_type, etl::dynamic_extent> subspan(size_t offset, size_t count = etl::dynamic_extent) const ETL_NOEXCEPT_EXPR(ETL_NOT_USING_EXCEPTIONS || ETL_NOT_CHECKING_EXTRA)
     {
+#if ETL_USING_CPP11 && ETL_NOT_USING_CPP14 && ETL_USING_EXCEPTIONS && ETL_CHECKING_EXTRA
+      return (offset <= size()) && (count != etl::dynamic_extent ? count <= (size() - offset) : true) ?
+        ((count == etl::dynamic_extent) ? etl::span<element_type, etl::dynamic_extent>(pbegin + offset, (pbegin + Extent))
+                                        : etl::span<element_type, etl::dynamic_extent>(pbegin + offset, pbegin + offset + count)) :
+        throw(ETL_ERROR(span_out_of_range));
+#else
+      ETL_ASSERT_CHECK_EXTRA(offset <= size(), ETL_ERROR(span_out_of_range));
+      ETL_ASSERT_CHECK_EXTRA(count != etl::dynamic_extent ? count <= (size() - offset) : true, ETL_ERROR(span_out_of_range));
+
       return (count == etl::dynamic_extent) ? etl::span<element_type, etl::dynamic_extent>(pbegin + offset, (pbegin + Extent))
                                             : etl::span<element_type, etl::dynamic_extent>(pbegin + offset, pbegin + offset + count);
+#endif
     }
 
     //*************************************************************************
@@ -513,11 +619,11 @@ namespace etl
     /// Reinterpret the span as a span with different element type.
     //*************************************************************************
     template<typename TNew>
-    ETL_NODISCARD ETL_CONSTEXPR14 etl::span<TNew, etl::dynamic_extent> reinterpret_as() const
+    ETL_NODISCARD ETL_CONSTEXPR14 etl::span<TNew, Extent * sizeof(element_type) / sizeof(TNew)> reinterpret_as() const
     {
       ETL_ASSERT(etl::is_aligned<etl::alignment_of<TNew>::value>(pbegin), ETL_ERROR(span_alignment_exception));
 
-      return etl::span<TNew, etl::dynamic_extent>(reinterpret_cast<TNew*>(pbegin),
+      return etl::span<TNew, Extent * sizeof(element_type) / sizeof(TNew)>(reinterpret_cast<TNew*>(pbegin),
                        Extent * sizeof(element_type) / sizeof(TNew));
     }
 
@@ -585,7 +691,7 @@ namespace etl
     /// Construct from iterators
     //*************************************************************************
     template <typename TIterator>
-    ETL_CONSTEXPR span(const TIterator begin_, const TIterator end_)
+    ETL_CONSTEXPR span(const TIterator begin_, const TIterator end_) ETL_NOEXCEPT
       : pbegin(etl::to_address(begin_))
       , pend(etl::to_address(begin_) + etl::distance(begin_, end_))
     {
@@ -657,8 +763,8 @@ namespace etl
     //*************************************************************************
     /// Copy constructor
     //*************************************************************************
-    template <typename U, size_t N>
-    ETL_CONSTEXPR span(const etl::span<U, N>& other) ETL_NOEXCEPT
+    template <typename U, size_t Size>
+    ETL_CONSTEXPR span(const etl::span<U, Size>& other) ETL_NOEXCEPT
       : pbegin(other.data())
       , pend(other.data() + other.size())
     {
@@ -667,17 +773,29 @@ namespace etl
     //*************************************************************************
     /// Returns a reference to the first element.
     //*************************************************************************
-    ETL_NODISCARD ETL_CONSTEXPR reference front() const ETL_NOEXCEPT
+    ETL_NODISCARD ETL_CONSTEXPR reference front() const ETL_NOEXCEPT_EXPR(ETL_NOT_USING_EXCEPTIONS || ETL_NOT_CHECKING_EXTRA)
     {
+#if ETL_USING_CPP11 && ETL_NOT_USING_CPP14 && ETL_USING_EXCEPTIONS && ETL_CHECKING_EXTRA
+      return size() > 0 ? *pbegin : throw(ETL_ERROR(span_out_of_range));
+#else
+      ETL_ASSERT_CHECK_EXTRA(size() > 0, ETL_ERROR(span_out_of_range));
+
       return *pbegin;
+#endif
     }
 
     //*************************************************************************
     /// Returns a reference to the last element.
     //*************************************************************************
-    ETL_NODISCARD ETL_CONSTEXPR reference back() const ETL_NOEXCEPT
+    ETL_NODISCARD ETL_CONSTEXPR reference back() const ETL_NOEXCEPT_EXPR(ETL_NOT_USING_EXCEPTIONS || ETL_NOT_CHECKING_EXTRA)
     {
+#if ETL_USING_CPP11 && ETL_NOT_USING_CPP14 && ETL_USING_EXCEPTIONS && ETL_CHECKING_EXTRA
+      return size() > 0 ? *(pend - 1) : throw(ETL_ERROR(span_out_of_range));
+#else
+      ETL_ASSERT_CHECK_EXTRA(size() > 0, ETL_ERROR(span_out_of_range));
+
       return *(pend - 1);
+#endif
     }
 
     //*************************************************************************
@@ -815,7 +933,7 @@ namespace etl
     //*************************************************************************
     ETL_NODISCARD ETL_CONSTEXPR14 reference at(size_t i)
     {
-      ETL_ASSERT(i < size(), ETL_ERROR(array_out_of_range));
+      ETL_ASSERT(i < size(), ETL_ERROR(span_out_of_range));
 
       return pbegin[i];
     }
@@ -825,7 +943,7 @@ namespace etl
     //*************************************************************************
     ETL_NODISCARD ETL_CONSTEXPR14 const_reference at(size_t i) const
     {
-      ETL_ASSERT(i < size(), ETL_ERROR(array_out_of_range));
+      ETL_ASSERT(i < size(), ETL_ERROR(span_out_of_range));
 
       return pbegin[i];
     }
@@ -835,41 +953,71 @@ namespace etl
     //*************************************************************************
     ETL_CONSTEXPR reference operator[](const size_t i) const
     {
+#if ETL_USING_CPP11 && ETL_NOT_USING_CPP14 && ETL_USING_EXCEPTIONS && ETL_CHECKING_INDEX_OPERATOR
+      return i < size() ? pbegin[i] : throw(ETL_ERROR(span_out_of_range));
+#else
+      ETL_ASSERT_CHECK_INDEX_OPERATOR(i < size(), ETL_ERROR(span_out_of_range));
+
       return pbegin[i];
+#endif
     }
 
     //*************************************************************************
     /// Obtains a span that is a view over the first COUNT elements of this span.
     //*************************************************************************
     template <size_t COUNT>
-    ETL_NODISCARD ETL_CONSTEXPR etl::span<element_type, COUNT> first() const ETL_NOEXCEPT
+    ETL_NODISCARD ETL_CONSTEXPR etl::span<element_type, COUNT> first() const ETL_NOEXCEPT_EXPR(ETL_NOT_USING_EXCEPTIONS || ETL_NOT_CHECKING_EXTRA)
     {
+#if ETL_USING_CPP11 && ETL_NOT_USING_CPP14 && ETL_USING_EXCEPTIONS && ETL_CHECKING_EXTRA
+      return COUNT <= size() ? etl::span<element_type, COUNT>(pbegin, pbegin + COUNT) : throw(ETL_ERROR(span_out_of_range));
+#else
+      ETL_ASSERT_CHECK_EXTRA(COUNT <= size(), ETL_ERROR(span_out_of_range));
+
       return etl::span<element_type, COUNT>(pbegin, pbegin + COUNT);
+#endif
     }
 
     //*************************************************************************
     /// Obtains a span that is a view over the first count elements of this span.
     //*************************************************************************
-    ETL_NODISCARD ETL_CONSTEXPR etl::span<element_type, etl::dynamic_extent> first(size_t count) const ETL_NOEXCEPT
+    ETL_NODISCARD ETL_CONSTEXPR etl::span<element_type, etl::dynamic_extent> first(size_t count) const ETL_NOEXCEPT_EXPR(ETL_NOT_USING_EXCEPTIONS || ETL_NOT_CHECKING_EXTRA)
     {
+#if ETL_USING_CPP11 && ETL_NOT_USING_CPP14 && ETL_USING_EXCEPTIONS && ETL_CHECKING_EXTRA
+      return count <= size() ? etl::span<element_type, etl::dynamic_extent>(pbegin, pbegin + count) : throw(ETL_ERROR(span_out_of_range));
+#else
+      ETL_ASSERT_CHECK_EXTRA(count <= size(), ETL_ERROR(span_out_of_range));
+
       return etl::span<element_type, etl::dynamic_extent>(pbegin, pbegin + count);
+#endif
     }
 
     //*************************************************************************
     /// Obtains a span that is a view over the last COUNT elements of this span.
     //*************************************************************************
     template <size_t COUNT>
-    ETL_NODISCARD ETL_CONSTEXPR etl::span<element_type, COUNT> last() const ETL_NOEXCEPT
+    ETL_NODISCARD ETL_CONSTEXPR etl::span<element_type, COUNT> last() const ETL_NOEXCEPT_EXPR(ETL_NOT_USING_EXCEPTIONS || ETL_NOT_CHECKING_EXTRA)
     {
+#if ETL_USING_CPP11 && ETL_NOT_USING_CPP14 && ETL_USING_EXCEPTIONS && ETL_CHECKING_EXTRA
+      return COUNT <= size() ? etl::span<element_type, COUNT>(pend - COUNT, pend) : throw(ETL_ERROR(span_out_of_range));
+#else
+      ETL_ASSERT_CHECK_EXTRA(COUNT <= size(), ETL_ERROR(span_out_of_range));
+
       return etl::span<element_type, COUNT>(pend - COUNT, pend);
+#endif
     }
 
     //*************************************************************************
     /// Obtains a span that is a view over the last count elements of this span.
     //*************************************************************************
-    ETL_NODISCARD ETL_CONSTEXPR etl::span<element_type, etl::dynamic_extent> last(size_t count) const ETL_NOEXCEPT
+    ETL_NODISCARD ETL_CONSTEXPR etl::span<element_type, etl::dynamic_extent> last(size_t count) const ETL_NOEXCEPT_EXPR(ETL_NOT_USING_EXCEPTIONS || ETL_NOT_CHECKING_EXTRA)
     {
+#if ETL_USING_CPP11 && ETL_NOT_USING_CPP14 && ETL_USING_EXCEPTIONS && ETL_CHECKING_EXTRA
+      return count <= size() ? etl::span<element_type, etl::dynamic_extent>(pend - count, pend) : throw(ETL_ERROR(span_out_of_range));
+#else
+      ETL_ASSERT_CHECK_EXTRA(count <= size(), ETL_ERROR(span_out_of_range));
+
       return etl::span<element_type, etl::dynamic_extent>(pend - count, pend);
+#endif
     }
 
 #if ETL_USING_CPP11
@@ -878,10 +1026,20 @@ namespace etl
     //*************************************************************************
     template <size_t OFFSET, size_t COUNT = etl::dynamic_extent>
     ETL_NODISCARD ETL_CONSTEXPR
-      etl::span<element_type, COUNT != etl::dynamic_extent ? COUNT : etl::dynamic_extent> subspan() const ETL_NOEXCEPT
+      etl::span<element_type, COUNT != etl::dynamic_extent ? COUNT : etl::dynamic_extent> subspan() const ETL_NOEXCEPT_EXPR(ETL_NOT_USING_EXCEPTIONS || ETL_NOT_CHECKING_EXTRA)
     {
+#if ETL_USING_CPP11 && ETL_NOT_USING_CPP14 && ETL_USING_EXCEPTIONS && ETL_CHECKING_EXTRA
+      return (OFFSET <= size()) && (COUNT != etl::dynamic_extent ? COUNT <= (size() - OFFSET) : true) ?
+        ((COUNT == etl::dynamic_extent) ? etl::span<element_type, COUNT != etl::dynamic_extent ? COUNT : etl::dynamic_extent>(pbegin + OFFSET, pend)
+                                        : etl::span<element_type, COUNT != etl::dynamic_extent ? COUNT : etl::dynamic_extent>(pbegin + OFFSET, pbegin + OFFSET + COUNT)) :
+        throw(ETL_ERROR(span_out_of_range));
+#else
+      ETL_ASSERT_CHECK_EXTRA(OFFSET <= size(), ETL_ERROR(span_out_of_range));
+      ETL_ASSERT_CHECK_EXTRA(COUNT != etl::dynamic_extent ? COUNT <= (size() - OFFSET) : true, ETL_ERROR(span_out_of_range));
+
       return (COUNT == etl::dynamic_extent) ? etl::span<element_type, COUNT != etl::dynamic_extent ? COUNT : etl::dynamic_extent>(pbegin + OFFSET, pend)
                                             : etl::span<element_type, COUNT != etl::dynamic_extent ? COUNT : etl::dynamic_extent>(pbegin + OFFSET, pbegin + OFFSET + COUNT);
+#endif
     }
 #else
     //*************************************************************************
@@ -890,6 +1048,9 @@ namespace etl
     template <size_t OFFSET, size_t COUNT>
     etl::span<element_type, COUNT != etl::dynamic_extent ? COUNT : etl::dynamic_extent> subspan() const
     {
+      ETL_ASSERT_CHECK_EXTRA(OFFSET <= size(), ETL_ERROR(span_out_of_range));
+      ETL_ASSERT_CHECK_EXTRA(COUNT != etl::dynamic_extent ? COUNT <= (size() - OFFSET) : true, ETL_ERROR(span_out_of_range));
+
       if (COUNT == etl::dynamic_extent)
       {
         return etl::span<element_type, COUNT != etl::dynamic_extent ? COUNT : etl::dynamic_extent>(pbegin + OFFSET, pend);
@@ -904,8 +1065,11 @@ namespace etl
     //*************************************************************************
     /// Obtains a span that is a view from 'offset' over the next 'count' elements of this span.
     //*************************************************************************
-    ETL_NODISCARD ETL_CONSTEXPR14 etl::span<element_type, etl::dynamic_extent> subspan(size_t offset, size_t count = etl::dynamic_extent) const ETL_NOEXCEPT
+    ETL_NODISCARD ETL_CONSTEXPR14 etl::span<element_type, etl::dynamic_extent> subspan(size_t offset, size_t count = etl::dynamic_extent) const ETL_NOEXCEPT_EXPR(ETL_NOT_USING_EXCEPTIONS || ETL_NOT_CHECKING_EXTRA)
     {
+      ETL_ASSERT_CHECK_EXTRA(offset <= size(), ETL_ERROR(span_out_of_range));
+      ETL_ASSERT_CHECK_EXTRA(count != etl::dynamic_extent ? count <= (size() - offset) : true, ETL_ERROR(span_out_of_range));
+
       return (count == etl::dynamic_extent) ? etl::span<element_type, etl::dynamic_extent>(pbegin + offset, pend)
                                             : etl::span<element_type, etl::dynamic_extent>(pbegin + offset, pbegin + offset + count);
     }
@@ -1082,26 +1246,26 @@ namespace etl
   span(const TIterator begin_, const TSize size_)
     ->span<etl::remove_pointer_t<TIterator>, etl::dynamic_extent>;
 
-  template <typename T, size_t N>
-  span(T(&)[N])
-    -> span<T, N>;
+  template <typename T, size_t Size>
+  span(T(&)[Size])
+    -> span<T, Size>;
 
-  template <typename T, size_t N>
-  span(etl::array<T, N>&)
-    -> span<T, N>;
+  template <typename T, size_t Size>
+  span(etl::array<T, Size>&)
+    -> span<T, Size>;
 
-  template <typename T, size_t N>
-  span(const etl::array<T, N>&)
-    -> span<const T, N>;
+  template <typename T, size_t Size>
+  span(const etl::array<T, Size>&)
+    -> span<const T, Size>;
 
 #if ETL_USING_STL && ETL_USING_CPP11
-  template <typename T, size_t N>
-  span(std::array<T, N>&)
-    ->span<T, N>;
+  template <typename T, size_t Size>
+  span(std::array<T, Size>&)
+    ->span<T, Size>;
 
-  template <typename T, size_t N>
-  span(const std::array<T, N>&)
-    ->span<const T, N>;
+  template <typename T, size_t Size>
+  span(const std::array<T, Size>&)
+    ->span<const T, Size>;
 #endif
 #endif 
 
@@ -1123,22 +1287,22 @@ namespace etl
   //*************************************************************************
   /// Obtains a view to the byte representation of the elements of the span s.
   //*************************************************************************
-  template <class T, size_t N>
-  span<const byte, (N == etl::dynamic_extent) ? (etl::dynamic_extent) : (N * sizeof(T))> 
-    as_bytes(span<T, N> s) ETL_NOEXCEPT
+  template <class T, size_t Size>
+  span<const byte, (Size == etl::dynamic_extent) ? (etl::dynamic_extent) : (Size * sizeof(T))> 
+    as_bytes(span<T, Size> s) ETL_NOEXCEPT
   {
-    return span<const byte, (N == etl::dynamic_extent) ? (etl::dynamic_extent) : (N * sizeof(T))>(reinterpret_cast<byte*>(s.data()), s.size_bytes());
+    return span<const byte, (Size == etl::dynamic_extent) ? (etl::dynamic_extent) : (Size * sizeof(T))>(reinterpret_cast<byte*>(s.data()), s.size_bytes());
   }
 
   //*************************************************************************
   /// Obtains a view to the byte representation of the elements of the span s.
   //*************************************************************************
-  template <class T, size_t N>
-  span<byte, (N == etl::dynamic_extent) ? (etl::dynamic_extent) : (N * sizeof(T))> 
-    as_writable_bytes(span<T, N> s) ETL_NOEXCEPT
+  template <class T, size_t Size>
+  span<byte, (Size == etl::dynamic_extent) ? (etl::dynamic_extent) : (Size * sizeof(T))> 
+    as_writable_bytes(span<T, Size> s) ETL_NOEXCEPT
   {
     ETL_STATIC_ASSERT(!etl::is_const<T>::value, "span<T> must be of non-const type");
-    return span<byte, (N == etl::dynamic_extent) ? (etl::dynamic_extent) : (N * sizeof(T))>(reinterpret_cast<byte*>(s.data()), s.size_bytes());
+    return span<byte, (Size == etl::dynamic_extent) ? (etl::dynamic_extent) : (Size * sizeof(T))>(reinterpret_cast<byte*>(s.data()), s.size_bytes());
   }
 }
 
