@@ -44,6 +44,9 @@ SOFTWARE.
 #include "smallest.h"
 #include "absolute.h"
 #include "expected.h"
+#include "math.h"
+
+#include <math.h>
 
 namespace etl
 {
@@ -233,31 +236,26 @@ namespace etl
         case etl::radix::binary:
         {
           return (c >= '0') && (c <= '1');
-          break;
         }
 
         case etl::radix::octal:
         {
           return (c >= '0') && (c <= '7');
-          break;
         }
 
         case etl::radix::decimal:
         {
           return (c >= '0') && (c <= '9');
-          break;
         }
 
-        case etl::radix::hex:
+        case etl::radix::hexadecimal:
         {
           return ((c >= '0') && (c <= '9')) || ((c >= 'a') && (c <= 'f'));
-          break;
         }
 
         default:
         {
           return false;
-          break;
         }
       }
     }
@@ -275,10 +273,9 @@ namespace etl
         case etl::radix::decimal:
         {
           return c - '0';
-          break;
         }
 
-        case etl::radix::hex:
+        case etl::radix::hexadecimal:
         {
           if ((c >= '0') && (c <= '9'))
           {
@@ -288,13 +285,11 @@ namespace etl
           {
             return (c - 'a') + 10;
           }
-          break;
         }
 
         default:
         {
           return 0;
-          break;
         }
       }
     }
@@ -360,7 +355,7 @@ namespace etl
       return (radix == etl::radix::binary)  ||
              (radix == etl::radix::octal)   ||
              (radix == etl::radix::decimal) ||
-             (radix == etl::radix::hex);
+             (radix == etl::radix::hexadecimal);
     }
 
     //***************************************************************************
@@ -394,7 +389,7 @@ namespace etl
           TValue old_value = integral_value;
           integral_value *= radix;
 
-          // No multipication overflow?
+          // No multiplication overflow?
           is_not_overflow = ((integral_value / radix) == old_value);
 
           if (is_not_overflow)
@@ -919,13 +914,11 @@ namespace etl
         value *= pow(static_cast<TValue>(10.0), static_cast<TValue>(exponent));
 
         // Check that the result is a valid floating point number.
-        if ((value == etl::numeric_limits<TValue>::infinity()) ||
-            (value == -etl::numeric_limits<TValue>::infinity()))
+        if (etl::is_infinity(value))
         {
           result = unexpected_type(to_arithmetic_status::Overflow);
         }
-        // Check for NaN.
-        else if (value != value)
+        else if (etl::is_nan(value))
         {
           result = unexpected_type(to_arithmetic_status::Invalid_Float);
         }
