@@ -46,7 +46,7 @@ namespace etl
   {
     inline namespace string_literals
     {
-      inline constexpr etl::u32string_view operator ""_sv(const char32_t* str, size_t length) noexcept
+      inline constexpr etl::u32string_view operator ""_sv(const char32_t* str, size_t length) ETL_NOEXCEPT
       {
         return etl::u32string_view{ str, length };
       }
@@ -263,8 +263,8 @@ namespace etl
   };
 
   //***************************************************************************
-  /// A u32string implementation that uses a fixed size external buffer.
-  ///\ingroup u32string
+  /// A string implementation that uses a fixed size external buffer.
+  ///\ingroup string
   //***************************************************************************
   class u32string_ext : public iu32string
   {
@@ -274,6 +274,7 @@ namespace etl
     typedef iu32string interface_type;
 
     typedef iu32string::value_type value_type;
+    typedef iu32string::size_type size_type;
 
     //*************************************************************************
     /// Constructor.
@@ -291,8 +292,15 @@ namespace etl
     u32string_ext(const etl::u32string_ext& other, value_type* buffer, size_type buffer_size)
       : iu32string(buffer, buffer_size - 1U)
     {
-      this->initialise();
-      this->assign(other);
+      if (this->is_within_buffer(other.data()))
+      {
+        this->current_size = other.size();
+      }
+      else
+      {
+        this->initialise();
+        this->assign(other);
+      }
     }
 
     //*************************************************************************
@@ -302,8 +310,15 @@ namespace etl
     u32string_ext(const etl::iu32string& other, value_type* buffer, size_type buffer_size)
       : iu32string(buffer, buffer_size - 1U)
     {
-      this->initialise();
-      this->assign(other);
+      if (this->is_within_buffer(other.data()))
+      {
+        this->current_size = other.size();
+      }
+      else
+      {
+        this->initialise();
+        this->assign(other);
+      }
     }
 
     //*************************************************************************
@@ -317,21 +332,29 @@ namespace etl
     {
       ETL_ASSERT(position < other.size(), ETL_ERROR(string_out_of_bounds));
 
-      this->initialise();
-      this->assign(other, position, length);
+      if (this->is_within_buffer(other.data()))
+      {
+        this->current_size = other.size();
+      }
+      else
+      {
+        this->initialise();
+        this->assign(other, position, length);
+      }
     }
 
     //*************************************************************************
     /// Constructor, from null terminated text.
     ///\param text The initial text of the u32string_ext.
     //*************************************************************************
-    ETL_EXPLICIT_STRING_FROM_CHAR u32string_ext(const value_type* text, value_type* buffer, size_type buffer_size)
+    template <typename TPointer>
+    u32string_ext(TPointer text, value_type* buffer, size_type buffer_size,
+                  typename etl::enable_if<etl::is_same<const value_type*, TPointer>::value, int>::type* = ETL_NULLPTR)
       : iu32string(buffer, buffer_size - 1U)
     {
-      // Is the initial text at the same address as the buffer?
-      if (text == buffer)
+      if (this->is_within_buffer(text))
       {
-        this->current_size = etl::strlen(buffer);;
+        this->current_size = etl::strlen(buffer);
       }
       else
       {
@@ -340,6 +363,25 @@ namespace etl
       }
     }
 
+    //*************************************************************************
+    /// Constructor, from null terminated literal text.
+    ///\param text The initial text of the u32string_ext.
+    //*************************************************************************
+    template <size_t Size>
+    u32string_ext(const value_type (&literal)[Size], value_type* buffer, size_type buffer_size)
+      : iu32string(buffer, buffer_size - 1U)
+    {
+      if (this->is_within_buffer(literal))
+      {
+        this->current_size = etl::strlen(literal);
+      }
+      else
+      {
+        this->initialise();
+        this->assign(literal);
+      }
+    }
+
     //*************************************************************************
     /// Constructor, from null terminated text and count.
     ///\param text  The initial text of the u32string_ext.
@@ -348,8 +390,15 @@ namespace etl
     u32string_ext(const value_type* text, size_type count, value_type* buffer, size_type buffer_size)
       : iu32string(buffer, buffer_size - 1U)
     {
-      this->initialise();
-      this->assign(text, text + count);
+      if (this->is_within_buffer(text))
+      {
+        this->current_size = count;
+      }
+      else
+      {
+        this->initialise();
+        this->assign(text, text + count);
+      }
     }
 
     //*************************************************************************
@@ -364,6 +413,24 @@ namespace etl
       this->resize(count, c);
     }
 
+    //*************************************************************************
+    /// From u32string_view.
+    ///\param view The u32string_view.
+    //*************************************************************************
+    explicit u32string_ext(const etl::u32string_view& view, value_type* buffer, size_type buffer_size)
+      : iu32string(buffer, buffer_size - 1U)
+    {
+      if (this->is_within_buffer(view.data()))
+      {
+        this->current_size = view.size();
+      }
+      else
+      {
+        this->initialise();
+        this->assign(view.begin(), view.end());
+      }
+    }
+
     //*************************************************************************
     /// Constructor, from an iterator range.
     ///\tparam TIterator The iterator type.
@@ -374,8 +441,15 @@ namespace etl
     u32string_ext(TIterator first, TIterator last, value_type* buffer, size_type buffer_size, typename etl::enable_if<!etl::is_integral<TIterator>::value, int>::type = 0)
       : iu32string(buffer, buffer_size - 1U)
     {
-      this->initialise();
-      this->assign(first, last);
+      if (this->is_within_buffer(reinterpret_cast<const_iterator>(etl::addressof(*first))))
+      {
+        this->current_size = etl::distance(first, last);
+      }
+      else
+      {
+        this->initialise();
+        this->assign(first, last);
+      }     
     }
 
 #if ETL_HAS_INITIALIZER_LIST
@@ -390,17 +464,6 @@ namespace etl
     }
 #endif
 
-    //*************************************************************************
-    /// From string_view.
-    ///\param view The string_view.
-    //*************************************************************************
-    explicit u32string_ext(const etl::u32string_view& view, value_type* buffer, size_type buffer_size)
-      : iu32string(buffer, buffer_size - 1U)
-    {
-      this->initialise();
-      this->assign(view.begin(), view.end());
-    }
-
     //*************************************************************************
     /// Assignment operator.
     //*************************************************************************
