@@ -34,10 +34,13 @@ SOFTWARE.
 #include "platform.h"
 
 #if ETL_USING_LEGACY_VARIANT
-  #include "private/variant_legacy.h"   // etl::variant
+  // etl::variant
+  #include "private/variant_legacy.h" // IWYU pragma: export
 #else
-  #include "private/variant_legacy.h"   // etl::legacy::variant
-  #include "private/variant_variadic.h" // etl::variant
+  // etl::legacy::variant
+  #include "private/variant_legacy.h" // IWYU pragma: export
+  // etl::variant
+  #include "private/variant_variadic.h" // IWYU pragma: export
 #endif
 
 #endif
