@@ -209,6 +209,13 @@ public:
     other.valid = false;
   }
 
+  TestDataM(const TestDataM&& other) noexcept
+    : value(std::move(other.value))
+    , valid(true)
+  {
+    other.valid = false;
+  }
+
   virtual ~TestDataM()
   {
     valid = false;
@@ -249,8 +256,8 @@ public:
     return valid;
   }
 
-  T    value;
-  bool valid;
+  T value;
+  mutable bool valid;
 
 private:
 
