@@ -1420,17 +1420,6 @@ namespace
       CHECK(is_same);
     }
 
-    //*************************************************************************
-    TEST(copy_s_random_iterator)
-    {
-      int data1[] = { 1, 2, 3, 4, 5 };
-      int out1[10];
-      CHECK_THROW(etl::copy_s(std::end(data1), std::begin(data1), std::begin(out1), std::end(out1)), etl::algorithm_error);
-      CHECK_THROW(etl::copy_s(std::begin(data1), std::end(data1), std::end(out1), std::begin(out1)), etl::algorithm_error);
-      CHECK_THROW(etl::move_s(std::end(data1), std::begin(data1), std::begin(out1), std::end(out1)), etl::algorithm_error);
-      CHECK_THROW(etl::move_s(std::begin(data1), std::end(data1), std::end(out1), std::begin(out1)), etl::algorithm_error);
-    }
-
     //*************************************************************************
     TEST(copy_4_parameter_non_random_iterator)
     {
