@@ -76,10 +76,10 @@ namespace
 
       CHECK_EQUAL(compare.is_lock_free(), test.is_lock_free());
 
-//#if ETL_NOT_USING_STL && ETL_HAS_ATOMIC
-//      CHECK_TRUE(etl::atomic<int>::is_always_lock_free);
-//      CHECK_TRUE(test.is_always_lock_free);
-//#endif
+#if ETL_HAS_ATOMIC_ALWAYS_LOCK_FREE
+      CHECK_TRUE(etl::atomic<int>::is_always_lock_free);
+      CHECK_TRUE(test.is_always_lock_free);
+#endif
     }
 
     //*************************************************************************
@@ -90,28 +90,28 @@ namespace
 
       CHECK_EQUAL(compare.is_lock_free(), test.is_lock_free());
 
-#if ETL_NOT_USING_STL && ETL_HAS_ATOMIC
+#if ETL_HAS_ATOMIC_ALWAYS_LOCK_FREE
       CHECK_TRUE(etl::atomic<int*>::is_always_lock_free);
       CHECK_TRUE(test.is_always_lock_free);
 #endif
     }
 
-//#if ETL_NOT_USING_STL && ETL_HAS_ATOMIC
-//    //*************************************************************************
-//    TEST(test_atomic_is_always_lock_free)
-//    {
-//      struct S 
-//      {
-//        int a;
-//        int b;
-//        int c;
-//      };
-//
-//      CHECK_TRUE(etl::atomic<int>::is_always_lock_free);
-//      CHECK_TRUE(etl::atomic<int*>::is_always_lock_free);
-//      CHECK_FALSE(etl::atomic<S>::is_always_lock_free);
-//    }
-//#endif
+#if ETL_HAS_ATOMIC_ALWAYS_LOCK_FREE
+    //*************************************************************************
+    TEST(test_atomic_is_always_lock_free)
+    {
+      struct S 
+      {
+        int a;
+        int b;
+        int c;
+      };
+
+      CHECK_TRUE(etl::atomic<int>::is_always_lock_free);
+      CHECK_TRUE(etl::atomic<int*>::is_always_lock_free);
+      CHECK_FALSE(etl::atomic<S>::is_always_lock_free);
+    }
+#endif
 
     //*************************************************************************
     TEST(test_atomic_integer_load)
