@@ -64,7 +64,7 @@ namespace
   std::vector<unsigned char> decoded_output;
   bool received_final_block = false;
 
-  codec::callback_type callback = [](const codec::span_type& sp)
+  auto lambda = [](const codec::span_type& sp)
     {
       if (sp.empty())
       {
@@ -76,6 +76,8 @@ namespace
       }
     };
 
+  codec::callback_type callback = lambda;
+
   std::array<unsigned char, 256> input_data =
   {
     0x3B, 0x27, 0x03, 0x43, 0x2D, 0xFB, 0x28, 0x2A, 0x61, 0xAE, 0xBC, 0x49, 0x71, 0x32, 0x01, 0x15,
