@@ -36,6 +36,13 @@ SOFTWARE.
 #include <vector>
 #include <functional>
 #include <algorithm>
+#include <type_traits>
+#include <stdexcept>
+
+// Enable exactly one of these at a time to see the corresponding static_assert fire.
+// #define ETL_NEGATIVE_TEST_DELEGATE_BAD_RETURN
+// #define ETL_NEGATIVE_TEST_DELEGATE_RVALUE_PARAM_MISMATCH_NONCONST
+// #define ETL_NEGATIVE_TEST_DELEGATE_RVALUE_PARAM_MISMATCH_CONST
 
 namespace
 {
@@ -158,6 +165,20 @@ namespace
     return i + j + 1;
   }
 
+  //*****************************************************************************
+  // The throwing function.
+  //*****************************************************************************
+  void throwing_void()
+  {
+    throw std::runtime_error("throwing function");
+  }
+
+  int throwing_normal(int, int)
+  {
+    throw std::runtime_error("throwing function with two parameters");
+  }
+
+
   //*****************************************************************************
   // The test class with member functions.
   //*****************************************************************************
@@ -221,8 +242,6 @@ namespace
       parameter_correct = (data.d == VALUE1) && (j == VALUE2);
     }
 
-    //*******************************************
-    // operator()
     void operator()()
     {
       function_called = FunctionCalled::Operator_Called;
@@ -234,6 +253,26 @@ namespace
     }
   };
 
+  //*******************************************
+  // Functor with non-const operator()
+  struct Functor
+  {
+    void operator()()
+    {
+      function_called = FunctionCalled::Operator_Called;
+    }
+  };
+
+  //*******************************************
+  // Functor with const operator()
+  struct FunctorConst
+  {
+    void operator()() const
+    {
+      function_called = FunctionCalled::Operator_Const_Called;
+    }
+  };
+
   //*******************************************
   int times_2(int a) 
   {
@@ -242,6 +281,15 @@ namespace
 
   Object object_static;
   const Object const_object_static;
+
+#if ETL_USING_CPP17
+  Functor functor_static;
+  const FunctorConst const_functor_static;
+#endif
+
+#if ETL_USING_CPP17
+  static auto global_lambda = [](int i, int j) { return i + j; };
+#endif
 }
 
 namespace
@@ -260,6 +308,18 @@ namespace
 
   SUITE(test_delegate)
   {
+    //*************************************************************************
+    TEST_FIXTURE(SetupFixture, test_delegate_types)
+    {
+      using Delegate = etl::delegate<int(float, long)>;
+
+      // Check the return type.
+      CHECK_TRUE((std::is_same<Delegate::return_type, int>::value));
+  
+      // Check the argument types.
+      CHECK_TRUE((std::is_same<Delegate::argument_types, etl::type_list<float, long>>::value));
+    }
+
     //*************************************************************************
     TEST_FIXTURE(SetupFixture, test_is_valid_false)
     {
@@ -287,7 +347,9 @@ namespace
     //*************************************************************************
     TEST_FIXTURE(SetupFixture, test_is_valid_true)
     {
-      etl::delegate<void(void)> d([] {});
+      auto lambda = [] {};
+
+      etl::delegate<void(void)> d(lambda);
 
       CHECK(d.is_valid());
       CHECK(d);
@@ -297,7 +359,9 @@ namespace
     //*************************************************************************
     TEST_FIXTURE(SetupFixture, test_is_valid_after_clear)
     {
-      etl::delegate<void(void)> d([] {});
+      auto lambda = [] {};
+
+      etl::delegate<void(void)> d(lambda);
 
       CHECK_TRUE(d.is_valid());
       d.clear();
@@ -314,6 +378,36 @@ namespace
       CHECK(function_called == FunctionCalled::Free_Void_Called);
     }
 
+    //*************************************************************************
+    TEST_FIXTURE(SetupFixture, test_throwing)
+    {
+      {
+        auto d = etl::delegate<void(void)>::create<throwing_void>();
+
+        CHECK_THROW(d(), std::runtime_error);
+        CHECK_THROW(d.call_if(), std::runtime_error);
+      }
+
+      {
+        auto d = etl::delegate<int(int, int)>::create<throwing_normal>();
+
+        CHECK_THROW({d.call_or(alternative, VALUE1, VALUE2);}, std::runtime_error);
+        CHECK_THROW({d.call_or<alternative>(VALUE1, VALUE2);}, std::runtime_error);
+      }
+    }
+
+    //*************************************************************************
+#if ETL_USING_CPP17
+    TEST_FIXTURE(SetupFixture, test_make_delegate_free_void)
+    {
+      auto d = etl::make_delegate<&free_void>();
+
+      d();
+
+      CHECK(function_called == FunctionCalled::Free_Void_Called);
+    }
+#endif
+
     //*************************************************************************
 #if ETL_USING_CPP14
     TEST_FIXTURE(SetupFixture, test_free_void_constexpr)
@@ -326,6 +420,18 @@ namespace
     }
 #endif
 
+    //*************************************************************************
+#if ETL_USING_CPP17
+    TEST_FIXTURE(SetupFixture, test_make_delegate_free_void_constexpr)
+    {
+      constexpr auto d = etl::make_delegate<&free_void>();
+
+      d();
+
+      CHECK(function_called == FunctionCalled::Free_Void_Called);
+    }
+#endif
+
     //*************************************************************************
     TEST_FIXTURE(SetupFixture, test_free_int)
     {
@@ -337,6 +443,19 @@ namespace
       CHECK(parameter_correct);
     }
 
+    //*************************************************************************
+#if ETL_USING_CPP17
+    TEST_FIXTURE(SetupFixture, test_make_delegate_free_int)
+    {
+      auto d = etl::make_delegate<&free_int>();
+
+      d(VALUE1, VALUE2);
+
+      CHECK(function_called == FunctionCalled::Free_Int_Called);
+      CHECK(parameter_correct);
+    }
+#endif
+
     //*************************************************************************
 #if ETL_USING_CPP14
     TEST_FIXTURE(SetupFixture, test_free_int_constexpr)
@@ -350,6 +469,19 @@ namespace
     }
 #endif
 
+    //*************************************************************************
+#if ETL_USING_CPP17
+    TEST_FIXTURE(SetupFixture, test_make_delegate_free_int_constexpr)
+    {
+      constexpr auto d = etl::make_delegate<&free_int>();
+
+      d(VALUE1, VALUE2);
+
+      CHECK(function_called == FunctionCalled::Free_Int_Called);
+      CHECK(parameter_correct);
+    }
+#endif
+
     //*************************************************************************
     TEST_FIXTURE(SetupFixture, test_free_reference)
     {
@@ -364,6 +496,22 @@ namespace
       CHECK(parameter_correct);
     }
 
+    //*************************************************************************
+#if ETL_USING_CPP17
+    TEST_FIXTURE(SetupFixture, test_make_delegate_free_reference)
+    {
+      etl::delegate<void(const Data&, int)> d = etl::make_delegate<&free_reference>();
+
+      Data data;
+      data.d = VALUE1;
+
+      d(data, VALUE2);
+
+      CHECK(function_called == FunctionCalled::Free_Reference_Called);
+      CHECK(parameter_correct);
+    }
+#endif
+
     //*************************************************************************
 #if ETL_USING_CPP14
     TEST_FIXTURE(SetupFixture, test_free_reference_constexpr)
@@ -380,6 +528,22 @@ namespace
     }
 #endif
 
+    //*************************************************************************
+#if ETL_USING_CPP17
+    TEST_FIXTURE(SetupFixture, test_make_delegate_free_reference_constexpr)
+    {
+      constexpr etl::delegate<void(const Data&, int)> d = etl::make_delegate<&free_reference>();
+
+      Data data;
+      data.d = VALUE1;
+
+      d(data, VALUE2);
+
+      CHECK(function_called == FunctionCalled::Free_Reference_Called);
+      CHECK(parameter_correct);
+    }
+#endif
+
     //*************************************************************************
     TEST_FIXTURE(SetupFixture, test_free_moveableonly)
     {
@@ -394,6 +558,22 @@ namespace
       CHECK(parameter_correct);
     }
 
+    //*************************************************************************
+#if ETL_USING_CPP17
+    TEST_FIXTURE(SetupFixture, test_make_delegate_free_moveableonly)
+    {
+      auto d = etl::make_delegate<&free_moveableonly>();
+
+      MoveableOnlyData data;
+      data.d = VALUE1;
+
+      d(std::move(data));
+
+      CHECK(function_called == FunctionCalled::Free_Moveableonly_Called);
+      CHECK(parameter_correct);
+    }
+#endif
+
     //*************************************************************************
 #if ETL_USING_CPP14
     TEST_FIXTURE(SetupFixture, test_free_moveableonly_constexpr)
@@ -410,10 +590,28 @@ namespace
     }
 #endif
 
+    //*************************************************************************
+#if ETL_USING_CPP17
+    TEST_FIXTURE(SetupFixture, test_make_delegate_free_moveableonly_constexpr)
+    {
+      constexpr auto d = etl::make_delegate<&free_moveableonly>();
+
+      MoveableOnlyData data;
+      data.d = VALUE1;
+
+      d(std::move(data));
+
+      CHECK(function_called == FunctionCalled::Free_Moveableonly_Called);
+      CHECK(parameter_correct);
+    }
+#endif
+
     //*************************************************************************
     TEST_FIXTURE(SetupFixture, test_lambda_int)
     {
-      etl::delegate<void(int, int)> d([](int i, int j) { function_called = FunctionCalled::Lambda_Called; parameter_correct = (i == VALUE1) && (j == VALUE2); });
+      auto lambda = [](int i, int j) { function_called = FunctionCalled::Lambda_Called; parameter_correct = (i == VALUE1) && (j == VALUE2); };
+
+      etl::delegate<void(int, int)> d(lambda);
 
       d(VALUE1, VALUE2);
 
@@ -421,6 +619,20 @@ namespace
       CHECK(parameter_correct);
     }
 
+#if ETL_USING_CPP17
+    //*************************************************************************
+    TEST_FIXTURE(SetupFixture, test_constexpr_lambda_int)
+    {
+      static constexpr int(*global_func_ptr)(int, int) = global_lambda;
+
+      auto d = etl::delegate<int(int, int)>::create<global_func_ptr>();
+
+      int result = d(VALUE1, VALUE2);
+
+      CHECK_EQUAL(result, VALUE1 + VALUE2);
+    }
+#endif
+
     //*************************************************************************
     TEST_FIXTURE(SetupFixture, test_lambda_int_create)
     {
@@ -434,6 +646,21 @@ namespace
       CHECK(parameter_correct);
     }
 
+#if ETL_USING_CPP17
+    //*************************************************************************
+    TEST_FIXTURE(SetupFixture, test_make_delegate_lambda_int_create)
+    {
+      auto lambda = [](int i, int j) { function_called = FunctionCalled::Lambda_Called; parameter_correct = (i == VALUE1) && (j == VALUE2); };
+
+      auto d = etl::make_delegate(lambda);
+
+      d(VALUE1, VALUE2);
+
+      CHECK(function_called == FunctionCalled::Lambda_Called);
+      CHECK(parameter_correct);
+    }
+#endif
+
     //*************************************************************************
     TEST_FIXTURE(SetupFixture, test_member_operator_void)
     {
@@ -446,6 +673,20 @@ namespace
       CHECK(function_called == FunctionCalled::Operator_Called);
     }
 
+#if ETL_USING_CPP17
+    //*************************************************************************
+    TEST_FIXTURE(SetupFixture, test_make_delegate_member_operator_void)
+    {
+      Functor object;
+
+      auto d = etl::make_delegate(object);
+
+      d();
+
+      CHECK(function_called == FunctionCalled::Operator_Called);
+    }
+#endif
+
     //*************************************************************************
     TEST_FIXTURE(SetupFixture, test_member_operator_void_create)
     {
@@ -459,7 +700,7 @@ namespace
     }
 
     //*************************************************************************
-#if ETL_USING_CPP14
+#if ETL_USING_CPP17
     TEST_FIXTURE(SetupFixture, test_member_operator_void_create_constexpr)
     {
       static Object object;
@@ -484,7 +725,21 @@ namespace
       CHECK(function_called == FunctionCalled::Operator_Const_Called);
     }
 
-#if !defined(ETL_COMPILER_GCC)
+    //*************************************************************************
+#if ETL_USING_CPP17
+    TEST_FIXTURE(SetupFixture, test_make_delegate_member_operator_void_const)
+    {
+      const FunctorConst object;
+
+      auto d = etl::make_delegate(object);
+
+      d();
+
+      CHECK(function_called == FunctionCalled::Operator_Const_Called);
+    }
+#endif
+
+#if !(defined(ETL_COMPILER_GCC) && (__GNUC__ <= 8))
     //*************************************************************************
     TEST_FIXTURE(SetupFixture, test_member_operator_void_compile_time)
     {
@@ -495,6 +750,18 @@ namespace
       CHECK(function_called == FunctionCalled::Operator_Called);
     }
 
+    //*************************************************************************
+#if ETL_USING_CPP17
+    TEST_FIXTURE(SetupFixture, test_make_delegate_member_operator_void_compile_time)
+    {
+      auto d = etl::make_delegate<Functor, functor_static>();
+
+      d();
+
+      CHECK(function_called == FunctionCalled::Operator_Called);
+    }
+#endif
+
     //*************************************************************************
 #if ETL_USING_CPP14
     TEST_FIXTURE(SetupFixture, test_member_operator_void_compile_time_constexpr)
@@ -507,6 +774,18 @@ namespace
     }
 #endif
 
+    //*************************************************************************
+#if ETL_USING_CPP17
+    TEST_FIXTURE(SetupFixture, test_make_delegate_member_operator_void_compile_time_constexpr)
+    {
+      constexpr auto d = etl::make_delegate<Functor, functor_static>();
+
+      d();
+
+      CHECK(function_called == FunctionCalled::Operator_Called);
+    }
+#endif
+
     //*************************************************************************
     TEST_FIXTURE(SetupFixture, test_member_operator_void_compile_time_const)
     {
@@ -517,6 +796,18 @@ namespace
       CHECK(function_called == FunctionCalled::Operator_Const_Called);
     }
 
+    //*************************************************************************
+#if ETL_USING_CPP17
+    TEST_FIXTURE(SetupFixture, test_make_delegate_member_operator_void_compile_time_const)
+    {
+      auto d = etl::make_delegate<const FunctorConst, const_functor_static>();
+
+      d();
+
+      CHECK(function_called == FunctionCalled::Operator_Const_Called);
+    }
+#endif
+
     //*************************************************************************
 #if ETL_USING_CPP14
     TEST_FIXTURE(SetupFixture, test_member_operator_void_compile_time_const_constexpr)
@@ -528,6 +819,18 @@ namespace
       CHECK(function_called == FunctionCalled::Operator_Const_Called);
     }
 #endif
+
+    //*************************************************************************
+#if ETL_USING_CPP17
+    TEST_FIXTURE(SetupFixture, test_make_delegate_member_operator_void_compile_time_const_constexpr)
+    {
+      constexpr auto d = etl::make_delegate<const FunctorConst, const_functor_static>();
+
+      d();
+
+      CHECK(function_called == FunctionCalled::Operator_Const_Called);
+    }
+#endif
 #endif
 
     //*************************************************************************
@@ -556,6 +859,20 @@ namespace
       CHECK(function_called == FunctionCalled::Member_Void_Called);
     }
 
+#if ETL_USING_CPP17
+    //*************************************************************************
+    TEST_FIXTURE(SetupFixture, test_make_delegate_member_void)
+    {
+      Object object;
+
+      auto d = etl::make_delegate<Object, &Object::member_void>(object);
+
+      d();
+
+      CHECK(function_called == FunctionCalled::Member_Void_Called);
+    }
+#endif
+
     //*************************************************************************
 #if ETL_USING_CPP14
     TEST_FIXTURE(SetupFixture, test_member_void_constexpr)
@@ -570,6 +887,20 @@ namespace
     }
 #endif
 
+    //*************************************************************************
+#if ETL_USING_CPP17
+    TEST_FIXTURE(SetupFixture, test_make_delegate_member_void_constexpr)
+    {
+      static Object object;
+
+      constexpr auto d = etl::make_delegate<Object, &Object::member_void>(object);
+
+      d();
+
+      CHECK(function_called == FunctionCalled::Member_Void_Called);
+    }
+#endif
+
     //*************************************************************************
     TEST_FIXTURE(SetupFixture, test_member_void_const)
     {
@@ -582,6 +913,20 @@ namespace
       CHECK(function_called == FunctionCalled::Member_Void_Const_Called);
     }
 
+    //*************************************************************************
+#if ETL_USING_CPP17
+    TEST_FIXTURE(SetupFixture, test_make_delegate_member_void_const)
+    {
+      const Object object;
+
+      auto d = etl::make_delegate<Object, &Object::member_void_const>(object);
+
+      d();
+
+      CHECK(function_called == FunctionCalled::Member_Void_Const_Called);
+    }
+#endif
+
     //*************************************************************************
 #if ETL_USING_CPP14
     TEST_FIXTURE(SetupFixture, test_member_void_const_constexpr)
@@ -596,6 +941,20 @@ namespace
     }
 #endif
 
+    //*************************************************************************
+#if ETL_USING_CPP17
+    TEST_FIXTURE(SetupFixture, test_make_delegate_member_void_const_constexpr)
+    {
+      static const Object object;
+
+      constexpr auto d = etl::make_delegate<Object, &Object::member_void_const>(object);
+
+      d();
+
+      CHECK(function_called == FunctionCalled::Member_Void_Const_Called);
+    }
+#endif
+
     //*************************************************************************
     TEST_FIXTURE(SetupFixture, test_member_int)
     {
@@ -609,6 +968,21 @@ namespace
       CHECK(parameter_correct);
     }
 
+    //*************************************************************************
+#if ETL_USING_CPP17
+    TEST_FIXTURE(SetupFixture, test_make_delegate_member_int)
+    {
+      Object object;
+
+      auto d = etl::make_delegate<Object, &Object::member_int>(object);
+
+      d(VALUE1, VALUE2);
+
+      CHECK(function_called == FunctionCalled::Member_Int_Called);
+      CHECK(parameter_correct);
+    }
+#endif
+
     //*************************************************************************
 #if ETL_USING_CPP14
     TEST_FIXTURE(SetupFixture, test_member_int_constexpr)
@@ -624,6 +998,21 @@ namespace
     }
 #endif
 
+    //*************************************************************************
+#if ETL_USING_CPP17
+    TEST_FIXTURE(SetupFixture, test_make_delegate_member_int_constexpr)
+    {
+      static Object object;
+
+      constexpr auto d = etl::make_delegate<Object, &Object::member_int>(object);
+
+      d(VALUE1, VALUE2);
+
+      CHECK(function_called == FunctionCalled::Member_Int_Called);
+      CHECK(parameter_correct);
+    }
+#endif
+
     //*************************************************************************
     TEST_FIXTURE(SetupFixture, test_member_int_const)
     {
@@ -637,6 +1026,21 @@ namespace
       CHECK(parameter_correct);
     }
 
+    //*************************************************************************
+#if ETL_USING_CPP17
+    TEST_FIXTURE(SetupFixture, test_make_delegate_member_int_const)
+    {
+      const Object object;
+
+      auto d = etl::make_delegate<Object, &Object::member_int_const>(object);
+
+      d(VALUE1, VALUE2);
+
+      CHECK(function_called == FunctionCalled::Member_Int_Const_Called);
+      CHECK(parameter_correct);
+    }
+#endif
+
     //*************************************************************************
 #if ETL_USING_CPP14
     TEST_FIXTURE(SetupFixture, test_member_int_const_constexpr)
@@ -652,6 +1056,21 @@ namespace
     }
 #endif
 
+    //*************************************************************************
+#if ETL_USING_CPP17
+    TEST_FIXTURE(SetupFixture, test_make_delegate_member_int_const_constexpr)
+    {
+      static const Object object;
+
+      constexpr auto d = etl::make_delegate<Object, &Object::member_int_const>(object);
+
+      d(VALUE1, VALUE2);
+
+      CHECK(function_called == FunctionCalled::Member_Int_Const_Called);
+      CHECK(parameter_correct);
+    }
+#endif
+
     //*************************************************************************
     TEST_FIXTURE(SetupFixture, test_member_reference)
     {
@@ -762,6 +1181,22 @@ namespace
       CHECK(parameter_correct);
     }
 
+    //*************************************************************************
+//#if ETL_USING_CPP17
+//    TEST_FIXTURE(SetupFixture, test_make_delegate_member_static)
+//    {
+//      auto d = etl::make_delegate<Object::member_static>();
+//
+//      Data data;
+//      data.d = VALUE1;
+//
+//      d(data, VALUE2);
+//
+//      CHECK(function_called == FunctionCalled::Member_Static_Called);
+//      CHECK(parameter_correct);
+//    }
+//#endif
+
     //*************************************************************************
 #if ETL_USING_CPP14
     TEST_FIXTURE(SetupFixture, test_member_static_constexpr)
@@ -778,6 +1213,22 @@ namespace
     }
 #endif
 
+    //*************************************************************************
+//#if ETL_USING_CPP17
+//    TEST_FIXTURE(SetupFixture, test_make_delegate_member_static_constexpr)
+//    {
+//      constexpr auto d = etl::make_delegate<Object::member_static>();
+//
+//      Data data;
+//      data.d = VALUE1;
+//
+//      d(data, VALUE2);
+//
+//      CHECK(function_called == FunctionCalled::Member_Static_Called);
+//      CHECK(parameter_correct);
+//    }
+//#endif
+
 #if !(defined(ETL_COMPILER_GCC) && (__GNUC__ <= 5))
     //*************************************************************************
     TEST_FIXTURE(SetupFixture, test_member_void_compile_time)
@@ -799,6 +1250,18 @@ namespace
       CHECK(function_called == FunctionCalled::Member_Void_Called);
     }
 
+    //*************************************************************************
+#if ETL_USING_CPP17
+    TEST_FIXTURE(SetupFixture, test_make_delegate_member_void_compile_time_new_api)
+    {
+      auto d = etl::make_delegate<Object, &Object::member_void, object_static>();
+
+      d();
+
+      CHECK(function_called == FunctionCalled::Member_Void_Called);
+    }
+#endif
+
     //*************************************************************************
 #if ETL_USING_CPP14
     TEST_FIXTURE(SetupFixture, test_member_void_compile_time_constexpr)
@@ -823,6 +1286,18 @@ namespace
     }
 #endif
 
+    //*************************************************************************
+#if ETL_USING_CPP17
+    TEST_FIXTURE(SetupFixture, test_make_delegate_member_void_compile_time_constexpr_new_api)
+    {
+      constexpr auto d = etl::make_delegate<Object, &Object::member_void, object_static>();
+
+      d();
+
+      CHECK(function_called == FunctionCalled::Member_Void_Called);
+    }
+#endif
+
     //*************************************************************************
     TEST_FIXTURE(SetupFixture, test_member_void_const_compile_time)
     {
@@ -843,6 +1318,18 @@ namespace
       CHECK(function_called == FunctionCalled::Member_Void_Const_Called);
     }
 
+    //*************************************************************************
+#if ETL_USING_CPP17
+    TEST_FIXTURE(SetupFixture, test_make_delegate_member_void_const_compile_time_new_api)
+    {
+      auto d = etl::make_delegate<Object, &Object::member_void_const, const_object_static>();
+
+      d();
+
+      CHECK(function_called == FunctionCalled::Member_Void_Const_Called);
+    }
+#endif
+
     //*************************************************************************
 #if ETL_USING_CPP14
     TEST_FIXTURE(SetupFixture, test_member_void_const_compile_time_constexpr)
@@ -867,6 +1354,18 @@ namespace
     }
 #endif
 
+    //*************************************************************************
+#if ETL_USING_CPP17
+    TEST_FIXTURE(SetupFixture, test_make_delegate_member_void_const_compile_time_constexpr_new_api)
+    {
+      constexpr auto d = etl::make_delegate<Object, &Object::member_void_const, const_object_static>();
+
+      d();
+
+      CHECK(function_called == FunctionCalled::Member_Void_Const_Called);
+    }
+#endif
+
     //*************************************************************************
     TEST_FIXTURE(SetupFixture, test_member_int_compile_time)
     {
@@ -889,6 +1388,19 @@ namespace
       CHECK(parameter_correct);
     }
 
+    //*************************************************************************
+#if ETL_USING_CPP17
+    TEST_FIXTURE(SetupFixture, test_make_delegate_member_int_compile_time_new_api)
+    {
+      auto d = etl::make_delegate<Object, &Object::member_int, object_static>();
+
+      d(VALUE1, VALUE2);
+
+      CHECK(function_called == FunctionCalled::Member_Int_Called);
+      CHECK(parameter_correct);
+    }
+#endif
+
     //*************************************************************************
 #if ETL_USING_CPP14
     TEST_FIXTURE(SetupFixture, test_member_int_compile_time_constexpr)
@@ -915,6 +1427,19 @@ namespace
     }
 #endif
 
+    //*************************************************************************
+#if ETL_USING_CPP17
+    TEST_FIXTURE(SetupFixture, test_make_delegate_member_int_compile_time_constexpr_new_api)
+    {
+      constexpr auto d = etl::make_delegate<Object, &Object::member_int, object_static>();
+
+      d(VALUE1, VALUE2);
+
+      CHECK(function_called == FunctionCalled::Member_Int_Called);
+      CHECK(parameter_correct);
+    }
+#endif
+
     //*************************************************************************
     TEST_FIXTURE(SetupFixture, test_member_int_const_compile_time)
     {
@@ -937,6 +1462,19 @@ namespace
       CHECK(parameter_correct);
     }
 
+    //*************************************************************************
+#if ETL_USING_CPP17
+    TEST_FIXTURE(SetupFixture, test_make_delegate_member_int_const_compile_time_new_api)
+    {
+      auto d = etl::make_delegate<Object, &Object::member_int_const, const_object_static>();
+
+      d(VALUE1, VALUE2);
+
+      CHECK(function_called == FunctionCalled::Member_Int_Const_Called);
+      CHECK(parameter_correct);
+    }
+#endif
+
     //*************************************************************************
 #if ETL_USING_CPP14
     TEST_FIXTURE(SetupFixture, test_member_int_const_compile_time_constexpr)
@@ -963,6 +1501,19 @@ namespace
     }
 #endif
 
+    //*************************************************************************
+#if ETL_USING_CPP17
+    TEST_FIXTURE(SetupFixture, test_make_delegate_member_int_const_compile_time_constexpr_new_api)
+    {
+      constexpr auto d = etl::make_delegate<Object, &Object::member_int_const, const_object_static>();
+
+      d(VALUE1, VALUE2);
+
+      CHECK(function_called == FunctionCalled::Member_Int_Const_Called);
+      CHECK(parameter_correct);
+    }
+#endif
+
     //*************************************************************************
     TEST_FIXTURE(SetupFixture, test_member_reference_compile_time)
     {
@@ -1431,6 +1982,43 @@ namespace
       CHECK(*itr != d2);
       CHECK(*itr == d3);
     }
+
+#if defined(ETL_NEGATIVE_TEST_DELEGATE_BAD_RETURN)
+    //*************************************************************************
+    // Triggers: return type not convertible (void -> int)
+    TEST(test_delegate_static_assert_bad_return)
+    {
+      auto bad = [](int) { /* returns void */ };
+      // static_assert in lambda_stub/const_lambda_stub should trigger:
+      // "etl::delegate: bound lambda/functor is not compatible with the delegate signature"
+      auto d = etl::delegate<int(int)>::create(bad);
+      (void)d;
+    }
+#endif
+
+#if defined(ETL_NEGATIVE_TEST_DELEGATE_RVALUE_PARAM_MISMATCH_NONCONST)
+    //*************************************************************************
+    // Triggers: parameter ref-qualification mismatch (expects rvalue, lambda takes lvalue ref)
+    TEST(test_delegate_static_assert_param_mismatch_nonconst)
+    {
+      auto bad = [](int&) { /* needs lvalue */ };
+      // Not invocable with int&&, so is_compatible_callable is false -> static_assert fires
+      auto d = etl::delegate<void(int&&)>::create(bad);
+      (void)d;
+    }
+#endif
+
+#if defined(ETL_NEGATIVE_TEST_DELEGATE_RVALUE_PARAM_MISMATCH_CONST)
+    //*************************************************************************
+    // Same as above, but binds a const lambda to hit const_lambda_stub
+    TEST(test_delegate_static_assert_param_mismatch_const)
+    {
+      const auto bad = [](int&) { /* needs lvalue */ };
+      // Not invocable with int&&, so is_compatible_callable is false -> static_assert fires
+      auto d = etl::delegate<void(int&&)>::create(bad);
+      (void)d;
+    }
+#endif
   };
 }
 
