@@ -70,7 +70,7 @@ namespace
   bool parameter_correct = false;
 
   //*****************************************************************************
-  // Test data structure.
+  // Object data structure.
   //*****************************************************************************
   struct Data
   {
@@ -137,7 +137,7 @@ namespace
   //*****************************************************************************
   // The test class with member functions.
   //*****************************************************************************
-  class Test
+  class Object
   {
   public:
 
@@ -208,8 +208,8 @@ namespace
     return a * 2;
   }
 
-  Test test_static;
-  const Test const_test_static;
+  Object test_static;
+  const Object const_test_static;
 }
 
 namespace
@@ -297,9 +297,9 @@ namespace
     //*************************************************************************
     TEST_FIXTURE(SetupFixture, test_member_operator_void)
     {
-      Test test;
+      Object object;
 
-      etl_cpp03::delegate<void(void)> d(test);
+      etl_cpp03::delegate<void(void)> d(object);
 
       d();
 
@@ -309,9 +309,9 @@ namespace
     //*************************************************************************
     TEST_FIXTURE(SetupFixture, test_member_operator_void_create)
     {
-      Test test;
+      Object object;
 
-      auto d = etl_cpp03::delegate<void(void)>::create(test);
+      auto d = etl_cpp03::delegate<void(void)>::create(object);
 
       d();
 
@@ -321,9 +321,9 @@ namespace
     //*************************************************************************
     TEST_FIXTURE(SetupFixture, test_member_operator_void_const)
     {
-      const Test test;
+      const Object object;
 
-      etl_cpp03::delegate<void(void)> d(test);
+      etl_cpp03::delegate<void(void)> d(object);
 
       d();
 
@@ -334,7 +334,7 @@ namespace
     //*************************************************************************
     TEST_FIXTURE(SetupFixture, test_member_operator_void_compile_time)
     {
-      auto d = etl_cpp03::delegate<void(void)>::create<Test, test_static>();
+      auto d = etl_cpp03::delegate<void(void)>::create<Object, test_static>();
 
       d();
 
@@ -344,7 +344,7 @@ namespace
     //*************************************************************************
     TEST_FIXTURE(SetupFixture, test_member_operator_void_compile_time_const)
     {
-      auto d = etl_cpp03::delegate<void(void)>::create<const Test, const_test_static>();
+      auto d = etl_cpp03::delegate<void(void)>::create<const Object, const_test_static>();
 
       d();
 
@@ -355,11 +355,11 @@ namespace
     //*************************************************************************
     TEST_FIXTURE(SetupFixture, test_assignment_member_operator_void)
     {
-      Test test;
+      Object object;
 
       etl_cpp03::delegate<void(void)> d;
 
-      d = test;
+      d = object;
 
       d();
 
@@ -369,9 +369,9 @@ namespace
     //*************************************************************************
     TEST_FIXTURE(SetupFixture, test_member_void)
     {
-      Test test;
+      Object object;
 
-      auto d = etl_cpp03::delegate<void(void)>::create<Test, &Test::member_void>(test);
+      auto d = etl_cpp03::delegate<void(void)>::create<Object, &Object::member_void>(object);
 
       d();
 
@@ -381,9 +381,9 @@ namespace
     //*************************************************************************
     TEST_FIXTURE(SetupFixture, test_member_void_const)
     {
-      const Test test;
+      const Object object;
 
-      auto d = etl_cpp03::delegate<void(void)>::create<Test, &Test::member_void_const>(test);
+      auto d = etl_cpp03::delegate<void(void)>::create<Object, &Object::member_void_const>(object);
 
       d();
 
@@ -393,9 +393,9 @@ namespace
     //*************************************************************************
     TEST_FIXTURE(SetupFixture, test_member_int)
     {
-      Test test;
+      Object object;
 
-      auto d = etl_cpp03::delegate<void(int)>::create<Test, &Test::member_int>(test);
+      auto d = etl_cpp03::delegate<void(int)>::create<Object, &Object::member_int>(object);
 
       d(VALUE1);
 
@@ -406,9 +406,9 @@ namespace
     //*************************************************************************
     TEST_FIXTURE(SetupFixture, test_member_int_const)
     {
-      const Test test;
+      const Object object;
 
-      auto d = etl_cpp03::delegate<void(int)>::create<Test, &Test::member_int_const>(test);
+      auto d = etl_cpp03::delegate<void(int)>::create<Object, &Object::member_int_const>(object);
 
       d(VALUE1);
 
@@ -419,8 +419,8 @@ namespace
     //*************************************************************************
     TEST_FIXTURE(SetupFixture, test_member_reference)
     {
-      Test test;
-      auto d = etl_cpp03::delegate<void(const Data&)>::create<Test, &Test::member_reference>(test);
+      Object object;
+      auto d = etl_cpp03::delegate<void(const Data&)>::create<Object, &Object::member_reference>(object);
 
       Data data;
       data.d = VALUE1;
@@ -434,8 +434,8 @@ namespace
     //*************************************************************************
     TEST_FIXTURE(SetupFixture, test_member_reference_const)
     {
-      const Test test;
-      auto d = etl_cpp03::delegate<void(const Data&)>::create<Test, &Test::member_reference_const>(test);
+      const Object object;
+      auto d = etl_cpp03::delegate<void(const Data&)>::create<Object, &Object::member_reference_const>(object);
 
       Data data;
       data.d = VALUE1;
@@ -449,7 +449,7 @@ namespace
     //*************************************************************************
     TEST_FIXTURE(SetupFixture, test_member_static)
     {
-      auto d = etl_cpp03::delegate<void(const Data&)>::create<Test::member_static>();
+      auto d = etl_cpp03::delegate<void(const Data&)>::create<Object::member_static>();
 
       Data data;
       data.d = VALUE1;
@@ -464,7 +464,17 @@ namespace
     //*************************************************************************
     TEST_FIXTURE(SetupFixture, test_member_void_compile_time)
     {
-      auto d = etl_cpp03::delegate<void(void)>::create<Test, test_static, &Test::member_void>();
+      auto d = etl_cpp03::delegate<void(void)>::create<Object, test_static, &Object::member_void>();
+
+      d();
+
+      CHECK(function_called == FunctionCalled::Member_Void_Called);
+    }
+
+    //*************************************************************************
+    TEST_FIXTURE(SetupFixture, test_member_void_compile_time_new_api)
+    {
+      auto d = etl_cpp03::delegate<void(void)>::create<Object, &Object::member_void, test_static>();
 
       d();
 
@@ -474,7 +484,17 @@ namespace
     //*************************************************************************
     TEST_FIXTURE(SetupFixture, test_member_void_const_compile_time)
     {
-      auto d = etl_cpp03::delegate<void(void)>::create<Test, const_test_static, &Test::member_void_const>();
+      auto d = etl_cpp03::delegate<void(void)>::create<Object, const_test_static, &Object::member_void_const>();
+
+      d();
+
+      CHECK(function_called == FunctionCalled::Member_Void_Const_Called);
+    }
+
+    //*************************************************************************
+    TEST_FIXTURE(SetupFixture, test_member_void_const_compile_time_new_api)
+    {
+      auto d = etl_cpp03::delegate<void(void)>::create<Object, &Object::member_void_const, const_test_static>();
 
       d();
 
@@ -484,7 +504,18 @@ namespace
     //*************************************************************************
     TEST_FIXTURE(SetupFixture, test_member_int_compile_time)
     {
-      auto d = etl_cpp03::delegate<void(int)>::create<Test, test_static, &Test::member_int>();
+      auto d = etl_cpp03::delegate<void(int)>::create<Object, test_static, &Object::member_int>();
+
+      d(VALUE1);
+
+      CHECK(function_called == FunctionCalled::Member_Int_Called);
+      CHECK(parameter_correct);
+    }
+
+    //*************************************************************************
+    TEST_FIXTURE(SetupFixture, test_member_int_compile_time_new_api)
+    {
+      auto d = etl_cpp03::delegate<void(int)>::create<Object, &Object::member_int, test_static>();
 
       d(VALUE1);
 
@@ -495,7 +526,18 @@ namespace
     //*************************************************************************
     TEST_FIXTURE(SetupFixture, test_member_int_const_compile_time)
     {
-      auto d = etl_cpp03::delegate<void(int)>::create<Test, const_test_static, &Test::member_int_const>();
+      auto d = etl_cpp03::delegate<void(int)>::create<Object, const_test_static, &Object::member_int_const>();
+
+      d(VALUE1);
+
+      CHECK(function_called == FunctionCalled::Member_Int_Const_Called);
+      CHECK(parameter_correct);
+    }
+
+    //*************************************************************************
+    TEST_FIXTURE(SetupFixture, test_member_int_const_compile_time_new_api)
+    {
+      auto d = etl_cpp03::delegate<void(int)>::create<Object, &Object::member_int_const, const_test_static>();
 
       d(VALUE1);
 
@@ -506,7 +548,21 @@ namespace
     //*************************************************************************
     TEST_FIXTURE(SetupFixture, test_member_reference_compile_time)
     {
-      auto d = etl_cpp03::delegate<void(const Data&)>::create<Test, test_static, &Test::member_reference>();
+      auto d = etl_cpp03::delegate<void(const Data&)>::create<Object, test_static, &Object::member_reference>();
+
+      Data data;
+      data.d = VALUE1;
+
+      d(data);
+
+      CHECK(function_called == FunctionCalled::Member_Reference_Called);
+      CHECK(parameter_correct);
+    }
+
+    //*************************************************************************
+    TEST_FIXTURE(SetupFixture, test_member_reference_compile_time_new_api)
+    {
+      auto d = etl_cpp03::delegate<void(const Data&)>::create<Object, &Object::member_reference, test_static>();
 
       Data data;
       data.d = VALUE1;
@@ -520,7 +576,21 @@ namespace
     //*************************************************************************
     TEST_FIXTURE(SetupFixture, test_member_reference_const_compile_time)
     {
-      auto d = etl_cpp03::delegate<void(const Data&)>::create<Test, const_test_static, &Test::member_reference_const>();
+      auto d = etl_cpp03::delegate<void(const Data&)>::create<Object, const_test_static, &Object::member_reference_const>();
+
+      Data data;
+      data.d = VALUE1;
+
+      d(data);
+
+      CHECK(function_called == FunctionCalled::Member_Reference_Const_Called);
+      CHECK(parameter_correct);
+    }
+
+    //*************************************************************************
+    TEST_FIXTURE(SetupFixture, test_member_reference_const_compile_time_new_api)
+    {
+      auto d = etl_cpp03::delegate<void(const Data&)>::create<Object, &Object::member_reference_const, const_test_static>();
 
       Data data;
       data.d = VALUE1;
@@ -560,10 +630,10 @@ namespace
     //*************************************************************************
     TEST_FIXTURE(SetupFixture, test_set_member_reference)
     {
-      Test test;
+      Object object;
       etl_cpp03::delegate<void(const Data&)> d;
       
-      d.set<Test, &Test::member_reference>(test);
+      d.set<Object, &Object::member_reference>(object);
 
       Data data;
       data.d = VALUE1;
@@ -577,10 +647,10 @@ namespace
     //*************************************************************************
     TEST_FIXTURE(SetupFixture, test_set_const_member_reference)
     {
-      Test test;
+      Object object;
       etl_cpp03::delegate<void(const Data&)> d;
 
-      d.set<Test, &Test::member_reference_const>(test);
+      d.set<Object, &Object::member_reference_const>(object);
 
       Data data;
       data.d = VALUE1;
@@ -596,7 +666,23 @@ namespace
     {
       etl_cpp03::delegate<void(const Data&)> d;
 
-      d.set<Test, test_static, &Test::member_reference>();
+      d.set<Object, test_static, &Object::member_reference>();
+
+      Data data;
+      data.d = VALUE1;
+
+      d(data);
+
+      CHECK(function_called == FunctionCalled::Member_Reference_Called);
+      CHECK(parameter_correct);
+    }
+
+    //*************************************************************************
+    TEST_FIXTURE(SetupFixture, test_set_member_reference_compile_time_new_api)
+    {
+      etl_cpp03::delegate<void(const Data&)> d;
+
+      d.set<Object, &Object::member_reference, test_static>();
 
       Data data;
       data.d = VALUE1;
@@ -612,7 +698,23 @@ namespace
     {
       etl_cpp03::delegate<void(const Data&)> d;
 
-      d.set<Test, const_test_static, &Test::member_reference_const>();
+      d.set<Object, const_test_static, &Object::member_reference_const>();
+
+      Data data;
+      data.d = VALUE1;
+
+      d(data);
+
+      CHECK(function_called == FunctionCalled::Member_Reference_Const_Called);
+      CHECK(parameter_correct);
+    }
+
+    //*************************************************************************
+    TEST_FIXTURE(SetupFixture, test_set_member_reference_const_compile_time_new_api)
+    {
+      etl_cpp03::delegate<void(const Data&)> d;
+
+      d.set<Object, &Object::member_reference_const, const_test_static>();
 
       Data data;
       data.d = VALUE1;
@@ -627,9 +729,9 @@ namespace
     //*************************************************************************
     TEST_FIXTURE(SetupFixture, test_copy_construct)
     {
-      Test test;
+      Object object;
 
-      auto d1 = etl_cpp03::delegate<void(int)>::create<Test, &Test::member_int>(test);
+      auto d1 = etl_cpp03::delegate<void(int)>::create<Object, &Object::member_int>(object);
       auto d2(d1);
 
       d2(VALUE1);
@@ -641,9 +743,9 @@ namespace
     //*************************************************************************
     TEST_FIXTURE(SetupFixture, test_assignment)
     {
-      Test test;
+      Object object;
 
-      auto d1 = etl_cpp03::delegate<void(int)>::create<Test, &Test::member_int>(test);
+      auto d1 = etl_cpp03::delegate<void(int)>::create<Object, &Object::member_int>(object);
       etl_cpp03::delegate<void(int)> d2;
 
       d2 = d1;
@@ -657,9 +759,9 @@ namespace
     //*************************************************************************
     TEST_FIXTURE(SetupFixture, test_delegate_equal)
     {
-      Test test;
+      Object object;
 
-      auto d1 = etl_cpp03::delegate<void(int)>::create<Test, &Test::member_int>(test);
+      auto d1 = etl_cpp03::delegate<void(int)>::create<Object, &Object::member_int>(object);
       auto d2 = d1;
 
       CHECK(d1 == d2);
@@ -668,10 +770,10 @@ namespace
     //*************************************************************************
     TEST_FIXTURE(SetupFixture, test_delegate_not_equal)
     {
-      Test test;
+      Object object;
 
-      auto d1 = etl_cpp03::delegate<void(int)>::create<Test, &Test::member_int>(test);
-      auto d2 = etl_cpp03::delegate<void(int)>::create<Test, &Test::member_int_const>(test);;
+      auto d1 = etl_cpp03::delegate<void(int)>::create<Object, &Object::member_int>(object);
+      auto d2 = etl_cpp03::delegate<void(int)>::create<Object, &Object::member_int_const>(object);;
 
       CHECK(d1 != d2);
     }
@@ -776,12 +878,12 @@ namespace
     //*************************************************************************
     TEST_FIXTURE(SetupFixture, test_delegate_identification)
     {
-      Test test1;
-      Test test2;
+      Object test1;
+      Object test2;
 
       auto d1 = etl_cpp03::delegate<void(int)>::create<free_int>();
-      auto d2 = etl_cpp03::delegate<void(int)>::create<Test, &Test::member_int>(test1);
-      auto d3 = etl_cpp03::delegate<void(int)>::create<Test, &Test::member_int>(test2);
+      auto d2 = etl_cpp03::delegate<void(int)>::create<Object, &Object::member_int>(test1);
+      auto d3 = etl_cpp03::delegate<void(int)>::create<Object, &Object::member_int>(test2);
 
       etl_cpp03::delegate<void(int)> d4;
 
@@ -812,7 +914,7 @@ namespace
       CHECK(*itr != d2);
       CHECK(*itr == d3);
 
-      d4 = etl_cpp03::delegate<void(int)>::create<Test, &Test::member_int>(test2); // Same as d3
+      d4 = etl_cpp03::delegate<void(int)>::create<Object, &Object::member_int>(test2); // Same as d3
       itr = std::find(delegate_list.begin(), delegate_list.end(), d4);
       CHECK(*itr != d1);
       CHECK(*itr != d2);
