@@ -45,8 +45,10 @@ namespace
       CHECK_EQUAL(STD_NL::digits, ETL_NL::digits);
       CHECK_EQUAL(STD_NL::digits10, ETL_NL::digits10);
       CHECK_EQUAL(STD_NL::epsilon(), ETL_NL::epsilon());
+#if ETL_NOT_USING_CPP23
       CHECK_EQUAL(int(STD_NL::has_denorm), int(ETL_NL::has_denorm));
       CHECK_EQUAL(STD_NL::has_denorm_loss, ETL_NL::has_denorm_loss);
+#endif
       CHECK_EQUAL(STD_NL::has_infinity,      ETL_NL::has_infinity);
       CHECK_EQUAL(STD_NL::has_quiet_NaN,     ETL_NL::has_quiet_NaN);
       CHECK_EQUAL(STD_NL::has_signaling_NaN, ETL_NL::has_signaling_NaN);
@@ -84,8 +86,10 @@ namespace
       CHECK_EQUAL(STD_NL::digits,            ETL_NL::digits);
       CHECK_EQUAL(STD_NL::digits10,          ETL_NL::digits10);
       CHECK_EQUAL(STD_NL::epsilon(),         ETL_NL::epsilon());
+#if ETL_NOT_USING_CPP23
       CHECK_EQUAL(int(STD_NL::has_denorm),   int(ETL_NL::has_denorm));
       CHECK_EQUAL(STD_NL::has_denorm_loss,   ETL_NL::has_denorm_loss);
+#endif
       CHECK_EQUAL(STD_NL::has_infinity,      ETL_NL::has_infinity);
       CHECK_EQUAL(STD_NL::has_quiet_NaN,     ETL_NL::has_quiet_NaN);
       CHECK_EQUAL(STD_NL::has_signaling_NaN, ETL_NL::has_signaling_NaN);
@@ -123,8 +127,10 @@ namespace
       CHECK_EQUAL(STD_NL::digits,            ETL_NL::digits);
       CHECK_EQUAL(STD_NL::digits10,          ETL_NL::digits10);
       CHECK_EQUAL(STD_NL::epsilon(),         ETL_NL::epsilon());
+#if ETL_NOT_USING_CPP23
       CHECK_EQUAL(int(STD_NL::has_denorm),   int(ETL_NL::has_denorm));
       CHECK_EQUAL(STD_NL::has_denorm_loss,   ETL_NL::has_denorm_loss);
+#endif
       CHECK_EQUAL(STD_NL::has_infinity,      ETL_NL::has_infinity);
       CHECK_EQUAL(STD_NL::has_quiet_NaN,     ETL_NL::has_quiet_NaN);
       CHECK_EQUAL(STD_NL::has_signaling_NaN, ETL_NL::has_signaling_NaN);
@@ -162,8 +168,10 @@ namespace
       CHECK_EQUAL(STD_NL::digits,            ETL_NL::digits);
       CHECK_EQUAL(STD_NL::digits10,          ETL_NL::digits10);
       CHECK_EQUAL(STD_NL::epsilon(),         ETL_NL::epsilon());
+#if ETL_NOT_USING_CPP23
       CHECK_EQUAL(int(STD_NL::has_denorm),   int(ETL_NL::has_denorm));
       CHECK_EQUAL(STD_NL::has_denorm_loss,   ETL_NL::has_denorm_loss);
+#endif
       CHECK_EQUAL(STD_NL::has_infinity,      ETL_NL::has_infinity);
       CHECK_EQUAL(STD_NL::has_quiet_NaN,     ETL_NL::has_quiet_NaN);
       CHECK_EQUAL(STD_NL::has_signaling_NaN, ETL_NL::has_signaling_NaN);
@@ -201,8 +209,10 @@ namespace
       CHECK_EQUAL(STD_NL::digits,            ETL_NL::digits);
       CHECK_EQUAL(STD_NL::digits10,          ETL_NL::digits10);
       CHECK_EQUAL(STD_NL::epsilon(),         ETL_NL::epsilon());
+#if ETL_NOT_USING_CPP23
       CHECK_EQUAL(int(STD_NL::has_denorm),   int(ETL_NL::has_denorm));
       CHECK_EQUAL(STD_NL::has_denorm_loss,   ETL_NL::has_denorm_loss);
+#endif
       CHECK_EQUAL(STD_NL::has_infinity,      ETL_NL::has_infinity);
       CHECK_EQUAL(STD_NL::has_quiet_NaN,     ETL_NL::has_quiet_NaN);
       CHECK_EQUAL(STD_NL::has_signaling_NaN, ETL_NL::has_signaling_NaN);
@@ -240,8 +250,10 @@ namespace
       CHECK_EQUAL(STD_NL::digits,            ETL_NL::digits);
       CHECK_EQUAL(STD_NL::digits10,          ETL_NL::digits10);
       CHECK_EQUAL(STD_NL::epsilon(),         ETL_NL::epsilon());
+#if ETL_NOT_USING_CPP23
       CHECK_EQUAL(int(STD_NL::has_denorm),   int(ETL_NL::has_denorm));
       CHECK_EQUAL(STD_NL::has_denorm_loss,   ETL_NL::has_denorm_loss);
+#endif
       CHECK_EQUAL(STD_NL::has_infinity,      ETL_NL::has_infinity);
       CHECK_EQUAL(STD_NL::has_quiet_NaN,     ETL_NL::has_quiet_NaN);
       CHECK_EQUAL(STD_NL::has_signaling_NaN, ETL_NL::has_signaling_NaN);
@@ -279,8 +291,10 @@ namespace
       CHECK_EQUAL(STD_NL::digits,            ETL_NL::digits);
       CHECK_EQUAL(STD_NL::digits10,          ETL_NL::digits10);
       CHECK_EQUAL(STD_NL::epsilon(),         ETL_NL::epsilon());
+#if ETL_NOT_USING_CPP23
       CHECK_EQUAL(int(STD_NL::has_denorm),   int(ETL_NL::has_denorm));
       CHECK_EQUAL(STD_NL::has_denorm_loss,   ETL_NL::has_denorm_loss);
+#endif
       CHECK_EQUAL(STD_NL::has_infinity,      ETL_NL::has_infinity);
       CHECK_EQUAL(STD_NL::has_quiet_NaN,     ETL_NL::has_quiet_NaN);
       CHECK_EQUAL(STD_NL::has_signaling_NaN, ETL_NL::has_signaling_NaN);
@@ -318,8 +332,10 @@ namespace
       CHECK_EQUAL(STD_NL::digits,            ETL_NL::digits);
       CHECK_EQUAL(STD_NL::digits10,          ETL_NL::digits10);
       CHECK_EQUAL(STD_NL::epsilon(),         ETL_NL::epsilon());
+#if ETL_NOT_USING_CPP23
       CHECK_EQUAL(int(STD_NL::has_denorm),   int(ETL_NL::has_denorm));
       CHECK_EQUAL(STD_NL::has_denorm_loss,   ETL_NL::has_denorm_loss);
+#endif
       CHECK_EQUAL(STD_NL::has_infinity,      ETL_NL::has_infinity);
       CHECK_EQUAL(STD_NL::has_quiet_NaN,     ETL_NL::has_quiet_NaN);
       CHECK_EQUAL(STD_NL::has_signaling_NaN, ETL_NL::has_signaling_NaN);
@@ -357,8 +373,10 @@ namespace
       CHECK_EQUAL(STD_NL::digits,            ETL_NL::digits);
       CHECK_EQUAL(STD_NL::digits10,          ETL_NL::digits10);
       CHECK_EQUAL(STD_NL::epsilon(),         ETL_NL::epsilon());
+#if ETL_NOT_USING_CPP23
       CHECK_EQUAL(int(STD_NL::has_denorm),   int(ETL_NL::has_denorm));
       CHECK_EQUAL(STD_NL::has_denorm_loss,   ETL_NL::has_denorm_loss);
+#endif
       CHECK_EQUAL(STD_NL::has_infinity,      ETL_NL::has_infinity);
       CHECK_EQUAL(STD_NL::has_quiet_NaN,     ETL_NL::has_quiet_NaN);
       CHECK_EQUAL(STD_NL::has_signaling_NaN, ETL_NL::has_signaling_NaN);
@@ -396,8 +414,10 @@ namespace
       CHECK_EQUAL(STD_NL::digits,            ETL_NL::digits);
       CHECK_EQUAL(STD_NL::digits10,          ETL_NL::digits10);
       CHECK_EQUAL(STD_NL::epsilon(),         ETL_NL::epsilon());
+#if ETL_NOT_USING_CPP23
       CHECK_EQUAL(int(STD_NL::has_denorm),   int(ETL_NL::has_denorm));
       CHECK_EQUAL(STD_NL::has_denorm_loss,   ETL_NL::has_denorm_loss);
+#endif
       CHECK_EQUAL(STD_NL::has_infinity,      ETL_NL::has_infinity);
       CHECK_EQUAL(STD_NL::has_quiet_NaN,     ETL_NL::has_quiet_NaN);
       CHECK_EQUAL(STD_NL::has_signaling_NaN, ETL_NL::has_signaling_NaN);
@@ -435,8 +455,10 @@ namespace
       CHECK_EQUAL(STD_NL::digits,            ETL_NL::digits);
       CHECK_EQUAL(STD_NL::digits10,          ETL_NL::digits10);
       CHECK_EQUAL(STD_NL::epsilon(),         ETL_NL::epsilon());
+#if ETL_NOT_USING_CPP23
       CHECK_EQUAL(int(STD_NL::has_denorm),   int(ETL_NL::has_denorm));
       CHECK_EQUAL(STD_NL::has_denorm_loss,   ETL_NL::has_denorm_loss);
+#endif
       CHECK_EQUAL(STD_NL::has_infinity,      ETL_NL::has_infinity);
       CHECK_EQUAL(STD_NL::has_quiet_NaN,     ETL_NL::has_quiet_NaN);
       CHECK_EQUAL(STD_NL::has_signaling_NaN, ETL_NL::has_signaling_NaN);
@@ -474,8 +496,10 @@ namespace
       CHECK_EQUAL(STD_NL::digits,            ETL_NL::digits);
       CHECK_EQUAL(STD_NL::digits10,          ETL_NL::digits10);
       CHECK_EQUAL(STD_NL::epsilon(),         ETL_NL::epsilon());
+#if ETL_NOT_USING_CPP23
       CHECK_EQUAL(int(STD_NL::has_denorm),   int(ETL_NL::has_denorm));
       CHECK_EQUAL(STD_NL::has_denorm_loss,   ETL_NL::has_denorm_loss);
+#endif
       CHECK_EQUAL(STD_NL::has_infinity,      ETL_NL::has_infinity);
       CHECK_EQUAL(STD_NL::has_quiet_NaN,     ETL_NL::has_quiet_NaN);
       CHECK_EQUAL(STD_NL::has_signaling_NaN, ETL_NL::has_signaling_NaN);
@@ -513,8 +537,10 @@ namespace
       CHECK_EQUAL(STD_NL::digits,            ETL_NL::digits);
       CHECK_EQUAL(STD_NL::digits10,          ETL_NL::digits10);
       CHECK_EQUAL(STD_NL::epsilon(),         ETL_NL::epsilon());
+#if ETL_NOT_USING_CPP23
       CHECK_EQUAL(int(STD_NL::has_denorm),   int(ETL_NL::has_denorm));
       CHECK_EQUAL(STD_NL::has_denorm_loss,   ETL_NL::has_denorm_loss);
+#endif
       CHECK_EQUAL(STD_NL::has_infinity,      ETL_NL::has_infinity);
       CHECK_EQUAL(STD_NL::has_quiet_NaN,     ETL_NL::has_quiet_NaN);
       CHECK_EQUAL(STD_NL::has_signaling_NaN, ETL_NL::has_signaling_NaN);
@@ -552,8 +578,10 @@ namespace
       CHECK_EQUAL(STD_NL::digits,            ETL_NL::digits);
       CHECK_EQUAL(STD_NL::digits10,          ETL_NL::digits10);
       CHECK_EQUAL(STD_NL::epsilon(),         ETL_NL::epsilon());
+#if ETL_NOT_USING_CPP23
       CHECK_EQUAL(int(STD_NL::has_denorm),   int(ETL_NL::has_denorm));
       CHECK_EQUAL(STD_NL::has_denorm_loss,   ETL_NL::has_denorm_loss);
+#endif
       CHECK_EQUAL(STD_NL::has_infinity,      ETL_NL::has_infinity);
       CHECK_EQUAL(STD_NL::has_quiet_NaN,     ETL_NL::has_quiet_NaN);
       CHECK_EQUAL(STD_NL::has_signaling_NaN, ETL_NL::has_signaling_NaN);
@@ -591,8 +619,10 @@ namespace
       CHECK_EQUAL(STD_NL::digits,            ETL_NL::digits);
       CHECK_EQUAL(STD_NL::digits10,          ETL_NL::digits10);
       CHECK_EQUAL(STD_NL::epsilon(),         ETL_NL::epsilon());
+#if ETL_NOT_USING_CPP23
       CHECK_EQUAL(int(STD_NL::has_denorm),   int(ETL_NL::has_denorm));
       CHECK_EQUAL(STD_NL::has_denorm_loss,   ETL_NL::has_denorm_loss);
+#endif
       CHECK_EQUAL(STD_NL::has_infinity,      ETL_NL::has_infinity);
       CHECK_EQUAL(STD_NL::has_quiet_NaN,     ETL_NL::has_quiet_NaN);
       CHECK_EQUAL(STD_NL::has_signaling_NaN, ETL_NL::has_signaling_NaN);
