@@ -29,7 +29,9 @@ SOFTWARE.
 #include "unit_test_framework.h"
 
 #include "etl/memory.h"
+#include "etl/list.h"
 #include "etl/debug_count.h"
+#include "etl/endianness.h"
 
 #include "data.h"
 
@@ -41,6 +43,7 @@ SOFTWARE.
 #include <stdint.h>
 #include <vector>
 #include <memory>
+#include <type_traits>
 
 namespace
 {
@@ -1175,9 +1178,20 @@ namespace
       uint32_t src[8] = { 0x12345678, 0x76543210, 0x01452367, 0x23670145, 0x67234501, 0x45016723, 0x01324576, 0x76453201 };
       uint32_t dst[8] = { 0, 0, 0, 0, 0, 0, 0, 0 };
 
-      etl::mem_copy(src, src + 8, dst);
-
+      uint32_t* result = etl::mem_copy(src, src + 8, dst);
       CHECK(std::equal(src, src + 8, dst));
+      CHECK(result == dst);
+    }
+
+    //*************************************************************************
+    TEST(test_mem_copy_const_pointer_const_pointer_pointer)
+    {
+      const uint32_t src[8] = { 0x12345678, 0x76543210, 0x01452367, 0x23670145, 0x67234501, 0x45016723, 0x01324576, 0x76453201 };
+      uint32_t dst[8] = { 0, 0, 0, 0, 0, 0, 0, 0 };
+
+      uint32_t* result = etl::mem_copy(src, src + 8, dst);
+      CHECK(std::equal(src, src + 8, dst));
+      CHECK(result == dst);
     }
 
     //*************************************************************************
@@ -1186,9 +1200,20 @@ namespace
       uint32_t src[8] = { 0x12345678, 0x76543210, 0x01452367, 0x23670145, 0x67234501, 0x45016723, 0x01324576, 0x76453201 };
       uint32_t dst[8] = { 0, 0, 0, 0, 0, 0, 0, 0 };
 
-      etl::mem_copy(src, 8, dst);
-
+      uint32_t* result = etl::mem_copy(src, 8, dst);
       CHECK(std::equal(src, src + 8, dst));
+      CHECK(result == dst);
+    }
+
+    //*************************************************************************
+    TEST(test_mem_copy_const_pointer_length_pointer)
+    {
+      const uint32_t src[8] = { 0x12345678, 0x76543210, 0x01452367, 0x23670145, 0x67234501, 0x45016723, 0x01324576, 0x76453201 };
+      uint32_t dst[8] = { 0, 0, 0, 0, 0, 0, 0, 0 };
+
+      uint32_t* result = etl::mem_copy(src, 8, dst);
+      CHECK(std::equal(src, src + 8, dst));
+      CHECK(result == dst);
     }
 
     //*************************************************************************
@@ -1197,9 +1222,22 @@ namespace
       uint32_t expected[8] = { 0x12345678, 0x76543210, 0x01452367, 0x23670145, 0x67234501, 0x45016723, 0x01324576, 0x76453201 };
       uint32_t data[12]    = { 0x12345678, 0x76543210, 0x01452367, 0x23670145, 0x67234501, 0x45016723, 0x01324576, 0x76453201, 0, 0, 0, 0 };
 
-      etl::mem_move(data, data + 8, data + 4);
-
+      uint32_t* result = etl::mem_move(data, data + 8, data + 4);
       CHECK(std::equal(expected, expected + 8, data + 4));
+      CHECK(result == data + 4);
+    }
+
+    //*************************************************************************
+    TEST(test_mem_move_const_pointer_const_pointer_pointer)
+    {
+      uint32_t expected[8] = { 0x12345678, 0x76543210, 0x01452367, 0x23670145, 0x67234501, 0x45016723, 0x01324576, 0x76453201 };
+      uint32_t data[12]    = { 0x12345678, 0x76543210, 0x01452367, 0x23670145, 0x67234501, 0x45016723, 0x01324576, 0x76453201, 0, 0, 0, 0 };
+      const uint32_t* data_begin = &data[0];
+      const uint32_t* data_end = &data[8];
+
+      uint32_t* result = etl::mem_move(data_begin, data_end, data + 4);
+      CHECK(std::equal(expected, expected + 8, data + 4));
+      CHECK(result == data + 4);
     }
 
     //*************************************************************************
@@ -1208,9 +1246,21 @@ namespace
       uint32_t expected[8] = { 0x12345678, 0x76543210, 0x01452367, 0x23670145, 0x67234501, 0x45016723, 0x01324576, 0x76453201 };
       uint32_t data[12]    = { 0x12345678, 0x76543210, 0x01452367, 0x23670145, 0x67234501, 0x45016723, 0x01324576, 0x76453201, 0, 0, 0, 0 };
 
-      etl::mem_move(data, 8, data + 4);
-
+      uint32_t* result = etl::mem_move(data, 8, data + 4);
       CHECK(std::equal(expected, expected + 8, data + 4));
+      CHECK(result == data + 4);
+    }
+
+    //*************************************************************************
+    TEST(test_mem_move_const_pointer_length_pointer)
+    {
+      uint32_t expected[8] = { 0x12345678, 0x76543210, 0x01452367, 0x23670145, 0x67234501, 0x45016723, 0x01324576, 0x76453201 };
+      uint32_t data[12]    = { 0x12345678, 0x76543210, 0x01452367, 0x23670145, 0x67234501, 0x45016723, 0x01324576, 0x76453201, 0, 0, 0, 0 };
+      const uint32_t* data_begin = &data[0];
+
+      uint32_t* result = etl::mem_move(data_begin, 8, data + 4);
+      CHECK(std::equal(expected, expected + 8, data + 4));
+      CHECK(result == data + 4);
     }
 
     //*************************************************************************
@@ -1220,7 +1270,33 @@ namespace
       uint32_t same[8] = { 0x12345678, 0x76543210, 0x01452367, 0x23670145, 0x67234501, 0x45016723, 0x01324576, 0x76453201 };
       uint32_t grtr[8] = { 0x12345678, 0x76543210, 0x01452367, 0x23670145, 0x67235501, 0x45016723, 0x01324576, 0x76453201 };
       uint32_t less[8] = { 0x12345678, 0x76543210, 0x01452367, 0x23670145, 0x67134501, 0x45016723, 0x01324576, 0x76453201 };
-      
+
+      CHECK(etl::mem_compare(data, data + 8, same) == 0);
+      CHECK(etl::mem_compare(data, data + 8, grtr) > 0);
+      CHECK(etl::mem_compare(data, data + 8, less) < 0);
+    }
+
+    //*************************************************************************
+    TEST(test_mem_compare_const_pointer_const_pointer_pointer)
+    {
+      const uint32_t data[8] = { 0x12345678, 0x76543210, 0x01452367, 0x23670145, 0x67234501, 0x45016723, 0x01324576, 0x76453201 };
+      uint32_t same[8] = { 0x12345678, 0x76543210, 0x01452367, 0x23670145, 0x67234501, 0x45016723, 0x01324576, 0x76453201 };
+      uint32_t grtr[8] = { 0x12345678, 0x76543210, 0x01452367, 0x23670145, 0x67235501, 0x45016723, 0x01324576, 0x76453201 };
+      uint32_t less[8] = { 0x12345678, 0x76543210, 0x01452367, 0x23670145, 0x67134501, 0x45016723, 0x01324576, 0x76453201 };
+
+      CHECK(etl::mem_compare(data, data + 8, same) == 0);
+      CHECK(etl::mem_compare(data, data + 8, grtr) > 0);
+      CHECK(etl::mem_compare(data, data + 8, less) < 0);
+    }
+
+    //*************************************************************************
+    TEST(test_mem_compare_const_pointer_const_pointer_const_pointer)
+    {
+      const uint32_t data[8] = { 0x12345678, 0x76543210, 0x01452367, 0x23670145, 0x67234501, 0x45016723, 0x01324576, 0x76453201 };
+      const uint32_t same[8] = { 0x12345678, 0x76543210, 0x01452367, 0x23670145, 0x67234501, 0x45016723, 0x01324576, 0x76453201 };
+      uint32_t grtr[8] = { 0x12345678, 0x76543210, 0x01452367, 0x23670145, 0x67235501, 0x45016723, 0x01324576, 0x76453201 };
+      uint32_t less[8] = { 0x12345678, 0x76543210, 0x01452367, 0x23670145, 0x67134501, 0x45016723, 0x01324576, 0x76453201 };
+
       CHECK(etl::mem_compare(data, data + 8, same) == 0);
       CHECK(etl::mem_compare(data, data + 8, grtr) > 0);
       CHECK(etl::mem_compare(data, data + 8, less) < 0);
@@ -1239,13 +1315,39 @@ namespace
       CHECK(etl::mem_compare(data, 8, less) < 0);
     }
 
+    //*************************************************************************
+    TEST(test_mem_compare_const_pointer_length_pointer)
+    {
+      const uint32_t data[8] = { 0x12345678, 0x76543210, 0x01452367, 0x23670145, 0x67234501, 0x45016723, 0x01324576, 0x76453201 };
+      uint32_t same[8] = { 0x12345678, 0x76543210, 0x01452367, 0x23670145, 0x67234501, 0x45016723, 0x01324576, 0x76453201 };
+      uint32_t grtr[8] = { 0x12345678, 0x76543210, 0x01452367, 0x23670145, 0x67235501, 0x45016723, 0x01324576, 0x76453201 };
+      uint32_t less[8] = { 0x12345678, 0x76543210, 0x01452367, 0x23670145, 0x67134501, 0x45016723, 0x01324576, 0x76453201 };
+
+      CHECK(etl::mem_compare(data, 8, same) == 0);
+      CHECK(etl::mem_compare(data, 8, grtr) > 0);
+      CHECK(etl::mem_compare(data, 8, less) < 0);
+    }
+
+    //*************************************************************************
+    TEST(test_mem_compare_const_pointer_length_const_pointer)
+    {
+      const uint32_t data[8] = { 0x12345678, 0x76543210, 0x01452367, 0x23670145, 0x67234501, 0x45016723, 0x01324576, 0x76453201 };
+      const uint32_t same[8] = { 0x12345678, 0x76543210, 0x01452367, 0x23670145, 0x67234501, 0x45016723, 0x01324576, 0x76453201 };
+      const uint32_t grtr[8] = { 0x12345678, 0x76543210, 0x01452367, 0x23670145, 0x67235501, 0x45016723, 0x01324576, 0x76453201 };
+      const uint32_t less[8] = { 0x12345678, 0x76543210, 0x01452367, 0x23670145, 0x67134501, 0x45016723, 0x01324576, 0x76453201 };
+
+      CHECK(etl::mem_compare(data, 8, same) == 0);
+      CHECK(etl::mem_compare(data, 8, grtr) > 0);
+      CHECK(etl::mem_compare(data, 8, less) < 0);
+    }
+
     //*************************************************************************
     TEST(test_mem_set_pointer_pointer)
     {
       uint32_t data[8]     = { 0, 0, 0, 0, 0, 0, 0, 0 };
       uint32_t expected[8] = { 0, 0x5A5A5A5A, 0x5A5A5A5A, 0x5A5A5A5A, 0x5A5A5A5A, 0, 0, 0 };
 
-      etl::mem_set(data + 1, data + 5, 0x5A);
+      etl::mem_set(data + 1, data + 5, (char)0x5A);
 
       CHECK(std::equal(expected, expected + 8, data));
     }
@@ -1256,7 +1358,7 @@ namespace
       uint32_t data[8] = { 0, 0, 0, 0, 0, 0, 0, 0 };
       uint32_t expected[8] = { 0, 0x5A5A5A5A, 0x5A5A5A5A, 0x5A5A5A5A, 0x5A5A5A5A, 0, 0, 0 };
 
-      etl::mem_set(data + 1, 4, 0x5A);
+      etl::mem_set(data + 1, 4, (char)0x5A);
 
       CHECK(std::equal(expected, expected + 8, data));
     }
@@ -1266,11 +1368,18 @@ namespace
     {
       uint32_t data[8] = { 0x12345678, 0x76543210, 0x01452367, 0x23670145, 0x67294501, 0x45016723, 0x01324576, 0x76453201 };
 
-      char *p1 = etl::mem_char(data, data + 8, 0x29);
-      char* p2 = etl::mem_char(data, data + 8, 0x99);
+      char *p1 = etl::mem_char(data, data + 8, (char)0x29);
+      char* p2 = etl::mem_char(data, data + 8, (char)0x99);
 
       CHECK_EQUAL(uint32_t(0x29), uint32_t(*p1));
-      CHECK((reinterpret_cast<char*>(data) + 18) == p1);
+      if (etl::endianness::value() == etl::endian::little)
+      {
+        CHECK((reinterpret_cast<char*>(data) + 18) == p1);
+      }
+      else
+      {
+        CHECK((reinterpret_cast<char*>(data) + 17) == p1);
+      }
       CHECK((reinterpret_cast<char*>(data) + 32) == p2);
     }
 
@@ -1279,11 +1388,18 @@ namespace
     {
       const uint32_t data[8] = { 0x12345678, 0x76543210, 0x01452367, 0x23670145, 0x67294501, 0x45016723, 0x01324576, 0x76453201 };
 
-      const char* p1 = etl::mem_char(data, data + 8, 0x29);
-      const char* p2 = etl::mem_char(data, data + 8, 0x99);
+      const char* p1 = etl::mem_char(data, data + 8, (char)0x29);
+      const char* p2 = etl::mem_char(data, data + 8, (char)0x99);
 
       CHECK_EQUAL(uint32_t(0x29), uint32_t(*p1));
-      CHECK((reinterpret_cast<const char*>(data) + 18) == p1);
+      if (etl::endianness::value() == etl::endian::little)
+      {
+        CHECK((reinterpret_cast<const char*>(data) + 18) == p1);
+      }
+      else
+      {
+        CHECK((reinterpret_cast<const char*>(data) + 17) == p1);
+      }
       CHECK((reinterpret_cast<const char*>(data) + 32) == p2);
     }
 
@@ -1292,11 +1408,18 @@ namespace
     {
       uint32_t data[8] = { 0x12345678, 0x76543210, 0x01452367, 0x23670145, 0x67294501, 0x45016723, 0x01324576, 0x76453201 };
 
-      char* p1 = etl::mem_char(data, 8, 0x29);
-      char* p2 = etl::mem_char(data, 8, 0x99);
+      char* p1 = etl::mem_char(data, 8, (char)0x29);
+      char* p2 = etl::mem_char(data, 8, (char)0x99);
 
       CHECK_EQUAL(uint32_t(0x29), uint32_t(*p1));
-      CHECK((reinterpret_cast<char*>(data) + 18) == p1);
+      if (etl::endianness::value() == etl::endian::little)
+      {
+        CHECK((reinterpret_cast<char*>(data) + 18) == p1);
+      }
+      else
+      {
+        CHECK((reinterpret_cast<char*>(data) + 17) == p1);
+      }
       CHECK((reinterpret_cast<char*>(data) + 32) == p2);
     }
 
@@ -1305,16 +1428,23 @@ namespace
     {
       const uint32_t data[8] = { 0x12345678, 0x76543210, 0x01452367, 0x23670145, 0x67294501, 0x45016723, 0x01324576, 0x76453201 };
 
-      const char* p1 = etl::mem_char(data, 8, 0x29);
-      const char* p2 = etl::mem_char(data, 8, 0x99);
+      const char* p1 = etl::mem_char(data, 8, (char)0x29);
+      const char* p2 = etl::mem_char(data, 8, (char)0x99);
 
       CHECK_EQUAL(uint32_t(0x29), uint32_t(*p1));
-      CHECK((reinterpret_cast<const char*>(data) + 18) == p1);
+      if (etl::endianness::value() == etl::endian::little)
+      {
+        CHECK((reinterpret_cast<const char*>(data) + 18) == p1);
+      }
+      else
+      {
+        CHECK((reinterpret_cast<const char*>(data) + 17) == p1);
+      }
       CHECK((reinterpret_cast<const char*>(data) + 32) == p2);
     }
 
     //*************************************************************************
-    class Base 
+    class Base
     {
     public:
       virtual ~Base() {};
@@ -1323,21 +1453,21 @@ namespace
 
     static bool function_was_called = false;
 
-    class Derived : public Base 
+    class Derived : public Base
     {
     public:
-      Derived() 
+      Derived()
       {
         function_was_called = false;
       }
 
-      void function() 
+      void function()
       {
         function_was_called = true;
       }
     };
 
-    void call(etl::unique_ptr<Base> ptr) 
+    void call(etl::unique_ptr<Base> ptr)
     {
       ptr->function();
     }
@@ -1348,13 +1478,13 @@ namespace
 
       etl::unique_ptr<Derived> ptr(new Derived());
       CHECK(ptr.get() != ETL_NULLPTR);
-      
+
       call(etl::move(ptr));
       CHECK(function_was_called);
       CHECK(ptr.get() == ETL_NULLPTR);
     }
 
-    //*************************************************************************
+
     struct Flags
     {
       Flags()
@@ -1401,7 +1531,7 @@ namespace
         int a;
         int b;
       };
-     
+
       alignas(Data) char buffer1[sizeof(Data)];
       char* pbuffer1 = buffer1;
 
@@ -1452,14 +1582,14 @@ namespace
       CHECK_FALSE(flags.destructed);
       CHECK_EQUAL(1, rdata1b.a);
       CHECK_EQUAL(2, rdata1b.b);
-      
+
       flags.Clear();
       Data& rdata2b = etl::get_object_at<Data>(pbuffer2b);
       CHECK_FALSE(flags.constructed);
       CHECK_FALSE(flags.destructed);
       CHECK_EQUAL(data2.a, rdata2b.a);
       CHECK_EQUAL(data2.b, rdata2b.b);
-      
+
       flags.Clear();
       Data& rdata3b = etl::get_object_at<Data>(pbuffer3b);
       CHECK_FALSE(flags.constructed);
@@ -1483,6 +1613,33 @@ namespace
       CHECK_TRUE(flags.destructed);
     }
 
+    TEST(test_get_object_at_const_specialization)
+    {
+      struct Data
+      {
+        Data()
+          : a(1)
+          , b(2)
+        {
+          flags.constructed = true;
+        }
+
+        ~Data() = default;
+
+        int a;
+        int b;
+      };
+
+      std::array<uint8_t, 32U> buffer{};
+      etl::construct_object_at(buffer.data(), Data());
+      const void* bufferPointer = buffer.data();
+
+      const Data& rdata = etl::get_object_at<Data>(bufferPointer);
+      CHECK_TRUE(flags.constructed);
+      CHECK_TRUE(rdata.a == 1);
+      CHECK_TRUE(rdata.b == 2);
+    }
+
     TEST(test_construct_get_destroy_object_misaligned)
     {
       struct Data
@@ -1527,5 +1684,20 @@ namespace
 
       CHECK_THROW(etl::destroy_object_at<Data>(pbuffer1), etl::alignment_error);
     }
+
+    //*************************************************************************
+    TEST(test_to_address)
+    {
+      int  i;
+      int* pi = &i;
+
+      etl::list<int, 4> container = { 1, 2, 3, 4 };
+      etl::list<int, 4>::iterator itr = container.begin();
+      std::advance(itr, 2);
+      int* plist_item = &*itr;
+
+      CHECK_EQUAL(&i, etl::to_address(pi));
+      CHECK_EQUAL(plist_item, etl::to_address(itr));
+    }
   };
 }
