@@ -168,6 +168,38 @@ namespace
   Router1 router1;
   Bus1    bus1;
 
+  using event_callback_type = etl::imessage_timer_locked::event_callback_type;
+
+  class TimerInsertRemoveTest
+  {
+  public:
+    uint32_t inserted;
+    uint32_t removed;
+    TimerInsertRemoveTest() : inserted(0), removed(0)
+    {
+    }
+
+    void insert_handler(etl::timer::id::type id_)
+    {
+      (void)id_;
+      inserted++;
+    }
+
+    void remove_handler(etl::timer::id::type id_)
+    {
+      (void)id_;
+      removed++;
+    }
+
+    void clear(void)
+    {
+      inserted = 0;
+      removed = 0;
+    }
+  };
+
+  TimerInsertRemoveTest timerInsertRemoveTest;
+
   using try_lock_type = etl::imessage_timer_locked::try_lock_type;
   using lock_type     = etl::imessage_timer_locked::lock_type;
   using unlock_type   = etl::imessage_timer_locked::unlock_type;
@@ -773,6 +805,7 @@ namespace
     //*************************************************************************
     TEST(message_timer_time_to_next_with_has_active_timer)
     {
+      timerInsertRemoveTest.clear();
       locks.clear();
       try_lock_type try_lock = try_lock_type::create<Locks, locks, &Locks::try_lock>();
       lock_type     lock     = lock_type::create<Locks, locks, &Locks::lock>();
@@ -784,29 +817,50 @@ namespace
       etl::timer::id::type id2 = timer_controller.register_timer(message2, router1, 23, etl::timer::mode::Single_Shot);
       etl::timer::id::type id3 = timer_controller.register_timer(message3, router1, 11, etl::timer::mode::Single_Shot);
 
+      timer_controller.set_insert_callback(event_callback_type::create<TimerInsertRemoveTest, timerInsertRemoveTest, &TimerInsertRemoveTest::insert_handler>());
+      timer_controller.set_remove_callback(event_callback_type::create<TimerInsertRemoveTest, timerInsertRemoveTest, &TimerInsertRemoveTest::remove_handler>());
+
       router1.clear();
 
       timer_controller.start(id1);
       timer_controller.start(id3);
       timer_controller.start(id2);
 
+      CHECK_EQUAL(3, timerInsertRemoveTest.inserted);
+      CHECK_EQUAL(0, timerInsertRemoveTest.removed);
+
       timer_controller.enable(true);
 
+      CHECK_EQUAL(3, timerInsertRemoveTest.inserted);
+      CHECK_EQUAL(0, timerInsertRemoveTest.removed);
+
       timer_controller.tick(11);
       CHECK_EQUAL(12, timer_controller.time_to_next());
       CHECK_TRUE(timer_controller.has_active_timer());
 
+      CHECK_EQUAL(3, timerInsertRemoveTest.inserted);
+      CHECK_EQUAL(1, timerInsertRemoveTest.removed);
+
       timer_controller.tick(23);
       CHECK_EQUAL(3, timer_controller.time_to_next());
       CHECK_TRUE(timer_controller.has_active_timer());
 
+      CHECK_EQUAL(3, timerInsertRemoveTest.inserted);
+      CHECK_EQUAL(2, timerInsertRemoveTest.removed);
+
       timer_controller.tick(2);
       CHECK_EQUAL(1, timer_controller.time_to_next());
       CHECK_TRUE(timer_controller.has_active_timer());
 
+      CHECK_EQUAL(3, timerInsertRemoveTest.inserted);
+      CHECK_EQUAL(2, timerInsertRemoveTest.removed);
+
       timer_controller.tick(1);
       CHECK_EQUAL(static_cast<etl::timer::interval::type>(etl::timer::interval::No_Active_Interval), timer_controller.time_to_next());
       CHECK_FALSE(timer_controller.has_active_timer());
+
+      CHECK_EQUAL(3, timerInsertRemoveTest.inserted);
+      CHECK_EQUAL(3, timerInsertRemoveTest.removed);
     }
 
     //*************************************************************************
