@@ -37,6 +37,7 @@ SOFTWARE.
 #include "etl/unaligned_type.h"
 #include "etl/pool.h"
 #include "etl/largest.h"
+#include "etl/memory.h"
 
 typedef TestDataDC<std::string>  Test_Data;
 typedef TestDataNDC<std::string> Test_Data2;
@@ -156,6 +157,39 @@ namespace
     return os;
   }
 
+  struct S
+  {
+    S()
+      : a(7), b(8) 
+    {
+      ++instance_count;
+    }
+
+    S(int a_, double b_)
+      : a(a_), b(b_) 
+    {
+      ++instance_count;
+    }
+
+    S(const S& other)
+      : a(other.a), b(other.b) 
+    {
+      ++instance_count;
+    }
+
+    ~S()
+    {
+      --instance_count;
+    }
+
+    int    a;
+    double b;
+
+    static int instance_count;
+  };
+
+  int S::instance_count = 0;
+
   SUITE(test_pool)
   {
     //*************************************************************************
@@ -735,4 +769,91 @@ namespace
     CHECK(!(begin != end));
     CHECK_EQUAL(etl::distance(begin, end), 0);
   }
+
+  //*************************************************************************
+  TEST(test_releaser_functor_with_unique_ptr)
+  {
+    etl::pool<S, 10> pool;  
+    auto pool_deleter = [&pool](S* ptr) { pool.release(ptr); };
+    using Unique = etl::unique_ptr<S, decltype(pool_deleter)>;
+
+    S::instance_count = 0;
+
+    CHECK_EQUAL(10, pool.available());
+
+    {
+      S* ps;
+
+      ps = pool.allocate();
+      ::new(ps) S(1, 2);
+      Unique us1(ps, pool_deleter);
+      CHECK_EQUAL(1, S::instance_count);
+      CHECK_EQUAL(1, us1->a);
+      CHECK_EQUAL(2, us1->b);
+      CHECK_EQUAL(9, pool.available());
+
+      {
+        ps = pool.allocate();
+        ::new(ps) S(3, 4);
+        Unique us2(ps, pool_deleter);
+        CHECK_EQUAL(2, S::instance_count);
+        CHECK_EQUAL(3, us2->a);
+        CHECK_EQUAL(4, us2->b);
+        CHECK_EQUAL(8, pool.available());      
+        us2->~S();
+      }
+
+      ps = pool.allocate();
+      ::new(ps) S(5, 6);
+      Unique us3(ps, pool_deleter);
+      CHECK_EQUAL(2, S::instance_count);
+      CHECK_EQUAL(5, us3->a);
+      CHECK_EQUAL(6, us3->b);
+      CHECK_EQUAL(8, pool.available());
+      us1->~S();
+      us3->~S();
+    }
+
+    CHECK_EQUAL(0, S::instance_count);
+    CHECK_EQUAL(10, pool.available());
+  }
+
+  //*************************************************************************
+  TEST(test_destroyer_functor_with_unique_ptr)
+  {
+    etl::pool<S, 10> pool;  
+    auto pool_deleter = [&pool](S* ptr) { pool.destroy(ptr); };
+    using Unique = etl::unique_ptr<S, decltype(pool_deleter)>;
+
+    S::instance_count = 0;
+
+    CHECK_EQUAL(10, pool.available());
+
+    {
+      Unique us1(pool.create(1, 2), pool_deleter);
+      CHECK_EQUAL(1, S::instance_count);
+      CHECK_EQUAL(1, us1->a);
+      CHECK_EQUAL(2, us1->b);
+      CHECK_EQUAL(9, pool.available());
+
+      {
+        Unique us2(pool.create(3, 4), pool_deleter);
+        CHECK_EQUAL(2, S::instance_count);
+        CHECK_EQUAL(3, us2->a);
+        CHECK_EQUAL(4, us2->b);
+        CHECK_EQUAL(8, pool.available());
+      }
+
+      CHECK_EQUAL(1, S::instance_count);
+
+      Unique us3(pool.create(5, 6), pool_deleter);
+      CHECK_EQUAL(2, S::instance_count);
+      CHECK_EQUAL(5, us3->a);
+      CHECK_EQUAL(6, us3->b);
+      CHECK_EQUAL(8, pool.available());
+    }
+
+    CHECK_EQUAL(0, S::instance_count);
+    CHECK_EQUAL(10, pool.available());
+  }
 }
