@@ -129,6 +129,78 @@ namespace
   {
     return first + second;
   }
+
+  // Structs to test is_specialized
+  template <typename T>
+  struct specialized
+  {
+  };
+
+  template <typename T>
+  struct other_specialized
+  {
+  };
+
+  struct MF
+  {
+    int f(int)                         { return 0; }
+    int fc(int) const                  { return 0; }
+    int fv(int) volatile               { return 0; }
+    int fcv(int) const volatile        { return 0; }
+
+#if ETL_USING_CPP11
+    int fl(int) &                      { return 0; }
+    int flc(int) const &               { return 0; }
+    int flv(int) volatile &            { return 0; }
+    int flcv(int) const volatile &     { return 0; }
+
+    int fr(int) &&                     { return 0; }
+    int frc(int) const &&              { return 0; }
+    int frv(int) volatile &&           { return 0; }
+    int frcv(int) const volatile &&    { return 0; }
+#endif
+
+#if ETL_HAS_NOEXCEPT_FUNCTION_TYPE
+    int fn(int) noexcept                         { return 0; }
+    int fnc(int) const noexcept                  { return 0; }
+    int fnv(int) volatile noexcept               { return 0; }
+    int fncv(int) const volatile noexcept        { return 0; }
+
+    int fnl(int) & noexcept                      { return 0; }
+    int fnlc(int) const & noexcept               { return 0; }
+    int fnlv(int) volatile & noexcept            { return 0; }
+    int fnlcv(int) const volatile & noexcept     { return 0; }
+
+    int fnr(int) && noexcept                     { return 0; }
+    int fnrc(int) const && noexcept              { return 0; }
+    int fnrv(int) volatile && noexcept           { return 0; }
+    int fnrcv(int) const volatile && noexcept    { return 0; }
+#endif
+
+    int fvar(int, ...)                 { return 0; }
+    int fvarc(int, ...) const          { return 0; }
+  };
+
+  struct MO
+  {
+    int data;
+  };
+
+  static int f(int) { return 0; }
+  static int fvar(...) { return 0; }
+  static int fvar2(int, ...) { return 0; }
+
+  template <typename T, typename... TArgs>
+  static T ft(TArgs...) { return T(); }
+
+#if ETL_HAS_NOEXCEPT_FUNCTION_TYPE
+  static int fn(int) noexcept { return 0; }
+  static int fnvar(...) noexcept { return 0; }
+  static int fnvar2(int, ...) noexcept { return 0; }
+
+  template <typename T, typename... TArgs>
+  static T fnt(TArgs...) noexcept { return T(); }
+#endif
 }
 
 // Definitions for when the STL and compiler built-ins are not available.
@@ -1098,11 +1170,11 @@ namespace
   TEST(test_conjunction)
   {
 #if ETL_USING_CPP17
-    CHECK((etl::conjunction_v<etl::true_type, etl::true_type, etl::true_type>));
-    CHECK((!etl::conjunction_v<etl::true_type, etl::false_type, etl::true_type>));
+    CHECK_TRUE((etl::conjunction_v<etl::true_type, etl::true_type, etl::true_type>));
+    CHECK_FALSE((etl::conjunction_v<etl::true_type, etl::false_type, etl::true_type>));
 #else
-    CHECK((etl::conjunction<etl::true_type, etl::true_type, etl::true_type>::value));
-    CHECK((!etl::conjunction<etl::true_type, etl::false_type, etl::true_type>::value));
+    CHECK_TRUE((etl::conjunction<etl::true_type, etl::true_type, etl::true_type>::value));
+    CHECK_FALSE((etl::conjunction<etl::true_type, etl::false_type, etl::true_type>::value));
 #endif
   }
 
@@ -1110,11 +1182,25 @@ namespace
   TEST(test_disjunction)
   {
 #if ETL_USING_CPP17
-    CHECK((etl::disjunction_v<etl::false_type, etl::true_type, etl::false_type>));
-    CHECK((!etl::disjunction_v<etl::false_type, etl::false_type, etl::false_type>));
+    CHECK_TRUE((etl::disjunction_v<etl::false_type, etl::true_type, etl::false_type>));
+    CHECK_FALSE((etl::disjunction_v<etl::false_type, etl::false_type, etl::false_type>));
 #else
-    CHECK((etl::disjunction<etl::false_type, etl::true_type, etl::false_type>::value));
-    CHECK((!etl::disjunction<etl::false_type, etl::false_type, etl::false_type>::value));
+    CHECK_TRUE((etl::disjunction<etl::false_type, etl::true_type, etl::false_type>::value));
+    CHECK_FALSE((etl::disjunction<etl::false_type, etl::false_type, etl::false_type>::value));
+#endif
+  }
+
+  //*************************************************************************
+  TEST(test_exclusive_disjunction)
+  {
+#if ETL_USING_CPP17
+    CHECK_TRUE((etl::exclusive_disjunction_v<etl::false_type, etl::true_type, etl::false_type>));
+    CHECK_FALSE((etl::exclusive_disjunction_v<etl::true_type, etl::false_type, etl::true_type>));
+    CHECK_FALSE((etl::exclusive_disjunction_v<etl::false_type, etl::false_type, etl::false_type>));
+#else
+    CHECK_TRUE((etl::exclusive_disjunction<etl::false_type, etl::true_type, etl::false_type>::value));
+    CHECK_FALSE((etl::exclusive_disjunction<etl::true_type, etl::false_type, etl::true_type>::value));
+    CHECK_FALSE((etl::exclusive_disjunction<etl::false_type, etl::false_type, etl::false_type>::value));
 #endif
   }
 
@@ -1328,12 +1414,68 @@ namespace
 #endif
   }
 
+  //*************************************************************************
+  TEST(test_nth_base)
+  {
+    struct D0 { };
+    struct D1 : D0 { using base_type = D0; };
+    struct D2 : D1 { using base_type = D1; };
+    struct D3 : D2 { using base_type = D2; };
+    struct D4 : D3 { using base_type = D3; };
+
+    CHECK_TRUE((std::is_same<D4, etl::nth_base_t<0, D4>>::value));
+    CHECK_TRUE((std::is_same<D3, etl::nth_base_t<1, D4>>::value));
+    CHECK_TRUE((std::is_same<D2, etl::nth_base_t<2, D4>>::value));
+    CHECK_TRUE((std::is_same<D1, etl::nth_base_t<3, D4>>::value));
+    CHECK_TRUE((std::is_same<D0, etl::nth_base_t<4, D4>>::value));
+  }
+
   //*************************************************************************
   TEST(test_type_identity) 
   {
     CHECK_CLOSE(type_identity_test_add(1.5f, 2), 3.5f, 0.01f);
   }
 
+  //*************************************************************************
+#if ETL_USING_BUILTIN_UNDERLYING_TYPE
+  TEST(test_underlying_type)
+  {
+    enum enum0_t : char
+    {
+    };
+
+    enum enum1_t : uint32_t
+    {
+    };
+
+    enum class enum2_t : short
+    {
+    };
+
+    enum class enum3_t : size_t
+    {
+    };
+
+    using enum4_t = enum1_t;
+    using enum5_t = std::add_const<enum2_t>::type;
+
+    CHECK_TRUE((std::is_same<etl::underlying_type<enum0_t>::type, char>::value));
+    CHECK_TRUE((std::is_same<etl::underlying_type<enum1_t>::type, uint32_t>::value));
+    CHECK_TRUE((std::is_same<etl::underlying_type<enum2_t>::type, short>::value));
+    CHECK_TRUE((std::is_same<etl::underlying_type<enum3_t>::type, size_t>::value));
+    CHECK_TRUE((std::is_same<etl::underlying_type<enum4_t>::type, uint32_t>::value));
+    CHECK_TRUE((std::is_same<etl::underlying_type<enum5_t>::type, short>::value));
+#if ETL_USING_CPP11
+    CHECK_TRUE((std::is_same<etl::underlying_type_t<enum0_t>, char>::value));
+    CHECK_TRUE((std::is_same<etl::underlying_type_t<enum1_t>, uint32_t>::value));
+    CHECK_TRUE((std::is_same<etl::underlying_type_t<enum2_t>, short>::value));
+    CHECK_TRUE((std::is_same<etl::underlying_type_t<enum3_t>, size_t>::value));
+    CHECK_TRUE((std::is_same<etl::underlying_type_t<enum4_t>, uint32_t>::value));
+    CHECK_TRUE((std::is_same<etl::underlying_type_t<enum5_t>, short>::value));
+#endif
+  }
+#endif
+
   //*************************************************************************
   TEST(test_has_duplicates)
   {
@@ -1379,4 +1521,148 @@ namespace
     CHECK_EQUAL(2, (etl::count_of<char, int, char, double, char>::value));
 #endif
   }
+
+  //*************************************************************************
+  TEST(test_is_specialization)
+  {
+#if ETL_USING_CPP17
+    CHECK_TRUE((etl::is_specialization_v<specialized<int>, specialized>));
+    CHECK_FALSE((etl::is_specialization_v<other_specialized<int>, specialized>));
+#else
+    CHECK_TRUE((etl::is_specialization<specialized<int>, specialized>::value));
+    CHECK_FALSE((etl::is_specialization<other_specialized<int>, specialized>::value));
+#endif
+  }
+
+#if ETL_USING_CPP11
+  //*************************************************************************
+  TEST(test_is_constant_evaluated)
+  {
+    constexpr bool c0 = etl::is_constant_evaluated();
+#if !ETL_USING_CPP23 && defined(ETL_COMPILER_MICROSOFT)
+    // Not supported on MSVC via __has_builtin, see determine_builtin_support.h
+    CHECK_FALSE(c0);
+#else
+    CHECK_TRUE(c0);
+#endif
+
+    volatile int i = 1;
+    const bool c1 = (((i == 1) && etl::is_constant_evaluated()) ? true : false);
+    CHECK_FALSE(c1);
+  }
+#endif
+
+  //*************************************************************************
+  // Basic cv for member function pointers
+  TEST(test_is_member_function_pointer)
+  {
+    CHECK_TRUE((etl::is_member_function_pointer<decltype(&MF::f)>::value));
+    CHECK_TRUE((etl::is_member_function_pointer<decltype(&MF::fc)>::value));
+    CHECK_TRUE((etl::is_member_function_pointer<decltype(&MF::fv)>::value));
+    CHECK_TRUE((etl::is_member_function_pointer<decltype(&MF::fcv)>::value));
+
+    CHECK_TRUE((etl::is_member_function_pointer<decltype(&MF::fl)>::value));
+    CHECK_TRUE((etl::is_member_function_pointer<decltype(&MF::flc)>::value));
+    CHECK_TRUE((etl::is_member_function_pointer<decltype(&MF::flv)>::value));
+    CHECK_TRUE((etl::is_member_function_pointer<decltype(&MF::flcv)>::value));
+
+    CHECK_TRUE((etl::is_member_function_pointer<decltype(&MF::fr)>::value));
+    CHECK_TRUE((etl::is_member_function_pointer<decltype(&MF::frc)>::value));
+    CHECK_TRUE((etl::is_member_function_pointer<decltype(&MF::frv)>::value));
+    CHECK_TRUE((etl::is_member_function_pointer<decltype(&MF::frcv)>::value));
+
+#if ETL_HAS_NOEXCEPT_FUNCTION_TYPE
+    CHECK_TRUE((etl::is_member_function_pointer<decltype(&MF::fn)>::value));
+    CHECK_TRUE((etl::is_member_function_pointer<decltype(&MF::fnc)>::value));
+    CHECK_TRUE((etl::is_member_function_pointer<decltype(&MF::fnv)>::value));
+    CHECK_TRUE((etl::is_member_function_pointer<decltype(&MF::fncv)>::value));
+
+    CHECK_TRUE((etl::is_member_function_pointer<decltype(&MF::fnl)>::value));
+    CHECK_TRUE((etl::is_member_function_pointer<decltype(&MF::fnlc)>::value));
+    CHECK_TRUE((etl::is_member_function_pointer<decltype(&MF::fnlv)>::value));
+    CHECK_TRUE((etl::is_member_function_pointer<decltype(&MF::fnlcv)>::value));
+
+    CHECK_TRUE((etl::is_member_function_pointer<decltype(&MF::fnr)>::value));
+    CHECK_TRUE((etl::is_member_function_pointer<decltype(&MF::fnrc)>::value));
+    CHECK_TRUE((etl::is_member_function_pointer<decltype(&MF::fnrv)>::value));
+    CHECK_TRUE((etl::is_member_function_pointer<decltype(&MF::fnrcv)>::value));
+#endif
+
+    CHECK_TRUE((etl::is_member_function_pointer<decltype(&MF::fvar)>::value));
+    CHECK_TRUE((etl::is_member_function_pointer<decltype(&MF::fvarc)>::value));
+  }
+
+  //*************************************************************************
+  // Negative tests for member function pointer trait
+  TEST(test_is_member_function_pointer_negative)
+  {
+    (void)f(0);
+
+    // Free function pointer
+    CHECK_FALSE((etl::is_member_function_pointer<decltype(&f)>::value));
+
+    // Member object pointer
+    CHECK_FALSE((etl::is_member_function_pointer<int MF::*>::value));
+
+    // Plain function type (not pointer)
+    CHECK_FALSE((etl::is_member_function_pointer<int(int)>::value));
+
+    // Non-function type
+    CHECK_FALSE((etl::is_member_function_pointer<int>::value));
+  }
+
+  //*************************************************************************
+  // Member object pointer trait
+  TEST(test_is_member_object_pointer)
+  {
+    CHECK_TRUE((etl::is_member_object_pointer<int MO::*>::value));
+
+    // Not a member object pointer
+    CHECK_FALSE((etl::is_member_object_pointer<int (MF::*)(int)>::value));
+    CHECK_FALSE((etl::is_member_object_pointer<int*>::value));
+  }
+
+  //*************************************************************************
+  // Member pointer (either member object or member function pointer)
+  TEST(test_is_member_pointer_any)
+  {
+    CHECK_TRUE((etl::is_member_pointer<int MF::*>::value));
+    CHECK_TRUE((etl::is_member_pointer<int (MF::*)(int)>::value));
+
+    // Not member pointers
+    CHECK_FALSE((etl::is_member_pointer<int*>::value));
+    CHECK_FALSE((etl::is_member_pointer<decltype(f)>::value));
+  }
+
+  //*************************************************************************
+  // Function type detection
+  TEST(test_is_function)
+  {
+    (void)f(0);
+    (void)fvar();
+    (void)fvar2(0); 
+    (void)ft<int, int, double>(0, 0.0);
+
+    CHECK_TRUE((etl::is_function<decltype(f)>::value));
+    CHECK_TRUE((etl::is_function<decltype(fvar)>::value));
+    CHECK_TRUE((etl::is_function<decltype(fvar2)>::value));
+    CHECK_TRUE((etl::is_function<decltype(ft<int, int, double>)>::value));
+
+#if ETL_HAS_NOEXCEPT_FUNCTION_TYPE
+    (void)fn(0);
+    (void)fnvar();
+    (void)fnvar2(0);
+    (void)fnt<int, int, double>(0, 0.0);
+
+    CHECK_TRUE((etl::is_function<decltype(fn)>::value));
+    CHECK_TRUE((etl::is_function<decltype(fnvar)>::value));
+    CHECK_TRUE((etl::is_function<decltype(fnvar2)>::value));
+    CHECK_TRUE((etl::is_function<decltype(fnt<int, int, double>)>::value));
+#endif
+
+    CHECK_FALSE((etl::is_function<int>::value));
+    CHECK_FALSE((etl::is_function<int*>::value));
+    CHECK_FALSE((etl::is_function<int MF::*>::value));
+    CHECK_FALSE((etl::is_function<int (MF::*)(int)>::value)); // pointer, not function
+  }
 }
